@@ -155,7 +155,7 @@ y[j] - b1) + 2 * rho * (y[i] - a1) * (y[j] - b1));
 }
 
 static GnmValue *
-cum_biv_norm_dist(FunctionEvalInfo *ei, GnmValue const * const *argv)
+cum_biv_norm_dist(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float a = value_get_as_float (argv[0]);
 	gnm_float b = value_get_as_float (argv[1]);
@@ -213,7 +213,7 @@ opt_bs1 (OptionSide side,
 
 
 static GnmValue *
-opt_bs (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_bs (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -282,7 +282,7 @@ opt_bs_delta1 (OptionSide side,
 
 
 static GnmValue *
-opt_bs_delta (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_bs_delta (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -342,7 +342,7 @@ opt_bs_gamma1 (gnm_float s,gnm_float x,gnm_float t,gnm_float r,gnm_float v,gnm_f
 
 
 static GnmValue *
-opt_bs_gamma (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_bs_gamma (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float s = value_get_as_float (argv[0]);
 	gnm_float x = value_get_as_float (argv[1]);
@@ -408,7 +408,7 @@ opt_bs_theta1 (OptionSide side,
 }
 
 static GnmValue *
-opt_bs_theta (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_bs_theta (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -468,7 +468,7 @@ opt_bs_vega1 (gnm_float s, gnm_float x, gnm_float t,
 }
 
 static GnmValue *
-opt_bs_vega (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_bs_vega (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float s = value_get_as_float (argv[0]);
 	gnm_float x = value_get_as_float (argv[1]);
@@ -539,7 +539,7 @@ opt_bs_rho1 (OptionSide side, gnm_float s, gnm_float x,
 
 
 static GnmValue *
-opt_bs_rho (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_bs_rho (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -606,7 +606,7 @@ opt_bs_carrycost1 (OptionSide side, gnm_float s, gnm_float x, gnm_float t, gnm_f
 }
 
 static GnmValue *
-opt_bs_carrycost (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_bs_carrycost (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -678,7 +678,7 @@ opt_garman_kohlhagen1 (OptionSide side,
 }
 
 static GnmValue *
-opt_garman_kohlhagen (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_garman_kohlhagen (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -748,7 +748,7 @@ opt_french1 (OptionSide side, gnm_float s, gnm_float x, gnm_float tradingt, gnm_
 
 
 static GnmValue *
-opt_french (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_french (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -815,7 +815,7 @@ opt_jump_diff1 (OptionSide side, gnm_float s, gnm_float x, gnm_float t, gnm_floa
 }
 
 static GnmValue *
-opt_jump_diff (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_jump_diff (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -901,7 +901,7 @@ opt_miltersen_schwartz1 (OptionSide side, gnm_float p_t, gnm_float f_t, gnm_floa
 }
 
 static GnmValue *
-opt_miltersen_schwartz (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_miltersen_schwartz (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float p_t = value_get_as_float (argv[1]);
@@ -1026,7 +1026,7 @@ static gnm_float opt_rgw1 (gnm_float s, gnm_float x, gnm_float t1, gnm_float t2,
 
 
 static GnmValue *
-opt_rgw(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_rgw(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float s = value_get_as_float (argv[0]);
 	gnm_float x = value_get_as_float (argv[1]);
@@ -1071,7 +1071,7 @@ static GnmFuncHelp const help_opt_rgw[] = {
 
 /* the Barone-Adesi and Whaley (1987) American approximation */
 static GnmValue *
-opt_baw_amer (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_baw_amer (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -1270,7 +1270,7 @@ opt_bjer_stens1 (OptionSide side, gnm_float s, gnm_float x, gnm_float t, gnm_flo
 }
 
 static GnmValue *
-opt_bjer_stens (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_bjer_stens (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -1356,7 +1356,7 @@ phi (gnm_float s, gnm_float t, gnm_float gamma, gnm_float H, gnm_float I, gnm_fl
 
 /* Executive stock options */
 static GnmValue *
-opt_exec (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_exec (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -1406,7 +1406,7 @@ static GnmFuncHelp const help_opt_exec[] = {
 
 /* Forward start options */
 static GnmValue *
-opt_forward_start(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_forward_start(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -1454,7 +1454,7 @@ static GnmFuncHelp const help_opt_forward_start[] = {
 
 /* time switch options (discrete) */
 static GnmValue *
-opt_time_switch (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_time_switch (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -1524,7 +1524,7 @@ static GnmFuncHelp const help_opt_time_switch[] = {
 
 /* simple chooser options */
 static GnmValue *
-opt_simple_chooser (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_simple_chooser (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float s = value_get_as_float (argv[0]);
 	gnm_float x = value_get_as_float (argv[1]);
@@ -1573,7 +1573,7 @@ static GnmFuncHelp const help_opt_simple_chooser[] = {
 
 /* Complex chooser options */
 static GnmValue *
-opt_complex_chooser(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_complex_chooser(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float s = value_get_as_float (argv[0]);
 	gnm_float xc = value_get_as_float (argv[1]);
@@ -1674,7 +1674,7 @@ opt_crit_val_chooser (gnm_float s,gnm_float xc,gnm_float xp,gnm_float t,
 
 /* Options on options */
 static GnmValue *
-opt_on_options (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_on_options (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	char const *type_flag = value_peek_string (argv[0]);
 	gnm_float s = value_get_as_float (argv[1]);
@@ -1775,7 +1775,7 @@ CriticalValueOptionsOnOptions (OptionSide side, gnm_float x1, gnm_float x2, gnm_
 
 /* Writer extendible options */
 static GnmValue *
-opt_extendible_writer (FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_extendible_writer (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string (argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -1846,7 +1846,7 @@ static GnmFuncHelp const help_opt_extendible_writer[] = {
 
 /* Two asset correlation options */
 static GnmValue *
-opt_2_asset_correlation(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_2_asset_correlation(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put = option_side (value_peek_string(argv[0]));
 	gnm_float s1 = value_get_as_float (argv[1]);
@@ -1909,7 +1909,7 @@ static GnmFuncHelp const help_opt_2_asset_correlation[] = {
 
 /* European option to exchange one asset for another */
 static GnmValue *
-opt_euro_exchange(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_euro_exchange(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float s1 = value_get_as_float (argv[0]);
 	gnm_float s2 = value_get_as_float (argv[1]);
@@ -1961,7 +1961,7 @@ static GnmFuncHelp const help_opt_euro_exchange[] = {
 
 /* American option to exchange one asset for another */
 static GnmValue *
-opt_amer_exchange(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_amer_exchange(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	gnm_float s1 = value_get_as_float (argv[0]);
 	gnm_float s2 = value_get_as_float (argv[1]);
@@ -2006,7 +2006,7 @@ static GnmFuncHelp const help_opt_amer_exchange[] = {
 
 /* Spread option approximation */
 static GnmValue *
-opt_spread_approx(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_spread_approx(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put_flag = option_side (value_peek_string(argv[0]));
 	gnm_float f1 = value_get_as_float (argv[1]);
@@ -2049,7 +2049,7 @@ static GnmFuncHelp const help_opt_spread_approx[] = {
 
 /* Floating strike lookback options */
 static GnmValue *
-opt_float_strk_lkbk(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_float_strk_lkbk(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put_flag = option_side (value_peek_string(argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -2114,7 +2114,7 @@ static GnmFuncHelp const help_opt_float_strk_lkbk[] = {
 /* Fixed strike lookback options */
 
 static GnmValue *
-opt_fixed_strk_lkbk(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_fixed_strk_lkbk(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionSide call_put_flag = option_side (value_peek_string(argv[0]));
 	gnm_float s = value_get_as_float (argv[1]);
@@ -2185,7 +2185,7 @@ static GnmFuncHelp const help_opt_fixed_strk_lkbk[] = {
 
 /* Binomial Tree valuation */
 static GnmValue *
-opt_binomial(FunctionEvalInfo *ei, GnmValue const * const *argv)
+opt_binomial(GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	OptionType amer_euro_flag = option_type(value_peek_string(argv[0]));
 	OptionSide call_put_flag = option_side (value_peek_string(argv[1]));
