@@ -7,7 +7,7 @@
  * Copyright (C) 2001 Adrian Custer, Berkeley
  * email: acuster@nature.berkeley.edu
  *
- * Copyright (C) 2001 Andreas J. Guelzow, Edmonton
+ * Copyright (C) 2001-2006 Andreas J. Guelzow, Edmonton
  * email: aguelzow@taliesin.ca
  *
  * This program is free software; you can redistribute it and/or modify
@@ -54,8 +54,8 @@
 #include <style-border.h>
 #include <sheet-style.h>
 #include <parse-util.h>
-#include <cellspan.h>
 #include <rendered-value.h>
+#include <cellspan.h>
 
 #include <locale.h>
 #include <gsf/gsf-output.h>
@@ -74,7 +74,7 @@ typedef struct {
 	char const     *horizontal;
 } latex_border_translator_t;
 
-/* the index into the following array is StyleBorderType */
+/* the index into the following array is GnmStyleBorderType */
 static latex_border_translator_t const border_styles[] = {
 	{LATEX_NO_BORDER,     "",  "~"},
 	{LATEX_SINGLE_BORDER, "|", "-"},
@@ -131,21 +131,65 @@ static latex_border_connectors_t const conn_styles[LATEX_MAX_BORDER]
 	  {{":b:",""}, { ":b:",""}, { ":",":"}}}}
 };
 
+/**
+ * latex_raw_str :
+ * @p :	    a pointer to a char, start of the string to be processed
+ * @output : output stream where the processed characters are written.
+ * @utf8:   is this a utf8 string?
+ *
+ * @return:
+ * If @p is in form of \L{foo}, return the char pointer pointing to '}' of \L{foo}
+ * else return @p untouched; 
+ * 
+ * Check if @p is in form of \L{foo}.
+ * If it is, the exact "foo" will be put into @output, without any esacaping.
+ *
+ */
+static char const *
+latex_raw_str(char const *p, GsfOutput *output, gboolean utf8)
+{
+	char const *p_begin, *p_orig = p;
+	int depth = 1;
+	if(strncasecmp(p, "\\L{", 3) == 0){
+		p += 3;
+		p_begin = p;
+		/* find the matching close bracket */
+		for(; *p; p = utf8 ? g_utf8_next_char(p) : p + 1){
+			switch(*p){ /* FIXME: how to put in unmatched brackets? */
+				case '{':
+					depth ++;
+					break;
+				case '}':
+					depth--;
+					if(depth == 0){
+						/* put the string beginning from p_begin to p to output */
+						gsf_output_write(output, p - p_begin, p_begin);
+						return p;
+					}
+			}
+		}
+	}
+	return p_orig;
+}
+
+
 /**
  * latex_fputs_utf :
  *
  * @p :      a pointer to a char, start of the string to be processed.
  * @output : output stream where the processed characters are written.
  *
- * This escapes any special LaTeX characters from the LaTeX engine. Re-ordered
- * from Rasca's code to have most common first.
+ * This escapes any special LaTeX characters from the LaTeX engine,
+ * except the ones enclosed in "\L{" and "}".
+ * Re-ordered from Rasca's code to have most common first.
  */
 static void
 latex_fputs_utf (char const *p, GsfOutput *output)
 {
+	char const *rlt;
 	for (; *p; p = g_utf8_next_char (p)) {
 		switch (g_utf8_get_char (p)) {
-			
+
 			/* These are the classic TeX symbols $ & % # _ { } (see Lamport, p.15) */
 		case '$': case '&': case '%': case '#':
 		case '_': case '{': case '}':
@@ -156,7 +200,11 @@ latex_fputs_utf (char const *p, GsfOutput *output)
 			gsf_output_printf (output, "\\%c{ }", *p);
 			break;
 		case '\\':
-			gsf_output_puts (output, "$\\backslash$");
+			rlt = latex_raw_str(p, output, TRUE);
+			if(rlt == p)
+			    gsf_output_puts (output, "$\\backslash$");
+			else
+			    p = rlt;
 			break;
 			/* Are these available only in LaTeX through mathmode? */
 		case '>': case '<':
@@ -177,13 +225,15 @@ latex_fputs_utf (char const *p, GsfOutput *output)
  * @p :     a pointer to a char, start of the string to be processed.
  * @output: output stream where the processed characters are written.
  *
- * This escapes any special LaTeX characters from the LaTeX engine.
+ * This escapes any special LaTeX characters from the LaTeX engine,
+ * except the ones enclosed in "\L{" and "}".
  * 
  * We assume that htis will be set in Mathematics mode.
  */
 static void
 latex_math_fputs_utf (char const *p, GsfOutput *output)
 {
+	char const *rlt;
 	for (; *p; p = g_utf8_next_char (p)) {
 		switch (g_utf8_get_char (p)) {
 
@@ -196,9 +246,12 @@ latex_math_fputs_utf (char const *p, GsfOutput *output)
 				gsf_output_printf (output, "\\%c{ }", *p);
 				break;
 			case '\\':
-				gsf_output_puts (output, "\\backslash");
+				rlt = latex_raw_str(p, output, TRUE);
+				if(rlt == p)
+				    gsf_output_puts (output, "$\\backslash$");
+				else
+				    p = rlt;
 				break;
-
 			default:
 				gsf_output_write (output, 
 						  (g_utf8_next_char (p)) - p, p);
@@ -207,33 +260,71 @@ latex_math_fputs_utf (char const *p, GsfOutput *output)
 	}
 }
 
+/**
+ * latex_convert_latin_to_utf
+ *
+ * @text: string to convert
+ *
+ * return value needs to be freed with g_free
+ *
+ * call g_convert_with_fallback and also handle utf minus.
+ *
+ */
+static char *
+latex_convert_latin_to_utf (char const *text)
+{
+	char * encoded_text = NULL;
+
+	gsize bytes_read;
+	gsize bytes_written;
+
+	if (g_utf8_strchr (text,-1, 0x2212) == NULL) {
+		encoded_text = g_convert_with_fallback
+			(text, strlen (text),
+			 "ISO-8859-1", "UTF-8", (gchar *)"?", 
+			 &bytes_read, &bytes_written, NULL);
+	} else {
+		gunichar* ucs_string = NULL;
+		gunichar* this_unichar;
+		char *new_text;
+		glong items_read;
+		glong items_written;
+
+		ucs_string = g_utf8_to_ucs4_fast (text, -1, &items_written);
+		for (this_unichar = ucs_string; *this_unichar != '\0'; this_unichar++) {
+			if (*this_unichar == 0x2212)
+				*this_unichar = 0x002d;
+		}
+		new_text = g_ucs4_to_utf8 (ucs_string, -1, &items_read, &items_written, NULL);
+		g_free (ucs_string);
+		encoded_text = g_convert_with_fallback
+			(new_text, strlen (new_text),
+			 "ISO-8859-1", "UTF-8", (gchar *)"?", 
+			 &bytes_read, &bytes_written, NULL);
+		g_free (new_text);
+	}
+
+	return encoded_text;
+}
+
 /**
  * latex_fputs_latin :
  *
  * @p :      a pointer to a char, start of the string to be processed.
  * @output : output stream where the processed characters are written.
  *
- * This escapes any special LaTeX characters from the LaTeX engine. Re-ordered
- * from Rasca's code to have most common first.
+ * This escapes any special LaTeX characters from the LaTeX engine,
+ * except the ones enclosed in "\L{" and "}".
+ * Re-ordered from Rasca's code to have most common first.
  */
 static void
 latex_fputs_latin (char const *text, GsfOutput *output)
 {
 	char * encoded_text = NULL;
-	char * p;
-	gsize bytes_read;
-	gsize bytes_written;
-	GError * error = NULL;
+	char const *p;
+	char const *rlt;
 
-	encoded_text = g_convert_with_fallback
-		(text, strlen (text),
-		 "ISO-8859-1", "UTF-8", (gchar *)"?", 
-		 &bytes_read, &bytes_written, &error);
-	if (error != NULL)
-	{
-		g_warning ("UTF-8 to Latin1 conversion failed for:\n%s", text);
-		g_error_free (error);
-	}
+	encoded_text = latex_convert_latin_to_utf (text);
 
 	for (p = encoded_text; *p; p++) {
 		switch (*p) {
@@ -248,7 +339,11 @@ latex_fputs_latin (char const *text, GsfOutput *output)
 			gsf_output_printf (output, "\\%c{ }", *p);
 			break;
 		case '\\':
-			gsf_output_puts (output, "$\\backslash$");
+			rlt = latex_raw_str(p, output, FALSE);
+			if(rlt == p)
+			    gsf_output_puts (output, "$\\backslash$");
+			else
+			    p = rlt;
 			break;
 			/* Are these available only in LaTeX through mathmode? */
 		case '>': case '<': case '':
@@ -269,7 +364,8 @@ latex_fputs_latin (char const *text, GsfOutput *output)
  * @p :     a pointer to a char, start of the string to be processed.
  * @output: output stream where the processed characters are written.
  *
- * This escapes any special LaTeX characters from the LaTeX engine.
+ * This escapes any special LaTeX characters from the LaTeX engine, 
+ * except the ones enclosed in "\L{" and "}".
  * 
  * We assume that htis will be set in Mathematics mode.
  */
@@ -277,20 +373,10 @@ static void
 latex_math_fputs_latin (char const *text, GsfOutput *output)
 {
 	char * encoded_text = NULL;
-	char * p;
-	gsize bytes_read;
-	gsize bytes_written;
-	GError * error = NULL;
+	char const *p;
+	char const *rlt;
 
-	encoded_text = g_convert_with_fallback
-		(text, strlen (text),
-		 "ISO-8859-1", "UTF-8", (gchar *)"?", 
-		 &bytes_read, &bytes_written, &error);
-	if (error != NULL)
-	{
-		g_warning ("UTF-8 to Latin1 conversion failed for:\n%s", text);
-		g_error_free (error);
-	}
+	encoded_text = latex_convert_latin_to_utf (text);
 
 	for (p = encoded_text; *p; p++) {
 		switch (*p) {
@@ -304,7 +390,11 @@ latex_math_fputs_latin (char const *text, GsfOutput *output)
 				gsf_output_printf (output, "\\%c{ }", *p);
 				break;
 			case '\\':
-				gsf_output_puts (output, "\\backslash");
+				rlt = latex_raw_str(p, output, FALSE);
+				if(rlt == p)
+				    gsf_output_puts (output, "$\\backslash$");
+				else
+				    p = rlt;
 				break;
 
 			default:
@@ -562,48 +652,48 @@ latex2e_write_table_header(GsfOutput *output, int num_cols)
  * Determine the border style
  *
  */
-static StyleBorderType
+static GnmStyleBorderType
 latex2e_find_vline (int col, int row, Sheet *sheet, GnmStyleElement which_border)
 {
-	GnmBorder	   *border;
-	GnmStyle             *mstyle;
+	GnmBorder const	*border;
+	GnmStyle const	*style;
 
 	if (col < 0 || row < 0)
-		return STYLE_BORDER_NONE;
+		return GNM_STYLE_BORDER_NONE;
 
-	mstyle = sheet_style_get (sheet, col, row);
-	border = gnm_style_get_border (mstyle, which_border);
+	style = sheet_style_get (sheet, col, row);
+	border = gnm_style_get_border (style, which_border);
 
-	if (!(style_border_is_blank (border) ||
-	      border->line_type == STYLE_BORDER_NONE))
+	if (!(gnm_style_border_is_blank (border) ||
+	      border->line_type == GNM_STYLE_BORDER_NONE))
 		return border->line_type;
 
 	if (which_border == MSTYLE_BORDER_LEFT) {
 		if (col < 1)
-			return STYLE_BORDER_NONE;
-		mstyle = sheet_style_get (sheet, col - 1, row);
-		border = gnm_style_get_border (mstyle, MSTYLE_BORDER_RIGHT);
-		return ((style_border_is_blank (border)) ? STYLE_BORDER_NONE :
+			return GNM_STYLE_BORDER_NONE;
+		style = sheet_style_get (sheet, col - 1, row);
+		border = gnm_style_get_border (style, MSTYLE_BORDER_RIGHT);
+		return ((gnm_style_border_is_blank (border)) ? GNM_STYLE_BORDER_NONE :
 			border->line_type);
 	} else {
-		mstyle = sheet_style_get (sheet, col + 1, row);
-		border = gnm_style_get_border (mstyle, MSTYLE_BORDER_LEFT);
-		return ((style_border_is_blank (border)) ? STYLE_BORDER_NONE :
+		style = sheet_style_get (sheet, col + 1, row);
+		border = gnm_style_get_border (style, MSTYLE_BORDER_LEFT);
+		return ((gnm_style_border_is_blank (border)) ? GNM_STYLE_BORDER_NONE :
 			border->line_type);
 	}
 
-	return STYLE_BORDER_NONE;
+	return GNM_STYLE_BORDER_NONE;
 }
 
 /**
  * latex2e_print_vert_border:
  *
  * @output : Output stream where the cell contents will be written.
- * @clines:  StyleBorderType indicating the type of border
+ * @clines:  GnmStyleBorderType indicating the type of border
  *
  */
 static void
-latex2e_print_vert_border (GsfOutput *output, StyleBorderType style)
+latex2e_print_vert_border (GsfOutput *output, GnmStyleBorderType style)
 {
 	g_return_if_fail (style >= 0 && style < G_N_ELEMENTS (border_styles));
 
@@ -611,12 +701,13 @@ latex2e_print_vert_border (GsfOutput *output, StyleBorderType style)
 }
 
 /**
- * latex2e_write_blank_cell:
+ * latex2e_write_blank_multicolumn_cell:
  *
  * @output : output stream where the cell contents will be written.
- * @col :
- * @row :
- * @first_column :
+ * @star_col :
+ * @start_row :
+ * @num_merged_cols : an integer value of the number of columns to merge.
+ * @num_merged_rows : an integer value of the number of rows to merge.
  * @sheet :  the current sheet.
  *
  * This function creates all the LaTeX code for the cell of a table (i.e. all
@@ -626,76 +717,14 @@ latex2e_print_vert_border (GsfOutput *output, StyleBorderType style)
  *
  */
 static void
-latex2e_write_blank_cell (GsfOutput *output, gint col, gint row, gint index,
-			  StyleBorderType *borders, Sheet *sheet)
+latex2e_write_blank_multicolumn_cell (GsfOutput *output, int start_col, int start_row,
+				      int num_merged_cols, int num_merged_rows,
+				      gint index,
+				      GnmStyleBorderType *borders, Sheet *sheet)
 {
-	GnmCellPos pos;
-	StyleBorderType left_border = STYLE_BORDER_NONE;
-	StyleBorderType right_border = STYLE_BORDER_NONE;
-
-	pos.col = col;
-	pos.row = row;
-
-	if (index == 0) {
-		left_border = *borders;
-	}
-	right_border = borders[index + 1];
-
-	if (left_border == STYLE_BORDER_NONE && right_border == STYLE_BORDER_NONE)
-		gsf_output_printf (output, "\n");
-	else {
-		/* Open the multicolumn statement. */
-		gsf_output_printf (output, "\\multicolumn{1}{");
-
-		if (left_border != STYLE_BORDER_NONE)
-			latex2e_print_vert_border (output, left_border);
-
-		/* Drop in the left hand format delimiter. */
-		gsf_output_printf (output, "c");
-
-		if (right_border != STYLE_BORDER_NONE)
-			latex2e_print_vert_border (output, right_border);
-
-		/*Close the right delimiter, as above. Also add the empty text delimiters.*/
-		gsf_output_printf (output,"}{}%%\n");
-	}
-}
-
-
-/**
- * latex2e_write_multicolumn_cell:
- *
- * @output : output stream where the cell contents will be written.
- * @cell :   the cell whose contents are to be written.
- * @num_merged_cols : an integer value of the number of columns to merge.
- * @num_merged_rows : an integer value of the number of rows to merge.
- * @sheet :  the current sheet.
- *
- * This function creates all the LaTeX code for the cell of a table (i.e. all
- * the code that might fall between two ampersands (&)).
- *
- * Note: we are _not_ putting single cell into \multicolumns since this
- * makes it much more difficult to change column widths later on.
- */
-static void
-latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
-				int num_merged_cols, int num_merged_rows,
-				gint index,
-				StyleBorderType *borders, Sheet *sheet)
-{
-	char * rendered_string;
-	gushort r,g,b;
-	gboolean wrap = FALSE;
-	GOFormatFamily cell_format_family;
 	int merge_width = 0;
-	StyleBorderType left_border = STYLE_BORDER_NONE;
-	StyleBorderType right_border = STYLE_BORDER_NONE;
-
-	/* Print the cell according to its style. */
-	GnmStyle *mstyle = cell_get_mstyle (cell);
-	gboolean hidden = gnm_style_get_content_hidden (mstyle);
-
-	g_return_if_fail (mstyle != NULL);
+	GnmStyleBorderType left_border = GNM_STYLE_BORDER_NONE;
+	GnmStyleBorderType right_border = GNM_STYLE_BORDER_NONE;
 
 	if (num_merged_cols > 1 || num_merged_rows > 1) {
 		ColRowInfo const * ci;
@@ -719,7 +748,7 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 		/* Open the multicolumn statement. */
 		gsf_output_printf (output, "\\multicolumn{%d}{", num_merged_cols);
 
-		if (left_border != STYLE_BORDER_NONE)
+		if (left_border != GNM_STYLE_BORDER_NONE)
 			latex2e_print_vert_border (output, left_border);
 
 		if (num_merged_rows > 1) {
@@ -733,23 +762,146 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 			gsf_output_printf (output, "\t\\tabcolsep*2*%i}", num_merged_cols - 1);
 		}
 
-		if (right_border != STYLE_BORDER_NONE)
+		if (right_border != GNM_STYLE_BORDER_NONE)
 			latex2e_print_vert_border (output, right_border);
 
 		/*Close the right delimiter, as above. Also open the text delimiter.*/
 		gsf_output_printf (output,"}%%\n\t{");
-	} else if (left_border != STYLE_BORDER_NONE || right_border != STYLE_BORDER_NONE) {
+	} else if (left_border != GNM_STYLE_BORDER_NONE || right_border != GNM_STYLE_BORDER_NONE) {
 
 		/* Open the multicolumn statement. */
 		gsf_output_printf (output, "\\multicolumn{1}{");
 
-		if (left_border != STYLE_BORDER_NONE)
+		if (left_border != GNM_STYLE_BORDER_NONE)
 			latex2e_print_vert_border (output, left_border);
 
 		/* Drop in the left hand format delimiter. */
-		gsf_output_printf (output, "p{\\gnumericCol%s}", col_name(cell->pos.col));
+		gsf_output_printf (output, "p{\\gnumericCol%s}", col_name(start_col));
 
-		if (right_border != STYLE_BORDER_NONE)
+		if (right_border != GNM_STYLE_BORDER_NONE)
+			latex2e_print_vert_border (output, right_border);
+
+		/*Close the right delimiter, as above. Also open the text delimiter.*/
+		gsf_output_printf (output,"}%%\n\t{");
+
+	}
+
+	if (num_merged_rows > 1) {
+		int i;
+		/* Open the multirow statement. */
+		gsf_output_printf (output, "\\multirow{%d}[%i]*{\\begin{tabular}{p{",
+			 num_merged_rows, num_merged_rows/2);
+		for (i = 0; i < num_merged_cols; i++) {
+			gsf_output_printf (output, "\t\\gnumericCol%s+%%\n", col_name (start_col + i));
+		}
+		if (num_merged_cols > 2)
+			gsf_output_printf (output, "\t\\tabcolsep*2*%i}}", num_merged_cols - 2);
+		else
+			gsf_output_printf (output, "\t0pt}}");
+		/* Close the multirowtext. */
+		gsf_output_printf (output, "\\end{tabular}}");
+	}
+
+	/* Close the multicolumn text bracket. */
+	if (num_merged_cols > 1 || left_border != GNM_STYLE_BORDER_NONE
+	    || right_border != GNM_STYLE_BORDER_NONE)
+		gsf_output_printf (output, "}");
+
+	/* And we are done. */
+	gsf_output_printf (output, "\n");
+
+}
+
+
+/**
+ * latex2e_write_multicolumn_cell:
+ *
+ * @output : output stream where the cell contents will be written.
+ * @cell :   the cell whose contents are to be written.
+ * @star_col :
+ * @num_merged_cols : an integer value of the number of columns to merge.
+ * @num_merged_rows : an integer value of the number of rows to merge.
+ * @sheet :  the current sheet.
+ *
+ * This function creates all the LaTeX code for the cell of a table (i.e. all
+ * the code that might fall between two ampersands (&)).
+ *
+ * Note: we are _not_ putting single cell into \multicolumns since this
+ * makes it much more difficult to change column widths later on.
+ */
+static void
+latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
+				int num_merged_cols, int num_merged_rows,
+				gint index,
+				GnmStyleBorderType *borders, Sheet *sheet)
+{
+	char * rendered_string;
+	gushort r,g,b;
+	gboolean wrap = FALSE;
+	GOFormatFamily cell_format_family;
+	int merge_width = 0;
+	GnmStyleBorderType left_border = GNM_STYLE_BORDER_NONE;
+	GnmStyleBorderType right_border = GNM_STYLE_BORDER_NONE;
+
+	/* Print the cell according to its style. */
+	GnmStyle const *style = gnm_cell_get_style (cell);
+	gboolean hidden = gnm_style_get_contents_hidden (style);
+
+	g_return_if_fail (style != NULL);
+
+	if (num_merged_cols > 1 || num_merged_rows > 1) {
+		ColRowInfo const * ci;
+		int i;
+
+		for (i = 0; i < num_merged_cols; i++) {
+			ci = sheet_col_get_info (sheet, start_col + i);
+			merge_width += ci->size_pixels;
+		}
+	}
+
+	if (index == 0) {
+		left_border = *borders;
+	}
+	right_border = borders[index + num_merged_cols];
+
+	/* We only set up a multicolumn command if necessary */
+	if (num_merged_cols > 1) {
+		int i;
+
+		/* Open the multicolumn statement. */
+		gsf_output_printf (output, "\\multicolumn{%d}{", num_merged_cols);
+
+		if (left_border != GNM_STYLE_BORDER_NONE)
+			latex2e_print_vert_border (output, left_border);
+
+		if (num_merged_rows > 1) {
+			gsf_output_printf (output, "c");
+		} else {
+			gsf_output_printf (output, "p{");
+			for (i = 0; i < num_merged_cols; i++) {
+				gsf_output_printf (output, "\t\\gnumericCol%s+%%\n",
+					 col_name (start_col + i));
+			}
+			gsf_output_printf (output, "\t\\tabcolsep*2*%i}", num_merged_cols - 1);
+		}
+
+		if (right_border != GNM_STYLE_BORDER_NONE)
+			latex2e_print_vert_border (output, right_border);
+
+		/*Close the right delimiter, as above. Also open the text delimiter.*/
+		gsf_output_printf (output,"}%%\n\t{");
+	} else if (left_border != GNM_STYLE_BORDER_NONE || right_border != GNM_STYLE_BORDER_NONE) {
+
+		/* Open the multicolumn statement. */
+		gsf_output_printf (output, "\\multicolumn{1}{");
+
+		if (left_border != GNM_STYLE_BORDER_NONE)
+			latex2e_print_vert_border (output, left_border);
+
+		/* Drop in the left hand format delimiter. */
+		gsf_output_printf (output, "p{\\gnumericCol%s}", col_name(start_col));
+
+		if (right_border != GNM_STYLE_BORDER_NONE)
 			latex2e_print_vert_border (output, right_border);
 
 		/*Close the right delimiter, as above. Also open the text delimiter.*/
@@ -776,10 +928,11 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 
 	/* Send the alignment of the cell through a routine to deal with
 	 * HALIGN_GENERAL and then deal with the three cases. */
-	switch ( style_default_halign(mstyle, cell) ) {
+	switch (gnm_style_default_halign (style, cell)) {
 	case HALIGN_RIGHT:
 		gsf_output_printf (output, "\\gnumericPB{\\raggedleft}");
 		break;
+	case HALIGN_DISTRIBUTED:
 	case HALIGN_CENTER:
 	case HALIGN_CENTER_ACROSS_SELECTION:
 		gsf_output_printf (output, "\\gnumericPB{\\centering}");
@@ -794,15 +947,16 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 	}
 
         /* Check whether we should do word wrapping */
-	wrap = gnm_style_get_wrap_text (mstyle);
+	wrap = gnm_style_get_wrap_text (style);
 
 	/* if we don't wrap put it into an mbox, adjusted to width 0 to avoid moving */
 	/* it to the second line of the parbox */
 	if (!wrap)
-		switch ( style_default_halign(mstyle, cell) ) {
+		switch (gnm_style_default_halign (style, cell)) {
 		case HALIGN_RIGHT:
 			gsf_output_printf (output, "\\gnumbox[r]{");
 			break;
+		case HALIGN_DISTRIBUTED:
 		case HALIGN_CENTER:
 		case HALIGN_CENTER_ACROSS_SELECTION:
 			gsf_output_printf (output, "\\gnumbox{");
@@ -818,9 +972,9 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 			break;
 		}
 
-	if (!cell_is_empty (cell)) {
+	if (!gnm_cell_is_empty (cell)) {
                 /* Check the foreground (text) colour. */
-		GOColor fore = cell_get_render_color (cell);
+		GOColor fore = gnm_cell_get_render_color (cell);
 		if (fore == 0)
 			r = g = b = 0;
 		else {
@@ -841,52 +995,54 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
       		 */
 
 		if (hidden)
-		  gsf_output_printf (output, "\\phantom{");
+			gsf_output_printf (output, "\\phantom{");
 
-		if (font_is_monospaced (mstyle))
+		if (font_is_monospaced (style))
 			gsf_output_printf (output, "\\texttt{");
-		else if (font_is_sansserif (mstyle))
+		else if (font_is_sansserif (style))
 			gsf_output_printf (output, "\\textsf{");
-		if (gnm_style_get_font_bold (mstyle))
+		if (gnm_style_get_font_bold (style))
 			gsf_output_printf (output, "\\textbf{");
-		if (gnm_style_get_font_italic (mstyle))
+		if (gnm_style_get_font_italic (style))
 			gsf_output_printf (output, "\\textit{");
 
 
-		cell_format_family = cell_get_format (cell)->family;
-		if (cell_format_family == GO_FORMAT_NUMBER || cell_format_family == GO_FORMAT_CURRENCY ||
-		    cell_format_family == GO_FORMAT_PERCENTAGE || cell_format_family == GO_FORMAT_FRACTION ||
+		cell_format_family = go_format_get_family (gnm_cell_get_format (cell));
+		if (cell_format_family == GO_FORMAT_NUMBER ||
+		    cell_format_family == GO_FORMAT_CURRENCY ||
+		    cell_format_family == GO_FORMAT_PERCENTAGE ||
+		    cell_format_family == GO_FORMAT_FRACTION ||
 		    cell_format_family == GO_FORMAT_SCIENTIFIC){
 			gsf_output_printf (output, "$");
-		        if (gnm_style_get_font_italic(mstyle))
+		        if (gnm_style_get_font_italic(style))
 			    gsf_output_printf (output, "\\gnumericmathit{");
 
 			/* Print the cell contents. */
-			rendered_string = cell_get_rendered_text (cell);
+			rendered_string = gnm_cell_get_rendered_text (cell);
 			latex_math_fputs (rendered_string, output);
 			g_free (rendered_string);
 
-		        if (gnm_style_get_font_italic(mstyle))
+		        if (gnm_style_get_font_italic(style))
 			    gsf_output_printf (output, "}");
 			gsf_output_printf (output, "$");
 		} else {
 			/* Print the cell contents. */
-			rendered_string = cell_get_rendered_text (cell);
+			rendered_string = gnm_cell_get_rendered_text (cell);
 			latex_fputs (rendered_string, output);
 			g_free (rendered_string);
 		}
 
 		/* Close the styles for the cell. */
-		if (gnm_style_get_font_italic (mstyle))
+		if (gnm_style_get_font_italic (style))
 			gsf_output_printf (output, "}");
-		if (gnm_style_get_font_bold (mstyle))
+		if (gnm_style_get_font_bold (style))
 			gsf_output_printf (output, "}");
-		if (font_is_monospaced (mstyle))
+		if (font_is_monospaced (style))
 			gsf_output_printf (output, "}");
-		else if (font_is_sansserif (mstyle))
+		else if (font_is_sansserif (style))
 			gsf_output_printf (output, "}");
 		if (hidden)
-		  gsf_output_printf (output, "}");
+			gsf_output_printf (output, "}");
 		if (r != 0 || g != 0 || b != 0)
 			gsf_output_printf (output, "}");
 	}
@@ -900,8 +1056,8 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 		gsf_output_printf (output, "\\end{tabular}}");
 
 	/* Close the multicolumn text bracket. */
-	if (num_merged_cols > 1 || left_border != STYLE_BORDER_NONE
-	    || right_border != STYLE_BORDER_NONE)
+	if (num_merged_cols > 1 || left_border != GNM_STYLE_BORDER_NONE
+	    || right_border != GNM_STYLE_BORDER_NONE)
 		gsf_output_printf (output, "}");
 
 	/* And we are done. */
@@ -912,7 +1068,7 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
 /**
  * latex2e_find_hhlines :
  *
- * @clines:  array of StyleBorderType* indicating the type of border
+ * @clines:  array of GnmStyleBorderType* indicating the type of border
  * @length:  (remaining) positions in clines
  * @col :
  * @row :
@@ -923,22 +1079,22 @@ latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int start_col,
  */
 
 static gboolean
-latex2e_find_hhlines (StyleBorderType *clines, int length, int col, int row,
+latex2e_find_hhlines (GnmStyleBorderType *clines, int length, int col, int row,
 		      Sheet *sheet, GnmStyleElement type)
 {
-	GnmStyle *mstyle;
-	GnmBorder	   *border;
- 	GnmRange const *merge_range;
+	GnmStyle const	*style;
+	GnmBorder const	*border;
+ 	GnmRange const	*merge_range;
 	GnmCellPos pos;
 
-	mstyle = sheet_style_get (sheet, col, row);
-	border = gnm_style_get_border (mstyle, type);
-	if (style_border_is_blank (border))
+	style = sheet_style_get (sheet, col, row);
+	border = gnm_style_get_border (style, type);
+	if (gnm_style_border_is_blank (border))
 		return FALSE;
 	clines[0] = border->line_type;
 	pos.col = col;
 	pos.row = row;
-	merge_range = sheet_merge_is_corner (sheet, &pos);
+	merge_range = gnm_sheet_merge_is_corner (sheet, &pos);
 	if (merge_range != NULL) {
 		int i;
 
@@ -954,7 +1110,7 @@ latex2e_find_hhlines (StyleBorderType *clines, int length, int col, int row,
  * latex2e_print_hhline :
  *
  * @output : output stream where the cell contents will be written.
- * @clines:  an array of StyleBorderType* indicating the type of border
+ * @clines:  an array of GnmStyleBorderType* indicating the type of border
  * @n : the number of elements in clines
  *
  * This procedure prints an hhline command according to the content
@@ -962,8 +1118,8 @@ latex2e_find_hhlines (StyleBorderType *clines, int length, int col, int row,
  *
  */
 static void
-latex2e_print_hhline (GsfOutput *output, StyleBorderType *clines, int n, StyleBorderType *prev_vert,
-		      StyleBorderType *next_vert)
+latex2e_print_hhline (GsfOutput *output, GnmStyleBorderType *clines, int n, GnmStyleBorderType *prev_vert,
+		      GnmStyleBorderType *next_vert)
 {
 	int col;
 	gsf_output_printf (output, "\\hhline{");
@@ -1027,8 +1183,8 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
  	GnmRange const *merge_range;
 	int row, col, num_cols, length;
 	int num_merged_cols, num_merged_rows;
-	StyleBorderType *clines, *this_clines;
-	StyleBorderType *prev_vert = NULL, *next_vert = NULL, *this_vert;
+	GnmStyleBorderType *clines, *this_clines;
+	GnmStyleBorderType *prev_vert = NULL, *next_vert = NULL, *this_vert;
 	gboolean needs_hline;
 
 	/* This is the preamble of the LaTeX2e file. */
@@ -1051,8 +1207,8 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 	gsf_output_puts (output, ""
 "\\setlength\\gnumericTableWidthComplete{\\gnumericTableWidth+%\n"
 "         \\tabcolsep*\\gumericNumCols*2+\\arrayrulewidth*\\gumericNumCols}\n"
-"\\ifthenelse{\\lengthtest{\\gnumericTableWidthComplete > \\textwidth}}%\n"
-"         {\\def\\gnumericScale{\\ratio{\\textwidth-%\n"
+"\\ifthenelse{\\lengthtest{\\gnumericTableWidthComplete > \\linewidth}}%\n"
+"         {\\def\\gnumericScale{\\ratio{\\linewidth-%\n"
 "                        \\tabcolsep*\\gumericNumCols*2-%\n"
 "                        \\arrayrulewidth*\\gumericNumCols}%\n"
 "{\\gnumericTableWidth}}}%\n"
@@ -1091,11 +1247,11 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 		ColRowInfo const * ri;
 		ri = sheet_row_get_info (current_sheet, row);
 		if (ri->needs_respan)
-			row_calc_spans ((ColRowInfo *) ri, current_sheet);
+			row_calc_spans ((ColRowInfo *) ri, row, current_sheet);
 
 		/* We need to check for horizontal borders at the top of this row */
 		length = num_cols;
-		clines = g_new0 (StyleBorderType, length);
+		clines = g_new0 (GnmStyleBorderType, length);
 		needs_hline = FALSE;
 		this_clines = clines;
 		for (col = total_range.start.col; col <= total_range.end.col; col++) {
@@ -1122,7 +1278,7 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 		/* We do this here rather than as we output the cells since */
 		/* we need to know the right connectors! */
 		prev_vert = next_vert;
-		next_vert = g_new0 (StyleBorderType, num_cols + 1);
+		next_vert = g_new0 (GnmStyleBorderType, num_cols + 1);
 		this_vert = next_vert;
 		*this_vert = latex2e_find_vline (total_range.start.col, row,
 						current_sheet, MSTYLE_BORDER_LEFT);
@@ -1138,8 +1294,11 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 		g_free (clines);
 
 		for (col = total_range.start.col; col <= total_range.end.col; col++) {
-			CellSpanInfo const *the_span;
+		        GnmCellPos pos;
 
+			pos.col = col;
+			pos.row = row;
+			
 			/* Get the cell. */
 			cell = sheet_cell_get (current_sheet, col, row);
 
@@ -1149,33 +1308,17 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 			else
 				gsf_output_printf (output, "\t ");
 
-			/* Even an empty cell (especially an empty cell!) can be */
-			/* covered by a span!                                    */
-			the_span = row_span_get (ri, col);
-			if (the_span != NULL) {
-				latex2e_write_multicolumn_cell(output, (GnmCell *)the_span->cell,
-							       col,
-							       the_span->right -
-							       col + 1, 1,
+			/* Check a merge. */
+			merge_range = gnm_sheet_merge_is_corner (current_sheet, &pos);
+			if (merge_range == NULL) {
+			        if (gnm_cell_is_empty(cell))
+				        latex2e_write_blank_multicolumn_cell(output, col, row,
+									     1, 1,
 							       col - total_range.start.col,
 							       next_vert, current_sheet);
-				col += the_span->right - col;
-				continue;
-			}
-
-
-			/* A blank cell has only a few options*/
-			if (cell_is_empty(cell)) {
-				latex2e_write_blank_cell(output, col, row,
-							col - total_range.start.col,
-							next_vert, current_sheet);
-				continue;
-			}
-
-			/* Check a merge. */
-			merge_range = sheet_merge_is_corner (current_sheet, &cell->pos);
-			if (merge_range == NULL) {
-				latex2e_write_multicolumn_cell(output, cell, col, 1, 1,
+				else
+				        latex2e_write_multicolumn_cell(output, cell, col,
+								       1, 1,
 							       col - total_range.start.col,
 							       next_vert, current_sheet);
 				continue;
@@ -1185,20 +1328,26 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 			num_merged_cols = merge_range->end.col - merge_range->start.col + 1;
 			num_merged_rows = merge_range->end.row - merge_range->start.row + 1;
 
-			latex2e_write_multicolumn_cell(output, cell, col, num_merged_cols,
-						       num_merged_rows,
-						       col - total_range.start.col,
-						       next_vert, current_sheet);
+			if (gnm_cell_is_empty(cell))
+				latex2e_write_blank_multicolumn_cell(output, col, row, 
+								     num_merged_cols,
+								     num_merged_rows,
+								     col - total_range.start.col,
+								     next_vert, current_sheet);
+			else
+				latex2e_write_multicolumn_cell(output, cell, col, num_merged_cols,
+							       num_merged_rows,
+							       col - total_range.start.col,
+							       next_vert, current_sheet);
 			col += (num_merged_cols - 1);
 			continue;
 		}
 		gsf_output_printf (output, "\\\\\n");
-		if (prev_vert != NULL)
-			g_free (prev_vert);
+		g_free (prev_vert);
 	}
 
 	/* We need to check for horizontal borders at the bottom  of  the last  row */
-	clines = g_new0 (StyleBorderType, total_range.end.col - total_range.start.col + 1);
+	clines = g_new0 (GnmStyleBorderType, total_range.end.col - total_range.start.col + 1);
 	needs_hline = FALSE;
 	length = num_cols;
 	this_clines = clines;
@@ -1228,3 +1377,104 @@ latex_file_save (GOFileSaver const *fs, IOContext *io_context,
 	gsf_output_printf (output, "\\end{longtable}\n\n");
 	gsf_output_printf (output, "\\gnumericTableEnd\n");
 }
+
+
+/**
+ * latex2e_table_cell:
+ *
+ * @output : output stream where the cell contents will be written.
+ * @cell :   the cell whose contents are to be written.
+ * @sheet :  the current sheet.
+ *
+ * This function creates all the LaTeX code for the cell of a table (i.e. all
+ * the code that might fall between two ampersands (&)).
+ *
+ */
+static void
+latex2e_table_write_cell (GsfOutput *output, GnmCell *cell, Sheet *sheet)
+{
+	GnmStyle const *style = gnm_cell_get_style (cell);
+
+	if (gnm_style_get_contents_hidden (style))
+		return;
+
+	if (!gnm_cell_is_empty (cell)) {
+		char * rendered_string;
+
+		rendered_string = gnm_cell_get_rendered_text (cell);
+		latex_fputs (rendered_string, output);
+		g_free (rendered_string);
+	}
+}
+
+
+/**
+ * latex2e_table_write_file_header:
+ *
+ * @output: Output stream where the cell contents will be written.
+ *
+ * This ouputs the LaTeX header. Kept separate for esthetics.
+ */
+
+static void
+latex2e_table_write_file_header(GsfOutput *output)
+{
+	gsf_output_puts (output,
+"%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\n"
+"%%                                                                  %%\n"
+"%%  This is a LaTeX2e table fragment exported from Gnumeric.        %%\n"
+"%%                                                                  %%\n"
+"%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\n"
+        );
+}
+
+/**
+ * latex_table_file_save :  The LaTeX2e exporter plugin function.
+ *
+ * @FileSaver :        New structure for file plugins. I don't understand.
+ * @IOcontext :        currently not used but reserved for the future.
+ * @WorkbookView :     this provides the way to access the sheet being exported.
+ * @filename :         where we'll write.
+ *
+ * This writes the top sheet of a Gnumeric workbook as the content of a latex table environment.
+ * We try to avoid all formatting.
+ */
+void
+latex_table_file_save (GOFileSaver const *fs, IOContext *io_context,
+		 WorkbookView const *wb_view, GsfOutput *output)
+{
+	GnmCell *cell;
+	Sheet *current_sheet;
+	GnmRange total_range;
+	int row, col;
+
+	/* This is the preamble of the LaTeX2e file. */
+	latex2e_table_write_file_header(output);
+
+	/* Get the topmost sheet and its range from the plugin function argument. */
+	current_sheet = wb_view_cur_sheet(wb_view);
+	total_range = sheet_get_extent (current_sheet, TRUE);
+
+	/* Step through the sheet, writing cells as appropriate. */
+	for (row = total_range.start.row; row <= total_range.end.row; row++) {
+		ColRowInfo const * ri;
+		ri = sheet_row_get_info (current_sheet, row);
+		if (ri->needs_respan)
+			row_calc_spans ((ColRowInfo *) ri, row, current_sheet);
+
+		for (col = total_range.start.col; col <= total_range.end.col; col++) {
+			/* Get the cell. */
+			cell = sheet_cell_get (current_sheet, col, row);
+
+			/* Check if we are not the first cell in the row.*/
+			if (col != total_range.start.col)
+				gsf_output_printf (output, "\t&");
+
+			if (gnm_cell_is_empty (cell))
+				continue;
+
+			latex2e_table_write_cell(output, cell, current_sheet);
+		}
+		gsf_output_printf (output, "\\\\\n");
+	}
+}
