@@ -31,8 +31,9 @@
 #include <goffice/utils/go-glib-extras.h>
 #include <goffice/utils/go-file.h>
 #include <gsf/gsf-impl-utils.h>
-#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
+#include <gtk/gtkfilefilter.h>
+#include <gtk/gtkrecentmanager.h>
 
 #define GNM_APP(o)		(G_TYPE_CHECK_INSTANCE_CAST((o), GNM_APP_TYPE, GnmApp))
 #define GNM_APP_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k),	 GNM_APP_TYPE, GnmAppClass))
@@ -248,7 +249,7 @@ gnm_app_clipboard_cut_copy (WorkbookControl *wbc, gboolean is_cut,
 
 /** gnm_app_clipboard_cut_copy_obj :
  * @wbc : #WorkbookControl
- * @is_cut : 
+ * @is_cut :
  * @sv : #SheetView
  * @objects : a list of #SheetObject which is freed
  *
@@ -266,7 +267,7 @@ gnm_app_clipboard_cut_copy_obj (WorkbookControl *wbc, gboolean is_cut,
 	g_free (app->clipboard_cut_range);
 	app->clipboard_cut_range = NULL;
 	sv_weak_ref (sv, &(app->clipboard_sheet_view));
-	app->clipboard_copied_contents 
+	app->clipboard_copied_contents
 		= clipboard_copy_obj (sv_sheet (sv), objects);
 	if (is_cut) {
 		cmd_objects_delete (wbc, objects, _("Cut Object"));
@@ -476,6 +477,14 @@ gnm_app_dpi_to_pixels (void)
 void *
 gnm_app_create_opener_filter (void)
 {
+	/* See below.  */
+	static const char *const bad_suffixes[] = {
+		"txt",
+		"html", "htm",
+		"xml",
+		NULL
+	};
+
 	GtkFileFilter *filter = gtk_file_filter_new ();
 
 	GList *openers;
@@ -488,27 +497,49 @@ gnm_app_create_opener_filter (void)
 		const GSList *suffixes = go_file_opener_get_suffixes (opener);
 
 		while (mimes) {
-			gtk_file_filter_add_mime_type (filter, mimes->data);
+#if 0
+			const char *mime = mimes->data;
+			/*
+			 * This needs rethink, see 438918.  Too many things
+			 * like *.xml and *.txt get added.
+			 */
+			gtk_file_filter_add_mime_type (filter, mime);
+			if (0)
+				g_print ("%s: Adding mime %s\n", go_file_opener_get_description (opener), mime);
+#endif
 			mimes = mimes->next;
 		}
 
 		while (suffixes) {
-			char *pattern = g_strconcat ("*.", suffixes->data, NULL);
+			const char *suffix = suffixes->data;
+			char *pattern;
+			int i;
+
+			for (i = 0; bad_suffixes[i]; i++)
+				if (strcmp (suffix, bad_suffixes[i]) == 0)
+					goto bad_suffix;
+
+			pattern = g_strconcat ("*.", suffix, NULL);
 			gtk_file_filter_add_pattern (filter, pattern);
+			if (0)
+				g_print ("%s: Adding %s\n", go_file_opener_get_description (opener), pattern);
 			g_free (pattern);
+
+		bad_suffix:
 			suffixes = suffixes->next;
 		}
 	}
-
 	return filter;
 }
 
 #ifdef HAVE_GTK_RECENT_MANAGER_GET_DEFAULT
 static gint
-compare_mru (GtkRecentInfo *a,
-	     GtkRecentInfo *b)
+compare_mru (GtkRecentInfo *a, GtkRecentInfo *b)
 {
-  return (gtk_recent_info_get_modified (a) < gtk_recent_info_get_modified (b));
+	time_t ta = MAX (gtk_recent_info_get_visited (a), gtk_recent_info_get_modified (a));
+	time_t tb = MAX (gtk_recent_info_get_visited (b), gtk_recent_info_get_modified (b));
+
+	return ta < tb;
 }
 #endif
 
@@ -520,18 +551,19 @@ compare_mru (GtkRecentInfo *a,
  * Return value: the list, which must be freed along with the strings in it.
  **/
 GSList *
-gnm_app_history_get_list (gboolean force_reload)
+gnm_app_history_get_list (int max_elements)
 {
 #ifdef HAVE_GTK_RECENT_MANAGER_GET_DEFAULT
 	GtkRecentManager *manager = gtk_recent_manager_get_default ();
 	GSList *res = NULL;
 	GList *items, *l;
 	GtkFileFilter *filter = gnm_app_create_opener_filter ();
+	int n_elements = 0;
 
 	items = gtk_recent_manager_get_items (manager);
 	items = g_list_sort (items, (GCompareFunc)compare_mru);
 
-	for (l = items; l; l = l->next) {
+	for (l = items; l && n_elements < max_elements; l = l->next) {
 		GtkRecentInfo *ri = l->data;
 		const char *uri = gtk_recent_info_get_uri (ri);
 		gboolean want_it;
@@ -560,8 +592,10 @@ gnm_app_history_get_list (gboolean force_reload)
 			g_free (filename);
 		}
 
-		if (want_it)
+		if (want_it) {
 			res = g_slist_prepend (res, g_strdup (uri));
+			n_elements++;
+		}
 	}
 
 	go_list_free_custom (items, (GFreeFunc)gtk_recent_info_unref);
@@ -590,6 +624,10 @@ gnm_app_history_add (char const *uri, const char *mimetype)
 
 	memset (&rd, 0, sizeof (rd));
 
+#if 0
+	g_print ("uri: %s\nmime: %s\n\n", uri, mimetype ? mimetype : "-");
+#endif
+
         rd.mime_type =
 		g_strdup (mimetype ? mimetype : "application/octet-stream");
 
@@ -608,11 +646,12 @@ gnm_app_history_add (char const *uri, const char *mimetype)
 	g_object_notify (G_OBJECT (app), "file-history-list");
 }
 
-gboolean gnm_app_use_auto_complete	  (void) { return gnm_app_prefs->auto_complete; }
-gboolean gnm_app_live_scrolling	  (void) { return gnm_app_prefs->live_scrolling; }
-int	 gnm_app_auto_expr_recalc_lag (void) { return gnm_app_prefs->recalc_lag; }
-gboolean gnm_app_use_transition_keys  (void) { return gnm_app_prefs->transition_keys; }
-void     gnm_app_set_transition_keys  (gboolean state)
+int	 gnm_app_enter_moves_dir	(void) { return gnm_app_prefs->enter_moves_dir; }
+gboolean gnm_app_use_auto_complete	(void) { return gnm_app_prefs->auto_complete; }
+gboolean gnm_app_live_scrolling		(void) { return gnm_app_prefs->live_scrolling; }
+int	 gnm_app_auto_expr_recalc_lag	(void) { return gnm_app_prefs->recalc_lag; }
+gboolean gnm_app_use_transition_keys	(void) { return gnm_app_prefs->transition_keys; }
+void     gnm_app_set_transition_keys	(gboolean state)
 {
 	((GnmAppPrefs *)gnm_app_prefs)->transition_keys = state;
 }
@@ -660,7 +699,7 @@ gnumeric_application_get_property (GObject *obj, guint param_id,
 #endif
 	switch (param_id) {
 	case APPLICATION_PROP_FILE_HISTORY_LIST:
-		g_value_set_pointer (value, gnm_app_history_get_list (FALSE));
+		g_value_set_pointer (value, gnm_app_history_get_list (G_MAXINT));
 		break;
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
@@ -740,7 +779,7 @@ gnm_app_init (GObject *obj)
 GSF_CLASS (GnmApp, gnm_app,
 	   gnm_app_class_init, gnm_app_init,
 	   G_TYPE_OBJECT);
- 
+
 /**********************************************************************/
 static GSList *extra_uis = NULL;
 
