@@ -4,11 +4,12 @@
 #include "gnumeric.h"
 #include <gdk/gdktypes.h>
 
-gboolean cell_calc_layout (GnmCell const *cell, RenderedValue *rv, int y_direction,
+gboolean cell_calc_layout (GnmCell const *cell, GnmRenderedValue *rv, int y_direction,
 			   int width, int height, int h_center,
 			   GOColor *res_color, gint *res_x, gint *res_y);
 
-void cell_finish_layout (GnmCell const *cell, RenderedValue *rv,
+void cell_finish_layout (GnmCell *cell, GnmRenderedValue *rv,
+			 int col_width,
 			 gboolean inhibit_overflow);
 
 void cell_draw (GnmCell const *cell, GdkGC *gc, GdkDrawable *drawable,
