@@ -172,7 +172,7 @@ gnm_cell_set_value (GnmCell *cell, GnmValue *v)
  */
 void
 gnm_cell_set_expr_and_value (GnmCell *cell, GnmExprTop const *texpr, GnmValue *v,
-			 gboolean link_expr)
+			     gboolean link_expr)
 {
 	g_return_if_fail (cell != NULL);
 	g_return_if_fail (texpr != NULL);
@@ -263,17 +263,15 @@ gnm_cell_set_expr (GnmCell *cell, GnmExprTop const *texpr)
 /**
  * gnm_cell_set_array_formula:
  * @sheet:   The sheet to set the expr in.
- * @row_a:   The top row in the destination region.
  * @col_a:   The left column in the destination region.
- * @row_b:   The bottom row in the destination region.
+ * @row_a:   The top row in the destination region.
  * @col_b:   The right column in the destination region.
- * @expr:    an expression
+ * @row_b:   The bottom row in the destination region.
+ * @expr:    an expression (the inner expression, not a corner or element)
  *
  * Uses cell_set_expr_internal to store the expr as an
  * 'array-formula'.  The supplied expression is wrapped in an array
- * operator for each cell in the range and scheduled for recalc.  The
- * upper left corner is handled as a special case and care is taken to
- * put it at the head of the recalc queue if recalcs are requested.
+ * operator for each cell in the range and scheduled for recalc.
  *
  * NOTE : Does not add a reference to the expression.  It takes over the
  *        caller's reference.
@@ -284,8 +282,8 @@ gnm_cell_set_expr (GnmCell *cell, GnmExprTop const *texpr)
  */
 void
 gnm_cell_set_array_formula (Sheet *sheet,
-			int col_a, int row_a, int col_b, int row_b,
-			GnmExprTop const *texpr)
+			    int col_a, int row_a, int col_b, int row_b,
+			    GnmExprTop const *texpr)
 {
 	int const num_rows = 1 + row_b - row_a;
 	int const num_cols = 1 + col_b - col_a;
@@ -470,9 +468,9 @@ gnm_cell_render_value (GnmCell *cell, gboolean allow_variable_width)
 
 	sheet = cell->base.sheet;
 	rv = gnm_rendered_value_new (cell, gnm_cell_get_style (cell),
-				 allow_variable_width,
-				 sheet->context,
-				 sheet->last_zoom_factor_used);
+				     allow_variable_width,
+				     sheet->context,
+				     sheet->last_zoom_factor_used);
 	if (cell->rendered_value)
 		gnm_rendered_value_destroy (cell->rendered_value);
 	cell->rendered_value = rv;
@@ -533,12 +531,14 @@ gnm_cell_get_entered_text (GnmCell const *cell)
 
 	if (gnm_cell_has_expr (cell)) {
 		GnmParsePos pp;
-		GString *res = g_string_new ("=");
+		GnmConventionsOut out;
 
-		gnm_expr_top_as_gstring (res, cell->base.texpr,
-					 parse_pos_init_cell (&pp, cell),
-					 cell->base.sheet->convs);
-		return g_string_free (res, FALSE);
+		out.accum = g_string_new ("=");
+		out.pp = parse_pos_init_cell (&pp, cell);
+		out.convs = cell->base.sheet->convs;
+
+		gnm_expr_top_as_gstring (cell->base.texpr, &out);
+		return g_string_free (out.accum, FALSE);
 	}
 
 	if (cell->value != NULL) {
