@@ -25,26 +25,38 @@ typedef int (*float_range_function_t) (gnm_float const *, int, gnm_float *);
 typedef int (*float_range_function2_t) (gnm_float const *, gnm_float const *, int, gnm_float *);
 typedef int (*string_range_function_t) (GSList *, char**);
 
+/*gnm_float *collect_floats (int argc, GnmExprConstPtr const *argv,
+				GnmEvalPos const *ep, CollectFlags flags,
+				int *n, GnmValue **error, GSList **info);*/
+
 gnm_float *collect_floats_value (GnmValue const *val,
 				 GnmEvalPos const *ep,
 				 CollectFlags flags,
 				 int *n, GnmValue **error);
 
+gnm_float *collect_floats_value_with_info (GnmValue const *val, GnmEvalPos const *ep,
+				CollectFlags flags, int *n, GSList **info,
+				GnmValue **error);
+
 GnmValue *float_range_function (int argc, GnmExprConstPtr const *argv,
-				FunctionEvalInfo *ei,
+				GnmFuncEvalInfo *ei,
 				float_range_function_t func,
 				CollectFlags flags,
 				GnmStdError func_error);
 
 GnmValue *float_range_function2 (GnmValue const *val0, GnmValue const *val1,
-				 FunctionEvalInfo *ei,
+				 GnmFuncEvalInfo *ei,
 				 float_range_function2_t func,
 				 CollectFlags flags,
 				 GnmStdError func_error);
 GnmValue *string_range_function (int argc, GnmExprConstPtr const *argv,
-				 FunctionEvalInfo *ei,
+				 GnmFuncEvalInfo *ei,
 				 string_range_function_t func,
 				 CollectFlags flags,
 				 GnmStdError func_error);
 
+GSList *gnm_slist_sort_merge (GSList * list_1, GSList * list_2);
+
+GArray *gnm_strip_missing (GArray * data, GSList **missing);
+
 #endif
