@@ -21,7 +21,7 @@
 
 #include <gnumeric-config.h>
 #include "gnumeric.h"
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "consolidate.h"
 
 #include "cell.h"
@@ -57,22 +57,21 @@ static void
 get_bounding_box (GSList const *granges, GnmRange *box)
 {
 	GSList const *l;
-	int max_x, max_y;
+	GnmSheetRange const *gr;
+	int ext_x, ext_y, max_x, max_y;
 
 	g_return_if_fail (granges != NULL);
 	g_return_if_fail (box != NULL);
 
 	max_x = max_y = 0;
 	for (l = granges; l != NULL; l = l->next) {
-		GnmSheetRange *gr = l->data;
-		int ext_x = gr->range.end.col - gr->range.start.col;
-		int ext_y = gr->range.end.row - gr->range.start.row;
+		gr = l->data;
 
 		g_return_if_fail (range_is_sane (&gr->range));
 
-		if (ext_x > max_x)
+		if ((ext_x = gr->range.end.col - gr->range.start.col) > max_x)
 			max_x = ext_x;
-		if (ext_y > max_y)
+		if ((ext_y = gr->range.end.row - gr->range.start.row) > max_y)
 			max_y = ext_y;
 	}
 
@@ -169,8 +168,8 @@ consolidate_check_destination (GnmConsolidate *cs, data_analysis_output_t *dao)
 	if (dao->type == NewSheetOutput || dao->type == NewWorkbookOutput)
 		return TRUE;
 
-	range_init (&r, dao->start_col, dao->start_row, 
-		    dao->start_col + dao->cols - 1, 
+	range_init (&r, dao->start_col, dao->start_row,
+		    dao->start_col + dao->cols - 1,
 		    dao->start_row + dao->rows - 1);
 	new = gnm_sheet_range_new (dao->sheet, &r);
 
@@ -273,6 +272,9 @@ retrieve_row_tree (GnmConsolidate *cs)
 {
 	GTree *tree;
 	GSList *l;
+	GnmSheetRange *gr;
+	TreeItem *ti;
+	GnmRange s;
 
 	g_return_val_if_fail (cs != NULL, NULL);
 
@@ -285,37 +287,24 @@ retrieve_row_tree (GnmConsolidate *cs)
 		for (row = sgr->range.start.row; row <= sgr->range.end.row; row++) {
 			GnmValue const *v = sheet_cell_get_value (sgr->sheet, sgr->range.start.col, row);
 
-			if (v && v->type != VALUE_EMPTY) {
-				GnmSheetRange *gr;
-				GSList *granges;
-				TreeItem *ti;
-				GnmRange s;
-
-				ti = g_tree_lookup (tree, (GnmValue *) v);
-
-				if (ti)
-					granges = ti->val;
-				else
-					granges = NULL;
-
-				s.start.row = s.end.row = row;
-				s.start.col = sgr->range.start.col + 1;
-				s.end.col   = sgr->range.end.col;
-
-				gr = gnm_sheet_range_new (sgr->sheet, &s);
-				granges = g_slist_append (granges, gr);
-
-				/*
-				 * NOTE: There is no need to duplicate the value
-				 * as it will not change during the consolidation
-				 * operation. We simply store it as const
-				 */
-				if (!ti) {
+			if (!VALUE_IS_EMPTY (v)) {
+				if (NULL == (ti = g_tree_lookup (tree, (gpointer) v))) {
+					/* NOTE: There is no need to duplicate
+					 * the value as it will not change
+					 * during the consolidation operation.
+					 * We simply store it as const */
 					ti = g_new0 (TreeItem, 1);
 				        ti->key = v;
+					ti->val = NULL;
 				}
-				ti->val = granges;
 
+				s.start.col = sgr->range.start.col + 1;
+				s.end.col   = sgr->range.end.col;
+				if (s.end.col >= s.start.col) {
+					s.start.row = s.end.row = row;
+					gr = gnm_sheet_range_new (sgr->sheet, &s);
+					ti->val = g_slist_append (ti->val, gr);
+				}
 				g_tree_insert (tree, (GnmValue *) ti->key, ti);
 			}
 		}
@@ -344,7 +333,7 @@ retrieve_col_tree (GnmConsolidate *cs)
 		for (col = sgr->range.start.col; col <= sgr->range.end.col; col++) {
 			GnmValue const *v = sheet_cell_get_value (sgr->sheet, col, sgr->range.start.row);
 
-			if (v && v->type != VALUE_EMPTY) {
+			if (!VALUE_IS_EMPTY (v)) {
 				GnmSheetRange *gr;
 				GSList *granges;
 				TreeItem *ti;
@@ -421,8 +410,8 @@ key_list_get (GnmConsolidate *cs, gboolean is_cols)
 			 * also we treat the value as a constant, we don't duplicate it. It will
 			 * not change during the consolidation.
 			 */
-			if (v && v->type != VALUE_EMPTY
-			    && g_slist_find_custom (keys, (GnmValue *) v, (GCompareFunc) cb_key_find) == NULL)
+			if (!VALUE_IS_EMPTY (v) &&
+			    g_slist_find_custom (keys, (GnmValue *) v, (GCompareFunc) cb_key_find) == NULL)
 				keys = g_slist_insert_sorted (keys, (GnmValue *) v, (GCompareFunc) cb_value_compare);
 		}
 	}
@@ -466,12 +455,7 @@ simple_consolidate (GnmFunc *fd, GSList const *src,
 	g_return_if_fail (fd != NULL);
 	g_return_if_fail (src != NULL);
 
-	/*
-	 * We first deduct the full bounding box of all ranges combined
-	 * this is needed so we know how far to traverse in total
-	 */
 	get_bounding_box (src, &box);
-
 	for (y = box.start.row; y <= box.end.row; y++) {
 		for (x = box.start.col; x <= box.end.col; x++) {
 			GnmExprList *args = NULL;
@@ -522,13 +506,9 @@ simple_consolidate (GnmFunc *fd, GSList const *src,
 				args = gnm_expr_list_append (args, gnm_expr_new_constant (val));
 			}
 
-			/* There is no need to free 'args', it will be absorbed
-			 * into the GnmExpr
-			 */
-			if (args) {
-				GnmExpr const *expr = gnm_expr_new_funcall (fd, args);
-				dao_set_cell_expr (dao, x, y, expr);
-			}
+			if (args)
+				dao_set_cell_expr (dao, x, y,
+					gnm_expr_new_funcall (fd, args));
 		}
 	}
 }
@@ -551,7 +531,7 @@ cb_row_tree (GnmValue const *key, TreeItem *ti, ConsolidateContext *cc)
 	GnmConsolidate *cs = cc->cs;
 
 	if (cs->mode & CONSOLIDATE_COPY_LABELS)
-		dao_set_cell_value (cc->dao, -1, 0, value_dup (key)); 
+		dao_set_cell_value (cc->dao, -1, 0, value_dup (key));
 
 	simple_consolidate (cs->fd, ti->val, FALSE, cc->dao);
 
@@ -599,7 +579,7 @@ cb_col_tree (GnmValue const *key, TreeItem *ti, ConsolidateContext *cc)
 	GnmConsolidate *cs = cc->cs;
 
 	if (cs->mode & CONSOLIDATE_COPY_LABELS)
-		dao_set_cell_value (cc->dao, 0, -1, value_dup (key)); 
+		dao_set_cell_value (cc->dao, 0, -1, value_dup (key));
 
 	simple_consolidate (cs->fd, ti->val, FALSE, cc->dao);
 
@@ -697,12 +677,12 @@ colrow_consolidate (GnmConsolidate *cs, data_analysis_output_t *dao)
 	if (cs->mode & CONSOLIDATE_COPY_LABELS) {
 		for (l = rows, y = 1; l != NULL; l = l->next, y++) {
 			GnmValue const *row_name = l->data;
-			
+
 			dao_set_cell_value (dao, 0, y, value_dup (row_name));
 		}
 		for (m = cols, x = 1; m != NULL; m = m->next, x++) {
 			GnmValue const *col_name = m->data;
-			
+
 			dao_set_cell_value (dao, x, 0, value_dup (col_name));
 		}
 		dao->offset_col = 1;
@@ -720,7 +700,7 @@ colrow_consolidate (GnmConsolidate *cs, data_analysis_output_t *dao)
 
 			if (args) {
 				GnmExpr const *expr = gnm_expr_new_funcall (cs->fd, args);
-				
+
 				dao_set_cell_expr (dao, x, y, expr);
 			}
 		}
@@ -731,7 +711,7 @@ colrow_consolidate (GnmConsolidate *cs, data_analysis_output_t *dao)
 }
 
 static gboolean
-consolidate_apply (GnmConsolidate *cs, 
+consolidate_apply (GnmConsolidate *cs,
 		   data_analysis_output_t *dao)
 {
 /* 	WorkbookView *wbv = wb_control_view (wbc); */
@@ -760,8 +740,8 @@ consolidate_apply (GnmConsolidate *cs,
 
 
 
-gboolean 
-tool_consolidate_engine (data_analysis_output_t *dao, gpointer specs, 
+gboolean
+tool_consolidate_engine (data_analysis_output_t *dao, gpointer specs,
 			 analysis_tool_engine_t selector, gpointer result)
 {
 	GnmConsolidate *cs = specs;
@@ -770,34 +750,34 @@ tool_consolidate_engine (data_analysis_output_t *dao, gpointer specs,
 	case TOOL_ENGINE_UPDATE_DESCRIPTOR:
 		return (dao_command_descriptor (dao, _("Consolidating to (%s)"),
 						result) == NULL);
-	case TOOL_ENGINE_UPDATE_DAO: 
+	case TOOL_ENGINE_UPDATE_DAO:
 	{
 		GnmRange r;
 
 		range_init (&r, 0, 0, 0, 0);
 		get_bounding_box (cs->src, &r);
-		
-		if ((cs->mode & CONSOLIDATE_ROW_LABELS) && 
+
+		if ((cs->mode & CONSOLIDATE_ROW_LABELS) &&
 		    (cs->mode & CONSOLIDATE_COL_LABELS))
-			dao_adjust (dao, r.end.col + 1 + 
+			dao_adjust (dao, r.end.col + 1 +
 				    ((cs->mode & CONSOLIDATE_COPY_LABELS) ?
-				     1 : 0), 
-				    r.end.row + 1 + 
+				     1 : 0),
+				    r.end.row + 1 +
 				    ((cs->mode & CONSOLIDATE_COPY_LABELS) ?
 				     1 : 0));
 		else if (cs->mode & CONSOLIDATE_ROW_LABELS)
-			dao_adjust (dao, r.end.col + 1, 
-				    r.end.row + 1 + 
+			dao_adjust (dao, r.end.col + 1,
+				    r.end.row + 1 +
 				    ((cs->mode & CONSOLIDATE_COPY_LABELS) ?
 				     1 : 0));
 
 		else if (cs->mode & CONSOLIDATE_COL_LABELS)
-			dao_adjust (dao, r.end.col + 1 + 
+			dao_adjust (dao, r.end.col + 1 +
 				    ((cs->mode & CONSOLIDATE_COPY_LABELS) ?
-				     1 : 0), 
+				     1 : 0),
 				    r.end.row + 1);
 		else
-			dao_adjust (dao, r.end.col + 1, 
+			dao_adjust (dao, r.end.col + 1,
 				    r.end.row + 1);
 		return FALSE;
 	}
