@@ -40,7 +40,7 @@
 #include <command-context.h>
 #include <workbook-control.h>
 #include <workbook.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <commands.h>
 #include <selection.h>
 #include <ranges.h>
@@ -78,7 +78,7 @@ demotable[PREVIEW_ROWS][PREVIEW_COLS] = {
 
 typedef struct {
 	Workbook           *wb;                              /* Workbook we are working on */
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	GladeXML	   *gui;
 	FooCanvasItem	   *grid[NUM_PREVIEWS];              /* Previewgrid's */
 	FooCanvasItem	   *selrect;                         /* Selection rectangle */
@@ -118,8 +118,6 @@ typedef struct {
 	} edges;
 
 	GtkButton      *ok, *cancel;
-
-	GtkTooltips    *tooltips;
 } AutoFormatState;
 
 /********************************************************************************/
@@ -351,9 +349,9 @@ previews_load (AutoFormatState *state, int topindex)
 			foo_canvas_scroll_to (state->canvas[i],
 				-BORDER, -BORDER);
 
-			gtk_tooltips_set_tip (state->tooltips,
-				GTK_WIDGET (state->canvas[i]),
-				_(ft->name), "");
+			go_widget_set_tooltip_text
+				(GTK_WIDGET (state->canvas[i]),
+				 _(ft->name));
 
 			gtk_widget_show (GTK_WIDGET (state->canvas[i]));
 			start = g_slist_next (start);
@@ -378,20 +376,10 @@ cb_ok_clicked (G_GNUC_UNUSED GtkButton *button,
 	gtk_widget_destroy (GTK_WIDGET (state->dialog));
 }
 
-static void
-cb_cancel_clicked (G_GNUC_UNUSED GtkButton *button,
-		   AutoFormatState *state)
-{
-	gtk_widget_destroy (GTK_WIDGET (state->dialog));
-}
-
 static void
 cb_autoformat_destroy (AutoFormatState *state)
 {
-	wbcg_edit_detach_guru (state->wbcg);
-
 	templates_free (state);
-	g_object_unref (G_OBJECT (state->tooltips));
 	category_group_list_free (state->category_groups);
 	g_object_unref (G_OBJECT (state->gui));
 	state->gui = NULL;
@@ -482,11 +470,11 @@ cb_category_changed (AutoFormatState *state)
 	if (templates_load (state) == FALSE)
 		g_warning ("Error while loading templates!");
 
-	gtk_tooltips_set_tip (state->tooltips, GTK_WIDGET (state->category),
-		_((state->current_category_group->description != NULL)
-			? state->current_category_group->description
-			: state->current_category_group->name),
-		"");
+	go_widget_set_tooltip_text
+		(GTK_WIDGET (state->category),
+		 _((state->current_category_group->description != NULL)
+		   ? state->current_category_group->description
+		   : state->current_category_group->name));
 
 	previews_load (state, 0);
 	cb_check_item_toggled (NULL, state);
@@ -544,7 +532,7 @@ cb_canvas_focus (GtkWidget *canvas, GtkDirectionType direction,
  * sheet of the workbook if the user desires.
  **/
 void
-dialog_autoformat (WorkbookControlGUI *wbcg)
+dialog_autoformat (WBCGtk *wbcg)
 {
 	GladeXML *gui;
 	AutoFormatState *state;
@@ -571,13 +559,6 @@ dialog_autoformat (WorkbookControlGUI *wbcg)
 	state->previews_locked   = FALSE;
 	state->more_down         = FALSE;
 	state->selected_template = NULL;
-	state->tooltips          = gtk_tooltips_new ();
-#if GLIB_CHECK_VERSION(2,10,0) && GTK_CHECK_VERSION(2,8,14)
-	g_object_ref_sink (state->tooltips);
-#else
-	g_object_ref (state->tooltips);
-	gtk_object_sink (GTK_OBJECT (state->tooltips));
-#endif
 
 	state->dialog     = GTK_DIALOG (glade_xml_get_widget (gui, "dialog"));
 	state->category   = GTK_COMBO_BOX (glade_xml_get_widget (gui, "format_category"));
@@ -634,9 +615,8 @@ dialog_autoformat (WorkbookControlGUI *wbcg)
 	g_signal_connect (G_OBJECT (state->ok),
 		"clicked",
 		G_CALLBACK (cb_ok_clicked), state);
-	g_signal_connect (G_OBJECT (state->cancel),
-		"clicked",
-		G_CALLBACK (cb_cancel_clicked), state);
+	g_signal_connect_swapped (G_OBJECT (state->cancel), "clicked",
+		G_CALLBACK (gtk_widget_destroy), state->dialog);
 
 	/* Fill category list */
 	state->category_groups =
@@ -687,11 +667,12 @@ dialog_autoformat (WorkbookControlGUI *wbcg)
 	gtk_dialog_set_default_response (state->dialog, GTK_RESPONSE_OK);
 
 	/* a candidate for merging into attach guru */
-	g_object_set_data_full (G_OBJECT (state->dialog),
-		"state", state, (GDestroyNotify)cb_autoformat_destroy);
 	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
 				   GTK_WINDOW (state->dialog));
-	wbcg_edit_attach_guru (state->wbcg, GTK_WIDGET (state->dialog));
+	wbc_gtk_attach_guru (state->wbcg, GTK_WIDGET (state->dialog));
+	g_object_set_data_full (G_OBJECT (state->dialog),
+		"state", state, (GDestroyNotify)cb_autoformat_destroy);
+
 	/* not show all or the scrollbars will appear */
 	gtk_widget_show (GTK_WIDGET (state->dialog));
 }
