@@ -34,7 +34,7 @@
 #include <workbook.h>
 #include <sheet.h>
 #include <sheet-view.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <workbook-control.h>
 #include <cell.h>
 #include <expr.h>
@@ -45,11 +45,7 @@
 #include <widgets/gnumeric-expr-entry.h>
 #include <widgets/gnumeric-cell-renderer-expr-entry.h>
 
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtktreestore.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktogglebutton.h>
+#include <gtk/gtk.h>
 #include <locale.h>
 #include <string.h>
 
@@ -61,7 +57,7 @@
 
 typedef struct
 {
-	WorkbookControlGUI  *wbcg;
+	WBCGtk  *wbcg;
 	Workbook  *wb;
 
 	GladeXML  *gui;
@@ -495,7 +491,6 @@ dialog_formula_guru_load_expr (GtkTreePath const *parent_path, gint child_num,
 static void
 cb_dialog_formula_guru_destroy (FormulaGuruState *state)
 {
-	wbcg_edit_detach_guru (state->wbcg);
 	wbcg_edit_finish (state->wbcg, WBC_EDIT_REJECT, NULL);
 
 	if (state->model != NULL)
@@ -895,11 +890,11 @@ dialog_formula_guru_init (FormulaGuruState *state)
 	gnumeric_init_help_button (
 		glade_xml_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_FORMULA_GURU);
+
+	wbc_gtk_attach_guru (state->wbcg, state->dialog);
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify) cb_dialog_formula_guru_destroy);
 
-	wbcg_edit_attach_guru (state->wbcg, state->dialog);
-
 	return FALSE;
 }
 
@@ -922,7 +917,7 @@ dialog_formula_guru_show (FormulaGuruState *state)
  * Pop up a function selector then a formula guru.
  */
 void
-dialog_formula_guru (WorkbookControlGUI *wbcg, GnmFunc const *fd)
+dialog_formula_guru (WBCGtk *wbcg, GnmFunc const *fd)
 {
 	SheetView *sv;
 	GladeXML  *gui;
