@@ -41,7 +41,7 @@
 #include <parse-util.h>
 #include <workbook.h>
 #include <workbook-control.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <workbook-view.h>
 #include <goal-seek.h>
 #include <mathfunc.h>
@@ -51,6 +51,9 @@
 #include <gtk/gtktable.h>
 
 #include <math.h>
+#include <string.h>
+
+static const gnm_float max_range_val = GNM_const(1e24);
 
 #define MAX_CELL_NAME_LEN  20
 #define GOALSEEK_KEY            "goal-seek-dialog"
@@ -73,7 +76,7 @@ typedef struct {
 	GtkWidget *result_table;
 	Sheet	  *sheet;
 	Workbook  *wb;
-	WorkbookControlGUI  *wbcg;
+	WBCGtk  *wbcg;
 	gnm_float target_value;
 	gnm_float xmin;
 	gnm_float xmax;
@@ -134,6 +137,7 @@ gnumeric_goal_seek (GoalSeekState *state)
 	evaldata.ycell = state->set_cell;
 	evaldata.ytarget = state->target_value;
 	evaldata.update_ui = FALSE;
+	evaldata.state = state;
 
 	hadold = !VALUE_IS_EMPTY_OR_ERROR (state->change_cell->value);
 	oldx = hadold ? value_get_as_float (state->change_cell->value) : 0;
@@ -142,7 +146,7 @@ gnumeric_goal_seek (GoalSeekState *state)
 	{
 		gnm_float x0;
 
-		if (hadold)
+		if (hadold && oldx >= seekdata.xmin && oldx <= seekdata.xmax)
 			x0 = oldx;
 		else
 			x0 = (seekdata.xmin + seekdata.xmax) / 2;
@@ -169,7 +173,7 @@ gnumeric_goal_seek (GoalSeekState *state)
 		gnm_float sigma, mu;
 		int i;
 
-		sigma = seekdata.xmax - seekdata.xmin;
+		sigma = MIN (seekdata.xmax - seekdata.xmin, 1e6);
 		mu = (seekdata.xmax + seekdata.xmin) / 2;
 
 		for (i = 0; i < 5; i++) {
@@ -187,7 +191,7 @@ gnumeric_goal_seek (GoalSeekState *state)
 		gnm_float sigma, mu;
 		int i;
 
-		sigma = seekdata.xmax - seekdata.xmin;
+		sigma = MIN (seekdata.xmax - seekdata.xmin, 1e6);
 		mu = seekdata.xmin;
 
 		for (i = 0; i < 5; i++) {
@@ -205,7 +209,7 @@ gnumeric_goal_seek (GoalSeekState *state)
 		gnm_float sigma, mu;
 		int i;
 
-		sigma = seekdata.xmax - seekdata.xmin;
+		sigma = MIN (seekdata.xmax - seekdata.xmin, 1e6);
 		mu = seekdata.xmax;
 
 		for (i = 0; i < 5; i++) {
@@ -256,21 +260,9 @@ gnumeric_goal_seek (GoalSeekState *state)
 	return status;
 }
 
-/**
- * dialog_destroy:
- * @window:
- * @focus_widget:
- * @state:
- *
- * Destroy the dialog and associated data structures.
- *
- **/
-static gboolean
-dialog_destroy (GtkObject *w, GoalSeekState  *state)
+static void
+cb_dialog_destroy (GoalSeekState *state)
 {
-	g_return_val_if_fail (w != NULL, FALSE);
-	g_return_val_if_fail (state != NULL, FALSE);
-
 	if (!state->cancelled 
 	    && state->old_value != NULL 
 	    && state->old_cell != NULL) {
@@ -279,25 +271,13 @@ dialog_destroy (GtkObject *w, GoalSeekState  *state)
 		state->old_value = NULL;
 	}
 
-	wbcg_edit_detach_guru (state->wbcg);
-
-	if (state->old_value != NULL) {
+	if (state->old_value != NULL)
 		value_release (state->old_value);
-		state->old_value = NULL;
-	}
-
-	if (state->gui != NULL) {
+	if (state->gui != NULL)
 		g_object_unref (G_OBJECT (state->gui));
-		state->gui = NULL;
-	}
 
 	wbcg_edit_finish (state->wbcg, WBC_EDIT_REJECT, NULL);
-
-	state->dialog = NULL;
-
 	g_free (state);
-
-	return FALSE;
 }
 
 static void
@@ -334,7 +314,6 @@ cb_dialog_apply_clicked (G_GNUC_UNUSED GtkWidget *button,
 {
 	char *status_str;
 	GoalSeekStatus status;
-  	gnm_float max_range_val = 1e24;
 	GnmValue *target;
 	GnmRangeRef const *r;
 	GOFormat *format;
@@ -437,7 +416,7 @@ cb_dialog_apply_clicked (G_GNUC_UNUSED GtkWidget *button,
 		GOFormat *format = go_format_general ();
 		GnmValue *error_value = value_new_float (state->target_value -
 						      value_get_as_float (state->set_cell->value));
-  		char *target_str = format_value (format, error_value, NULL, 0,
+  		char *target_str = format_value (format, error_value, NULL, -1,
 						 workbook_date_conv (state->wb));
 		gtk_label_set_text (GTK_LABEL (state->target_value_label), target_str);
 		g_free (target_str);
@@ -592,22 +571,80 @@ dialog_init (GoalSeekState *state)
 	gtk_widget_show (GTK_WIDGET (state->change_cell_entry));
 
 
-	wbcg_edit_attach_guru (state->wbcg, state->dialog);
 	g_signal_connect (G_OBJECT (state->dialog),
 		"realize",
 		G_CALLBACK (dialog_realized), state);
-	g_signal_connect (G_OBJECT (state->dialog),
-		"destroy",
-		G_CALLBACK (dialog_destroy), state);
 
 	state->old_value = NULL;
 	state->old_cell = NULL;
 
+	wbc_gtk_attach_guru (state->wbcg, state->dialog);
+	g_object_set_data_full (G_OBJECT (state->dialog),
+		"state", state, (GDestroyNotify) cb_dialog_destroy);
+
 	gnm_expr_entry_grab_focus (state->set_cell_entry, FALSE);
 
 	return FALSE;
 }
 
+/*
+ * We need a horizontal strip of 5 cells containing:
+ *
+ * 0. Formula cell.
+ * 1: X value cell.
+ * 2: Y target value.
+ * 3: Min value.
+ * 4: Max value.
+ */
+static void
+dialog_goal_seek_test (Sheet *sheet, const GnmRange *range)
+{
+	GoalSeekState state;
+	GnmCell *cell;
+	int r, c;
+	GoalSeekStatus status;
+
+	g_return_if_fail (range->start.row == range->end.row);
+	g_return_if_fail (range->start.col + 4 == range->end.col);
+
+	memset (&state, 0, sizeof (state));
+	r = range->start.row;
+	c = range->start.col;
+
+	state.wb = sheet->workbook;
+	state.sheet = sheet;
+
+	state.set_cell = sheet_cell_fetch (sheet, c + 0, r);
+	state.change_cell = sheet_cell_fetch (sheet, c + 1, r);
+	state.old_value = state.change_cell->value
+		? value_dup (state.change_cell->value)
+		: NULL;
+
+	cell = sheet_cell_fetch (sheet, c + 2, r);
+	state.target_value = value_get_as_float (cell->value);
+
+	cell = sheet_cell_fetch (sheet, c + 3, r);
+	state.xmin = VALUE_IS_EMPTY (cell->value)
+		? -max_range_val
+		: value_get_as_float (cell->value);
+
+	cell = sheet_cell_fetch (sheet, c + 4, r);
+	state.xmax = VALUE_IS_EMPTY (cell->value)
+		? max_range_val
+		: value_get_as_float (cell->value);
+
+	status = gnumeric_goal_seek (&state);
+	if (status == GOAL_SEEK_OK) {
+		/* Nothing */
+	} else {
+		sheet_cell_set_value (state.change_cell,
+				      value_new_error_VALUE (NULL));
+	}
+
+	if (state.old_value)
+		value_release (state.old_value);
+}
+
 /**
  * dialog_goal_seek:
  * @wbcg:
@@ -617,11 +654,33 @@ dialog_init (GoalSeekState *state)
  *
  **/
 void
-dialog_goal_seek (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_goal_seek (WBCGtk *wbcg, Sheet *sheet)
 {
         GoalSeekState *state;
 	GladeXML *gui;
 
+	g_return_if_fail (IS_SHEET (sheet));
+
+	/* Testing hook.  */
+	if (wbcg == NULL) {
+		GnmRangeRef *range =
+			g_object_get_data (G_OBJECT (sheet), "ssconvert-goal-seek");
+		if (range) {
+			Sheet *start_sheet, *end_sheet;
+			GnmEvalPos ep;
+			GnmRange r;
+
+			gnm_rangeref_normalize (range,
+						eval_pos_init_sheet (&ep, sheet),
+						&start_sheet, &end_sheet,
+						&r);
+			g_return_if_fail (start_sheet == sheet);
+
+			dialog_goal_seek_test (sheet, &r);
+			return;
+		}
+	}
+
 	g_return_if_fail (wbcg != NULL);
 
 	/* Only pop up one copy per workbook */
@@ -651,6 +710,4 @@ dialog_goal_seek (WorkbookControlGUI *wbcg, Sheet *sheet)
 			       GOALSEEK_KEY);
 
 	gtk_widget_show (state->dialog);
-
-        return;
 }
