@@ -21,7 +21,7 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -33,7 +33,7 @@
 #include <sheet-view.h>
 #include <workbook.h>
 #include <workbook-control.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <workbook-view.h>
 #include <gui-util.h>
 #include <parse-util.h>
@@ -60,7 +60,7 @@ typedef struct {
 	GtkListStore		*model;
 	GtkTreeSelection	*selection;
 
-	WorkbookControlGUI	*wbcg;
+	WBCGtk	*wbcg;
 } DialogPasteNames;
 
 static void
@@ -69,7 +69,6 @@ dialog_paste_names_free (DialogPasteNames *state)
 	WorkbookControl *wbc = WORKBOOK_CONTROL (state->wbcg);
 
 	wb_view_selection_desc (wb_control_view (wbc), TRUE, wbc);
-	wbcg_edit_detach_guru (state->wbcg);
 	if (state->gui != NULL) {
 		g_object_unref (G_OBJECT (state->gui));
 		state->gui = NULL;
@@ -83,7 +82,7 @@ dialog_paste_names_free (DialogPasteNames *state)
 }
 
 static gboolean
-paste_names_init (DialogPasteNames *state, WorkbookControlGUI *wbcg)
+paste_names_init (DialogPasteNames *state, WBCGtk *wbcg)
 {
 	GtkTreeViewColumn *column;
 
@@ -118,21 +117,21 @@ paste_names_init (DialogPasteNames *state, WorkbookControlGUI *wbcg)
 		"state", state, (GDestroyNotify)dialog_paste_names_free);
 	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
 		GTK_WINDOW (state->dialog));
-	wbcg_edit_attach_guru (state->wbcg, state->dialog);
+	wbc_gtk_attach_guru (state->wbcg, state->dialog);
 	gtk_widget_show_all (GTK_WIDGET (state->dialog));
 
 	return FALSE;
 }
 
 void
-dialog_paste_names (WorkbookControlGUI *wbcg)
+dialog_paste_names (WBCGtk *wbcg)
 {
 	DialogPasteNames *state;
 
 	g_return_if_fail (wbcg != NULL);
 
 	/* Only one guru per workbook. */
-	if (wbcg_edit_get_guru (wbcg))
+	if (wbc_gtk_get_guru (wbcg))
 		return;
 
 	/* Only pop up one copy per workbook */
