@@ -36,7 +36,7 @@
 #include <ranges.h>
 #include <sheet.h>
 #include <workbook.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <style.h>
 #include <gnumeric-gconf.h>
 
@@ -119,7 +119,7 @@ typedef struct {
 } UnitInfo;
 
 struct _PrinterSetupState {
-	WorkbookControlGUI  *wbcg;
+	WBCGtk  *wbcg;
 	Sheet            *sheet;
 	GladeXML         *gui;
 	PrintInformation *pi;
@@ -1095,7 +1095,7 @@ do_hf_customize (gboolean header, PrinterSetupState *state)
 	/* Let them begin typing into the first entry widget. */
 	gtk_widget_grab_focus (GTK_WIDGET (left));
 
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (state->dialog));
+	go_gtk_window_set_transient (GTK_WINDOW (dialog), GTK_WINDOW (state->dialog));
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
 	gtk_widget_show (dialog);
@@ -1672,7 +1672,8 @@ cb_do_print_preview (PrinterSetupState *state)
 	fetch_settings (state);
 	old_pi = state->sheet->print_info;
 	state->sheet->print_info = state->pi;
-	gnm_print_sheet (state->wbcg, state->sheet, TRUE, PRINT_ACTIVE_SHEET, NULL);
+	gnm_print_sheet (WORKBOOK_CONTROL (state->wbcg),
+		state->sheet, TRUE, PRINT_ACTIVE_SHEET, NULL);
 	state->sheet->print_info = old_pi;
 }
 
@@ -1685,9 +1686,6 @@ cb_do_print_cancel (PrinterSetupState *state)
 static void
 cb_do_print_ok (PrinterSetupState *state)
 {
-	/* Detach BEFORE we finish editing */
-	wbcg_edit_detach_guru (state->wbcg);
-	wbcg_edit_finish (state->wbcg, WBC_EDIT_ACCEPT, NULL);
 	fetch_settings (state);
 	if (gtk_toggle_button_get_active (
 		    GTK_TOGGLE_BUTTON (
@@ -1703,20 +1701,14 @@ cb_do_print_ok (PrinterSetupState *state)
 static void
 cb_do_print (PrinterSetupState *state)
 {
-	WorkbookControlGUI *wbcg = state->wbcg;
-	Sheet *sheet = state->sheet;
-
 	cb_do_print_ok (state);
-
-	gnm_print_sheet (wbcg, sheet, FALSE, PRINT_ACTIVE_SHEET, NULL);
+	gnm_print_sheet (WORKBOOK_CONTROL (state->wbcg),
+		state->sheet, FALSE, PRINT_ACTIVE_SHEET, NULL);
 }
 
 static void
 cb_do_print_destroy (PrinterSetupState *state)
 {
-	wbcg_edit_detach_guru (state->wbcg);
-	wbcg_edit_finish (state->wbcg, WBC_EDIT_REJECT, NULL);
-
 /* 	if (state->customize_header) */
 /* 		gtk_widget_destroy (state->customize_header); */
 
@@ -1817,14 +1809,11 @@ do_setup_main_dialog (PrinterSetupState *state)
 	
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify) cb_do_print_destroy);
-	wbcg_edit_attach_guru (state->wbcg, state->dialog);
-
+	wbc_gtk_attach_guru (state->wbcg, state->dialog);
 }
 
-
-
 static PrinterSetupState *
-printer_setup_state_new (WorkbookControlGUI *wbcg, Sheet *sheet)
+printer_setup_state_new (WBCGtk *wbcg, Sheet *sheet)
 {
 	PrinterSetupState *state;
 	GladeXML *gui;
@@ -1919,13 +1908,6 @@ do_fetch_scale (PrinterSetupState *state)
 	}
 }
 
-static double
-get_margin (UnitInfo *ui)
-{
-	return ui->value;
-}
-
-
 /**
  * Header and footer are stored with Excel semantics, but displayed with
  * more natural semantics. In Excel, both top margin and header are measured
@@ -2037,12 +2019,12 @@ dialog_gtk_printer_setup_cb (PrinterSetupState *state)
 
 
 void
-dialog_printer_setup (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_printer_setup (WBCGtk *wbcg, Sheet *sheet)
 {
 	PrinterSetupState *state;
 
 	/* Only one guru per workbook. */
-	if (wbcg_edit_get_guru (wbcg))
+	if (wbc_gtk_get_guru (wbcg))
 		return;
 
 	/* Only pop up one copy per workbook */
