@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-search.c:
  *   Dialog for entering a search query.
@@ -36,7 +37,7 @@
 #include <cell.h>
 #include <value.h>
 #include <parse-util.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <sheet-object-cell-comment.h>
 #include <selection.h>
 
@@ -60,7 +61,7 @@ enum {
 };
 
 typedef struct {
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 
 	GladeXML *gui;
 	GtkDialog *dialog;
@@ -233,22 +234,6 @@ range_focused (G_GNUC_UNUSED GtkWidget *widget,
 	return FALSE;
 }
 
-static void
-dialog_destroy (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
-{
-#ifdef USE_GURU
-	wbcg_edit_detach_guru (dd->wbcg);
-#endif
-	free_state (dd);
-}
-
-static void
-close_clicked (G_GNUC_UNUSED GObject *dummy, DialogState *dd)
-{
-	GtkDialog *dialog = dd->dialog;
-	gtk_widget_destroy (GTK_WIDGET (dialog));
-}
-
 static gboolean
 is_checked (GladeXML *gui, const char *name)
 {
@@ -298,21 +283,24 @@ static void
 search_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 {
 	GladeXML *gui = dd->gui;
-	WorkbookControlGUI *wbcg = dd->wbcg;
+	WBCGtk *wbcg = dd->wbcg;
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	GnmSearchReplace *sr;
 	char *err;
 	int i;
 	GnmSearchReplaceScope scope;
+	char *text;
 
 	i = gnumeric_glade_group_value (gui, scope_group);
 	scope = (i == -1) ? GNM_SRS_SHEET : (GnmSearchReplaceScope)i;
 
+	text = g_utf8_normalize (gtk_entry_get_text (dd->gentry), -1, G_NORMALIZE_DEFAULT);
+
 	sr = g_object_new (GNM_SEARCH_REPLACE_TYPE,
 			   "sheet", wb_control_cur_sheet (wbc),
 			   "scope", scope,
 			   "range-text", gnm_expr_entry_get_text (dd->rangetext),
-			   "search-text", gtk_entry_get_text (dd->gentry),
+			   "search-text", text,
 			   "is-regexp", gnumeric_glade_group_value (gui, search_type_group) == 1,
 			   "ignore-case", is_checked (gui, "ignore_case"),
 			   "match-words", is_checked (gui, "match_words"),
@@ -324,6 +312,8 @@ search_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 			   "by-row", gnumeric_glade_group_value (gui, direction_group) == 0,
 			   NULL);
 
+	g_free (text);
+
 	err = gnm_search_replace_verify (sr, FALSE);
 	if (err) {
 		go_gtk_notice_dialog (GTK_WINDOW (dd->dialog),
@@ -451,7 +441,7 @@ make_matches_table (DialogState *dd)
 }
 
 void
-dialog_search (WorkbookControlGUI *wbcg)
+dialog_search (WBCGtk *wbcg)
 {
 	GladeXML *gui;
 	GtkDialog *dialog;
@@ -462,7 +452,7 @@ dialog_search (WorkbookControlGUI *wbcg)
 
 #ifdef USE_GURU
 	/* Only one guru per workbook. */
-	if (wbcg_edit_get_guru (wbcg))
+	if (wbc_gtk_get_guru (wbcg))
 		return;
 #endif
 
@@ -529,46 +519,34 @@ dialog_search (WorkbookControlGUI *wbcg)
 	/* Set sensitivity of buttons.  */
 	cursor_change (dd->matches_table, dd);
 
-	g_signal_connect (G_OBJECT (dd->matches_table),
-		"cursor_changed",
+	g_signal_connect (G_OBJECT (dd->matches_table), "cursor_changed",
 		G_CALLBACK (cursor_change), dd);
-	g_signal_connect (G_OBJECT (dd->matches_table),
-			  "select_cursor_row",
-			  G_CALLBACK (cb_next),
-			  dd);
-	g_signal_connect (G_OBJECT (glade_xml_get_widget (gui, "search_button")),
-		"clicked",
+	g_signal_connect (G_OBJECT (dd->matches_table), "select_cursor_row",
+		G_CALLBACK (cb_next), dd);
+	go_glade_signal_connect (gui, "search_button", "clicked",
 		G_CALLBACK (search_clicked), dd);
-	g_signal_connect (G_OBJECT (dd->prev_button),
-		"clicked",
+	g_signal_connect (G_OBJECT (dd->prev_button), "clicked",
 		G_CALLBACK (prev_clicked), dd);
-	g_signal_connect (G_OBJECT (dd->next_button),
-		"clicked",
+	g_signal_connect (G_OBJECT (dd->next_button), "clicked",
 		G_CALLBACK (next_clicked), dd);
-	g_signal_connect (G_OBJECT (glade_xml_get_widget (gui, "close_button")),
-		"clicked",
-		G_CALLBACK (close_clicked), dd);
-	g_signal_connect (G_OBJECT (dialog),
-		"destroy",
-		G_CALLBACK (dialog_destroy), dd);
-	g_signal_connect (G_OBJECT (gnm_expr_entry_get_entry (dd->rangetext)),
-		"focus-in-event",
+	go_glade_signal_connect_swapped (gui, "close_button", "clicked",
+		G_CALLBACK (gtk_widget_destroy), dd->dialog);
+	g_signal_connect (G_OBJECT (gnm_expr_entry_get_entry (dd->rangetext)), "focus-in-event",
 		G_CALLBACK (range_focused), dd);
-	g_signal_connect (G_OBJECT (glade_xml_get_widget (gui, "scope_range")),
-		"toggled",
+	go_glade_signal_connect (gui, "scope_range", "toggled",
 		G_CALLBACK (cb_focus_on_entry), dd->rangetext);
 
+#ifdef USE_GURU
+	wbc_gtk_attach_guru_with_unfocused_rs (wbcg, GTK_WIDGET (dialog), dd->rangetext);
+#endif
+	g_object_set_data_full (G_OBJECT (dialog),
+		"state", dd, (GDestroyNotify) free_state);
 	gnm_dialog_setup_destroy_handlers (dialog, wbcg,
-					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
-
+		GNM_DIALOG_DESTROY_SHEET_REMOVED);
 	gnumeric_init_help_button (
 		glade_xml_get_widget (gui, "help_button"),
 		GNUMERIC_HELP_LINK_SEARCH);
 
-#ifdef USE_GURU
-	wbcg_edit_attach_guru_with_unfocused_rs (wbcg, GTK_WIDGET (dialog), dd->rangetext);
-#endif
-
 	go_gtk_nonmodal_dialog (wbcg_toplevel (wbcg), GTK_WINDOW (dialog));
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 }
