@@ -20,13 +20,14 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "dialog-stf.h"
 #include <gui-util.h>
 #include <workbook.h>
 #include <gtk/gtkframe.h>
 #include <goffice/utils/go-glib-extras.h>
+#include <string.h>
 
 /*************************************************************************************************
  * MISC UTILITY FUNCTIONS
@@ -156,7 +157,9 @@ main_page_import_range_changed (StfDialogData *data)
 	data->cur = stf_parse_find_line (data->parseoptions, data->utf8_data, startrow - 1);
 	data->cur_end = stf_parse_find_line (data->parseoptions, data->utf8_data, stoprow);
 
-	linescaption = g_strdup_printf (_("%d of %d lines to import"),
+	linescaption = g_strdup_printf (ngettext("%d of %d line to import",
+						 "%d of %d lines to import",
+						 renderdata->lines->len),
 					(stoprow - startrow) + 1,
 					renderdata->lines->len);
 	gtk_label_set_text (data->main.main_lines, linescaption);
