@@ -18,9 +18,7 @@
 
 #include <gui-gnumeric.h>
 #include <stf.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktooltips.h>
+#include <gtk/gtk.h>
 
 #define LINE_DISPLAY_LIMIT 500
 #define COLUMN_CAPTION N_("Column %d")
@@ -30,7 +28,6 @@ typedef struct {
 	GStringChunk     *lines_chunk;
 	GPtrArray        *lines;
 	GtkTreeView      *tree_view;
-	GtkTooltips      *tooltips;
 
 	int              colcount;
 	int              startrow;        /* Row at which to start rendering */
