@@ -56,10 +56,10 @@ static GnmFuncHelp const help_sum[] = {
 };
 
 GnmValue *
-gnumeric_sum (FunctionEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
+gnumeric_sum (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 {
 	return float_range_function (argc, argv, ei,
-				     range_sum,
+				     gnm_range_sum,
 				     COLLECT_IGNORE_STRINGS |
 				     COLLECT_IGNORE_BOOLS |
 				     COLLECT_IGNORE_BLANKS,
@@ -93,11 +93,11 @@ range_bogusproduct (gnm_float const *xs, int n, gnm_float *res)
 		*res = 0;  /* Severe Excel brain damange.  */
 		return 0;
 	} else
-		return range_product (xs, n, res);
+		return gnm_range_product (xs, n, res);
 }
 
 GnmValue *
-gnumeric_product (FunctionEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
+gnumeric_product (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 {
 	return float_range_function (argc, argv, ei,
 				     range_bogusproduct,
@@ -125,7 +125,7 @@ static GnmFuncHelp const help_gnumeric_version[] = {
 };
 
 static GnmValue *
-gnumeric_version (FunctionEvalInfo *ei, GnmValue const * const *argv)
+gnumeric_version (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
 	return value_new_string (GNUMERIC_VERSION);
 }
@@ -133,12 +133,12 @@ gnumeric_version (FunctionEvalInfo *ei, GnmValue const * const *argv)
 /***************************************************************************/
 
 static DependentFlags
-gnumeric_table_link (FunctionEvalInfo *ei)
+gnumeric_table_link (GnmFuncEvalInfo *ei)
 {
 	GnmDependent *dep = ei->pos->dep;
 	GnmRangeRef rr;
 
-	rr.a.col_relative = rr.a.row_relative = 
+	rr.a.col_relative = rr.a.row_relative =
 	rr.b.col_relative = rr.b.row_relative = FALSE;
 	rr.a.sheet = rr.b.sheet = dep->sheet;
 
@@ -160,7 +160,7 @@ gnumeric_table_link (FunctionEvalInfo *ei)
 }
 
 static GnmValue *
-gnumeric_table (FunctionEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
+gnumeric_table (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 {
 	GnmExpr const *arg;
 	GnmCell       *in[3], *x_iter, *y_iter;
@@ -171,9 +171,9 @@ gnumeric_table (FunctionEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 	/* evaluation clears the dynamic deps */
 	gnumeric_table_link (ei);
 
-	/* FIXME: This looks b-o-g-u-s!  */
-	if (argc != 2 &&
-	    ei->pos->eval.col > 0 && ei->pos->eval.row > 0)
+	if (argc != 2 ||
+	    ei->pos->eval.col < 1 ||
+	    ei->pos->eval.row < 1)
 		return value_new_error_REF (ei->pos);
 
 	for (x = 0; x < 2 ; x++) {
@@ -193,7 +193,7 @@ gnumeric_table (FunctionEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 
 	val[2] = NULL;
 	if (NULL != in[0] && NULL != in[1]) {
-		in[2] = sheet_cell_get (ei->pos->sheet, 
+		in[2] = sheet_cell_get (ei->pos->sheet,
 			ei->pos->eval.col - 1, ei->pos->eval.row - 1);
 		if (NULL == in[2])
 			in[2] = sheet_cell_fetch (ei->pos->sheet,
@@ -210,7 +210,7 @@ gnumeric_table (FunctionEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 		if (NULL == x_iter)
 			continue;
 		if (NULL != in[0]) {
-			cell_eval (x_iter);
+			gnm_cell_eval (x_iter);
 			in[0]->value = value_dup (x_iter->value);
 			dependent_queue_recalc (&in[0]->base);
 		}
@@ -219,18 +219,18 @@ gnumeric_table (FunctionEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 				ei->pos->eval.col-1, y + ei->pos->eval.row);
 			if (NULL == y_iter)
 				continue;
-			cell_eval (y_iter);
+			gnm_cell_eval (y_iter);
 			if (NULL != in[1]) {
 				in[1]->value = value_dup (y_iter->value);
 				dependent_queue_recalc (&in[1]->base);
 				if (NULL != in[0]) {
-					cell_eval (in[2]);
+					gnm_cell_eval (in[2]);
 					value_array_set (res, x, y, value_dup (in[2]->value));
-					value_release (in[1]->value);
 				} else {
-					cell_eval (x_iter);
+					gnm_cell_eval (x_iter);
 					value_array_set (res, x, y, value_dup (x_iter->value));
 				}
+				value_release (in[1]->value);
 			} else
 				value_array_set (res, x, y, value_dup (y_iter->value));
 		}
@@ -249,7 +249,7 @@ gnumeric_table (FunctionEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 		}
 	for (x = 0 ; x < 3 ; x++)
 		if (in[x])
-			cell_eval (in[x]);
+			gnm_cell_eval (in[x]);
 
 	return res;
 }
@@ -275,8 +275,8 @@ func_builtin_init (void)
 			GNM_FUNC_TEST_STATUS_BASIC
 		},
 		{	"gnumeric_version",	"",	"",
-			help_gnumeric_version,	gnumeric_version,
-			NULL, NULL, NULL, NULL, GNM_FUNC_SIMPLE,
+			help_gnumeric_version,	gnumeric_version, NULL,
+			NULL, NULL, NULL, GNM_FUNC_SIMPLE,
 			GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 			GNM_FUNC_TEST_STATUS_EXHAUSTIVE
 		},
