@@ -2,7 +2,7 @@
 /* format.c - attempts to emulate excel's number formatting ability.
  *
  * Copyright (C) 1998 Chris Lahey, Miguel de Icaza
- * Copyright (C) 2006 Morten Welinder (terra@gnome.org)
+ * Copyright (C) 2006-2007 Morten Welinder (terra@gnome.org)
  *
  * Redid the format parsing routine to make it accept more of the Excel
  * formats.  The number rendeing code from Chris has not been touched,
@@ -32,7 +32,6 @@
 #include <goffice/utils/go-locale.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
-#include <stdio.h>
 #include <style-font.h>
 
 static char const *
@@ -64,7 +63,8 @@ static void
 hash_fill (PangoLayout *layout, GString *str, const GOFontMetrics *metrics, int col_width)
 {
 	if (col_width <= 0) {
-		if (layout) pango_layout_set_text (layout, "", -1);
+		g_string_truncate (str, 0);
+		if (layout) pango_layout_set_text (layout, str->str, -1);
 	} else {
 		int l = metrics->hash_width > 0
 			? col_width / metrics->hash_width
@@ -95,6 +95,8 @@ format_value_common (PangoLayout *layout, GString *str,
 
 	if (format == NULL)
 		format = VALUE_FMT (value);
+	if (format && go_format_is_markup (format))
+		format = NULL;
 
 	/* Use top left corner of an array result.  This will not work for
 	 * ranges because we dont't have a location */
@@ -203,15 +205,14 @@ format_value (GOFormat const *format, GnmValue const *value, GOColor *go_color,
 	return g_string_free (result, FALSE);
 }
 
-int
-gnm_format_is_date_for_value (GOFormat const *fmt,
-			      GnmValue const *value)
+GOFormat const *
+gnm_format_specialize (GOFormat const *fmt, GnmValue const *value)
 {
 	char type;
 	gnm_float val;
 
-	g_return_val_if_fail (fmt != NULL, -1);
-	g_return_val_if_fail (value != NULL, -1);
+	g_return_val_if_fail (fmt != NULL, go_format_general ());
+	g_return_val_if_fail (value != NULL, fmt);
 
 	if (VALUE_IS_FLOAT (value)) {
 		val = value_get_as_float (value);
@@ -222,11 +223,43 @@ gnm_format_is_date_for_value (GOFormat const *fmt,
 		type = VALUE_IS_ERROR (value) ? 'E' : 'S';
 	}
 
-	return
 #ifdef WITH_LONG_DOUBLE
-		go_format_is_date_for_valuel
+	return go_format_specializel (fmt, val, type, NULL);
 #else
-		go_format_is_date_for_value
+	return go_format_specialize (fmt, val, type, NULL);
 #endif
-		(fmt, val, type);
+}
+
+int
+gnm_format_is_date_for_value (GOFormat const *fmt,
+			      GnmValue const *value)
+{
+	fmt = gnm_format_specialize (fmt, value);
+	return go_format_is_date (fmt);
+}
+
+gboolean
+gnm_format_month_before_day (GOFormat const *fmt,
+			     GnmValue const *value)
+{
+	int mbd;
+
+	if (value)
+		fmt = gnm_format_specialize (fmt, value);
+
+	mbd = go_format_month_before_day (fmt);
+	if (mbd < 0)
+		mbd = go_locale_month_before_day ();
+
+	return mbd != 0;
+}
+
+gboolean
+gnm_format_has_hour (GOFormat const *fmt,
+		     GnmValue const *value)
+{
+	if (value)
+		fmt = gnm_format_specialize (fmt, value);
+
+	return go_format_has_hour (fmt);
 }
