@@ -81,7 +81,7 @@ static GtkTargetEntry const drag_types_out[] = {
 static gboolean
 gnm_pane_guru_key (WBCGtk const *wbcg, GdkEventKey *event)
 {
-	GtkWidget *entry, *guru = wbcg_edit_get_guru (wbcg);
+	GtkWidget *entry, *guru = wbc_gtk_get_guru (wbcg);
 
 	if (guru == NULL)
 		return FALSE;
@@ -263,7 +263,7 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 			if (NULL != so) {
 				SheetObjectView	*sov = sheet_object_get_view (so,
 					(SheetObjectViewContainer *)pane);
-				gnm_cell_combo_foo_view_popdown (sov);
+				gnm_cell_combo_foo_view_popdown (sov, event->time);
 				break;
 			}
 	}
@@ -566,7 +566,7 @@ gnm_pane_key_press (GtkWidget *widget, GdkEventKey *event)
 
 	/* Object manipulation */
 	if ((scg->selected_objects != NULL || scg->new_object != NULL)) {
-		if (wbcg_edit_get_guru (scg->wbcg) == NULL  &&
+		if (wbc_gtk_get_guru (scg->wbcg) == NULL  &&
 		    gnm_pane_object_key_press (pane, event))
 			return TRUE;
 	}
@@ -715,7 +715,7 @@ gnm_pane_dispose (GObject *obj)
 	 * unexpectedly.  */
 	pane->grid = NULL;
 	pane->editor = NULL;
-	pane->cursor.std = pane->cursor.rangesel = pane->cursor.special = pane->cursor.rangehighlight = NULL;
+	pane->cursor.std = pane->cursor.rangesel = pane->cursor.special = pane->cursor.expr_range = NULL;
 	pane->size_guide.guide = NULL;
 	pane->size_guide.start = NULL;
 	pane->size_guide.points = NULL;
@@ -753,8 +753,8 @@ gnm_pane_class_init (GnmPaneClass *klass)
 static GtkEditable *
 gnm_pane_get_editable (GnmPane const *pane)
 {
-	GnmExprEntry *ee = wbcg_get_entry_logical (pane->simple.scg->wbcg);
-	GtkEntry *entry = gnm_expr_entry_get_entry (ee);
+	GnmExprEntry *gee = wbcg_get_entry_logical (pane->simple.scg->wbcg);
+	GtkEntry *entry = gnm_expr_entry_get_entry (gee);
 	return GTK_EDITABLE (entry);
 }
 
@@ -906,7 +906,7 @@ gnm_pane_init (GnmPane *pane)
 	pane->mouse_cursor = NULL;
 	pane->cursor.rangesel = NULL;
 	pane->cursor.special = NULL;
-	pane->cursor.rangehighlight = NULL;
+	pane->cursor.expr_range = NULL;
 	pane->cursor.animated = NULL;
 	pane->size_tip = NULL;
 
@@ -1045,8 +1045,8 @@ cb_pane_drag_motion (GtkWidget *widget, GdkDragContext *context,
 			NULL, NULL, &mask);
 		gnm_pane_objects_drag (GNM_PANE (source_widget), NULL,
 			wx, wy, 8, FALSE, (mask & GDK_SHIFT_MASK) != 0);
-		gdk_drag_status (context, 
-				 (mask & GDK_CONTROL_MASK) != 0 ? GDK_ACTION_COPY : GDK_ACTION_MOVE, 
+		gdk_drag_status (context,
+				 (mask & GDK_CONTROL_MASK) != 0 ? GDK_ACTION_COPY : GDK_ACTION_MOVE,
 				 time);
 	}
 	return TRUE;
@@ -1077,7 +1077,7 @@ cb_pane_drag_leave (GtkWidget *widget, GdkDragContext *context,
 	GtkWidget *source_widget = gtk_drag_get_source_widget (context);
 	GnmPane *source_pane;
 	WBCGtk *wbcg;
-  
+
 	if (!source_widget || !IS_GNM_PANE (source_widget)) return;
 
 	source_pane = GNM_PANE (source_widget);
@@ -2123,8 +2123,8 @@ gnm_pane_reposition_cursors (GnmPane *pane)
 		item_cursor_reposition (pane->cursor.rangesel);
 	if (NULL != pane->cursor.special)
 		item_cursor_reposition (pane->cursor.special);
-	if (NULL != pane->cursor.rangehighlight)
-		item_cursor_reposition (ITEM_CURSOR (pane->cursor.rangehighlight));
+	if (NULL != pane->cursor.expr_range)
+		item_cursor_reposition (ITEM_CURSOR (pane->cursor.expr_range));
 	for (l = pane->cursor.animated; l; l = l->next)
 		item_cursor_reposition (ITEM_CURSOR (l->data));
 
@@ -2152,15 +2152,16 @@ gnm_pane_rangesel_start (GnmPane *pane, GnmRange const *r)
 {
 	FooCanvasItem *item;
 	SheetControlGUI *scg = pane->simple.scg;
+	GnmExprEntry *gee = wbcg_get_entry_logical (pane->simple.scg->wbcg);
 
 	g_return_if_fail (pane->cursor.rangesel == NULL);
 
 	/* Hide the primary cursor while the range selection cursor is visible
-	 * and we are selecting on a different sheet than the expr being edited
-	 */
+	 * and we are selecting on a different sheet than the expr being edited */
 	if (scg_sheet (scg) != wb_control_cur_sheet (scg_wbc (scg)))
 		item_cursor_set_visibility (pane->cursor.std, FALSE);
-
+	if (NULL != gee)
+		gnm_expr_entry_disable_highlight (gee);
 	item = foo_canvas_item_new (pane->grid_items,
 		item_cursor_get_type (),
 		"SheetControlGUI", scg,
@@ -2168,24 +2169,19 @@ gnm_pane_rangesel_start (GnmPane *pane, GnmRange const *r)
 		NULL);
 	pane->cursor.rangesel = ITEM_CURSOR (item);
 	item_cursor_bound_set (pane->cursor.rangesel, r);
-
-	/* If we are selecting a range on a different sheet this may be NULL */
-	if (pane->editor)
-		item_edit_disable_highlight (ITEM_EDIT (pane->editor));
 }
 
 void
 gnm_pane_rangesel_stop (GnmPane *pane)
 {
-	g_return_if_fail (pane->cursor.rangesel != NULL);
+	GnmExprEntry *gee = wbcg_get_entry_logical (pane->simple.scg->wbcg);
+	if (NULL != gee)
+		gnm_expr_entry_enable_highlight (gee);
 
+	g_return_if_fail (pane->cursor.rangesel != NULL);
 	gtk_object_destroy (GTK_OBJECT (pane->cursor.rangesel));
 	pane->cursor.rangesel = NULL;
 
-	/* If we are selecting a range on a different sheet this may be NULL */
-	if (pane->editor)
-		item_edit_enable_highlight (ITEM_EDIT (pane->editor));
-
 	/* Make the primary cursor visible again */
 	item_cursor_set_visibility (pane->cursor.std, TRUE);
 
@@ -2237,6 +2233,32 @@ gnm_pane_mouse_cursor_set (GnmPane *pane, GdkCursor *c)
 
 /****************************************************************************/
 
+void
+gnm_pane_expr_cursor_bound_set (GnmPane *pane, GnmRange const *r)
+{
+	if (NULL == pane->cursor.expr_range)
+		pane->cursor.expr_range = ITEM_CURSOR (foo_canvas_item_new (
+			FOO_CANVAS_GROUP (FOO_CANVAS (pane)->root),
+			item_cursor_get_type (),
+			"SheetControlGUI",	pane->simple.scg,
+			"style",		ITEM_CURSOR_BLOCK,
+			"color",		"red",
+			NULL));
+
+	item_cursor_bound_set (pane->cursor.expr_range, r);
+}
+
+void
+gnm_pane_expr_cursor_stop (GnmPane *pane)
+{
+	if (NULL != pane->cursor.expr_range) {
+		gtk_object_destroy (GTK_OBJECT (pane->cursor.expr_range));
+		pane->cursor.expr_range = NULL;
+	}
+}
+
+/****************************************************************************/
+
 void
 gnm_pane_edit_start (GnmPane *pane)
 {
@@ -2539,7 +2561,7 @@ gnm_pane_drag_begin (GnmPane *pane, SheetObject *so, GdkEvent *event)
 			target_list_add_list (targets, im_targets);
 			gtk_target_list_unref (im_targets);
 		}
-	} 
+	}
 	if (imageable) {
 		im_targets = sheet_object_get_target_list (imageable);
 		if (im_targets != NULL) {
@@ -2602,7 +2624,7 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 	SheetObject *so;
 	int idx;
 
-	if (wbcg_edit_get_guru (scg_wbcg (scg)) != NULL)
+	if (wbc_gtk_get_guru (scg_wbcg (scg)) != NULL)
 		return FALSE;
 
 	so  = g_object_get_data (G_OBJECT (ctrl_pt), "so");
@@ -2684,7 +2706,7 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 		 * the semantics of the col,row args in the callback.  However,
 		 * that is more work than I want to do right now.
 		 */
-		if (idx == 8) 
+		if (idx == 8)
 			gnm_pane_drag_begin (pane, so, event);
 		else if (gnm_pane_handle_motion (GNM_PANE (ctrl_pt->canvas),
 						   ctrl_pt->canvas, &event->motion,
