@@ -155,9 +155,8 @@ sof_default_style (void)
 #ifdef WITH_GTK
 #include <sheet-control-gui.h>
 #include <dialogs/dialogs.h>
-#include <gnumeric-pane.h>
 #include <gnumeric-simple-canvas.h>
-#include <gnumeric-canvas.h>
+#include <gnm-pane.h>
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-rect-ellipse.h>
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-util.h>
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-text.h>
@@ -230,7 +229,7 @@ gnm_so_filled_new_view (SheetObject *so, SheetObjectViewContainer *container)
 {
 	GnmSOFilled *sof = GNM_SO_FILLED (so);
 	FooCanvasGroup *group = (FooCanvasGroup *) foo_canvas_item_new (
-		((GnmPane *)container)->gcanvas->object_views,
+		gnm_pane_object_group (GNM_PANE (container)),
 		so_filled_foo_view_get_type (),
 		NULL);
 
@@ -249,14 +248,12 @@ gnm_so_filled_new_view (SheetObject *so, SheetObjectViewContainer *container)
 
 static void
 gnm_so_filled_draw_cairo (SheetObject const *so, gpointer data,
-	double width, double height)
+			  double width, double height)
 {
-#ifdef GOFFICE_WITH_CAIRO
 	GnmSOFilled *sof = GNM_SO_FILLED (so);
 	cairo_t *cairo = (cairo_t*) data;
 	GogStyle const *style = sof->style;
 	cairo_pattern_t *pat = NULL;
-	gpointer obj = NULL;
 
 	cairo_new_path (cairo);
 	if (sof->is_oval) {
@@ -273,14 +270,12 @@ gnm_so_filled_draw_cairo (SheetObject const *so, gpointer data,
 		cairo_close_path (cairo);
 	}
 	/* Fill the shape */
-	pat = gog_style_create_cairo_pattern (style, width, height, &obj);
+	pat = gog_style_create_cairo_pattern (style, cairo);
 	if (pat) {
 		cairo_set_source (cairo, pat);
 		cairo_fill_preserve (cairo);
 		cairo_pattern_destroy (pat);
 	}
-	if (obj)
-		g_object_unref (G_OBJECT (obj));
 	/* Draw the line */
 	cairo_set_line_width (cairo, (style->outline.width)? style->outline.width: 1.);
 	cairo_set_source_rgba (cairo,
@@ -289,7 +284,6 @@ gnm_so_filled_draw_cairo (SheetObject const *so, gpointer data,
 		UINT_RGBA_G(style->outline.color),
 		UINT_RGBA_A(style->outline.color));
 	cairo_stroke (cairo);
-#endif
 }
 
 static gboolean
