@@ -34,6 +34,14 @@
 #include <string.h>
 #include <math.h>
 
+#define CXML2C(s) ((char const *)(s))
+
+static inline gboolean
+attr_eq (const xmlChar *a, const char *s)
+{
+	return !strcmp (CXML2C (a), s);
+}
+
 #define GNM_SO_POLYGON(o)       (G_TYPE_CHECK_INSTANCE_CAST ((o), GNM_SO_POLYGON_TYPE, GnmSOPolygon))
 #define GNM_SO_POLYGON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k),	GNM_SO_POLYGON_TYPE, GnmSOPolygonClass))
 
@@ -45,8 +53,7 @@ typedef struct {
 typedef SheetObjectClass GnmSOPolygonClass;
 
 #ifdef WITH_GTK
-#include "gnumeric-canvas.h"
-#include "gnumeric-pane.h"
+#include "gnm-pane.h"
 #include <goffice/cut-n-paste/foocanvas/foo-canvas.h>
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-polygon.h>
 static void
@@ -163,9 +170,9 @@ cb_gnm_so_polygon_style_changed (FooCanvasItem *view, GnmSOPolygon const *sop)
 static SheetObjectView *
 gnm_so_polygon_new_view (SheetObject *so, SheetObjectViewContainer *container)
 {
-	GnmCanvas *gcanvas = ((GnmPane *)container)->gcanvas;
 	GnmSOPolygon *sop = GNM_SO_POLYGON (so);
-	FooCanvasItem *item = foo_canvas_item_new (gcanvas->object_views,
+	FooCanvasItem *item = foo_canvas_item_new (
+		gnm_pane_object_group (GNM_PANE (container)),
 		so_polygon_foo_view_get_type (),
 		/* "join_style",	GDK_JOIN_ROUND, */
 		NULL);
@@ -179,23 +186,17 @@ gnm_so_polygon_new_view (SheetObject *so, SheetObjectViewContainer *container)
 static void
 gnm_so_polygon_user_config (SheetObject *so, SheetControl *sc)
 {
-	dialog_so_styled (scg_get_wbcg (SHEET_CONTROL_GUI (sc)), G_OBJECT (so),
+	dialog_so_styled (scg_wbcg (SHEET_CONTROL_GUI (sc)), G_OBJECT (so),
 		GNM_SO_POLYGON (so)->style, sop_default_style (),
 		_("Polygon Properties"));
 }
-static void
-gnm_so_polygon_print (SheetObject const *so, GnomePrintContext *gp_context,
-		      double base_x, double base_y)
-{
-}
+
 #endif /* WITH_GTK */
 
 static void
 gnm_so_polygon_draw_cairo (SheetObject const *so, gpointer data,
 	double width, double height)
 {
-#ifdef GOFFICE_WITH_CAIRO
-#endif
 }
 
 static gboolean
@@ -209,7 +210,7 @@ gnm_so_polygon_read_xml_dom (SheetObject *so, char const *typename,
 	g_array_set_size (sop->points, 0);
 	for (ptr = node->xmlChildrenNode; ptr != NULL ; ptr = ptr->next)
 		if (!xmlIsBlankNode (ptr) && ptr->name &&
-		    !strcmp (ptr->name, "Point") &&
+		    attr_eq (ptr->name, "Point") &&
 		    xml_node_get_double	(ptr, "x", vals + 0) &&
 		    xml_node_get_double	(ptr, "y", vals + 1))
 			g_array_append_vals (sop->points, vals, 2);
@@ -322,7 +323,6 @@ gnm_so_polygon_class_init (GObjectClass *gobject_class)
 #ifdef WITH_GTK
 	so_class->new_view		= gnm_so_polygon_new_view;
 	so_class->user_config		= gnm_so_polygon_user_config;
-	so_class->print			= gnm_so_polygon_print;
 #endif /* WITH_GTK */
 	so_class->draw_cairo	= gnm_so_polygon_draw_cairo;
 
