@@ -7,6 +7,9 @@
 #include <gnumeric.h>
 #include <glib-object.h>
 #include <print-info.h>
+#include <libgnumeric.h>
+#include <goffice/utils/go-geometry.h>
+#include <gtk/gtkprintsettings.h>
 
 typedef struct {
 	struct {
@@ -72,16 +75,19 @@ typedef struct {
 	double	         print_margin_top;
 	double       	 print_margin_bottom;
 	GtkUnit          desired_display;
-  
+
   /* Also acts as flag whether the print defaults are loaded  */
         GtkPrintSettings *print_settings;
         GtkPageSetup     *page_setup;
 
-	
+
 	float		 horizontal_dpi;
 	float		 vertical_dpi;
+
 	gboolean	 auto_complete;
+	GODirection	 enter_moves_dir;	/* Which way does hitting <Enter> go */
 	gboolean	 transition_keys;
+
 	gboolean	 live_scrolling;
 	GHashTable      *toolbars;
 	GHashTable      *toolbar_positions;
@@ -90,7 +96,7 @@ typedef struct {
 	gboolean         prefer_clipboard_selection;  /* As opposed to "primary".  */
 	gboolean	 latex_use_utf8;
 } GnmAppPrefs;
-extern GnmAppPrefs const *gnm_app_prefs;
+GNM_VAR_DECL GnmAppPrefs const *gnm_app_prefs;
 
 typedef struct _GOConfNode GOConfNode;
 
@@ -98,12 +104,6 @@ void     gnm_conf_init (gboolean fast);
 void     gnm_conf_shutdown (void);
 GOConfNode *gnm_conf_get_root (void);
 
-/* autocorrect */
-void     gnm_gconf_set_autocorrect_init_caps (gboolean val);
-void     gnm_gconf_set_autocorrect_first_letter (gboolean val);
-void     gnm_gconf_set_autocorrect_names_of_days (gboolean val);
-void     gnm_gconf_set_autocorrect_replace (gboolean val);
-
 /* autocomplete */
 void     gnm_gconf_set_autocomplete (gboolean val);
 
@@ -133,9 +133,9 @@ void     gnm_gconf_set_file_single_sheet_save (gboolean value);
 void     gnm_gconf_init_printer_defaults (void);
 
 void     gnm_gconf_set_all_sheets (gboolean val);
-void     gnm_gconf_set_printer_header (gchar const *left, gchar const *middle, 
+void     gnm_gconf_set_printer_header (gchar const *left, gchar const *middle,
 				       gchar const *right);
-void     gnm_gconf_set_printer_footer (gchar const *left, gchar const *middle, 
+void     gnm_gconf_set_printer_footer (gchar const *left, gchar const *middle,
 				       gchar const *right);
 void     gnm_gconf_set_print_center_horizontally (gboolean val);
 void     gnm_gconf_set_print_center_vertically (gboolean val);
@@ -146,8 +146,10 @@ void     gnm_gconf_set_print_titles (gboolean val);
 void     gnm_gconf_set_print_order_across_then_down (gboolean val);
 void     gnm_gconf_set_print_scale_percentage (gboolean val);
 void     gnm_gconf_set_print_scale_percentage_value (gnm_float val);
-void     gnm_gconf_set_print_tb_margins (PrintMargins const *pm, GtkUnit unit);
-void     gnm_gconf_set_print_header_formats (GSList *left, GSList *middle, 
+void     gnm_gconf_set_print_tb_margins (double edge_to_header,
+					 double edge_to_footer,
+					 GtkUnit unit);
+void     gnm_gconf_set_print_header_formats (GSList *left, GSList *middle,
 					     GSList *right);
 void	 gnm_gconf_set_print_settings (GtkPrintSettings *settings);
 void     gnm_gconf_set_page_setup (GtkPageSetup *setup);
@@ -166,6 +168,7 @@ gboolean gnm_gconf_get_toolbar_visible (char const *name);
 void     gnm_gconf_set_toolbar_visible (char const *name, gboolean vis);
 int      gnm_gconf_get_toolbar_position (char const *name);
 void     gnm_gconf_set_toolbar_position (char const *name, int pos);
+void	 gnm_gconf_set_enter_moves_dir (GODirection val);
 
 /* default font */
 void     gnm_gconf_set_default_font_size (gnm_float val);
@@ -212,18 +215,21 @@ gint	 go_conf_get_int	(GOConfNode *node, gchar const *key);
 gdouble	 go_conf_get_double	(GOConfNode *node, gchar const *key);
 gchar	*go_conf_get_string	(GOConfNode *node, gchar const *key);
 GSList	*go_conf_get_str_list	(GOConfNode *node, gchar const *key);
+gchar	*go_conf_get_enum_as_str(GOConfNode *node, gchar const *key);
 
 gboolean go_conf_load_bool	(GOConfNode *node, gchar const *key, gboolean default_val);
 gint	 go_conf_load_int	(GOConfNode *node, gchar const *key, gint minima, gint maxima, gint default_val);
 gdouble	 go_conf_load_double	(GOConfNode *node, gchar const *key, gdouble minima, gdouble maxima, gdouble default_val);
 gchar	*go_conf_load_string	(GOConfNode *node, gchar const *key);
 GSList	*go_conf_load_str_list	(GOConfNode *node, gchar const *key);
+int	 go_conf_load_enum	(GOConfNode *node, gchar const *key, GType t, int default_val);
 
 void	 go_conf_set_bool	(GOConfNode *node, gchar const *key, gboolean val);
 void	 go_conf_set_int	(GOConfNode *node, gchar const *key, gint val);
 void	 go_conf_set_double	(GOConfNode *node, gchar const *key, gnm_float val);
 void	 go_conf_set_string	(GOConfNode *node, gchar const *key, gchar const *str);
 void	 go_conf_set_str_list	(GOConfNode *node, gchar const *key, GSList *list);
+void	 go_conf_set_enum	(GOConfNode *node, gchar const *key, GType t, gint val);
 
 void	 go_conf_sync		(GOConfNode *node);
 
