@@ -7,11 +7,11 @@ typedef struct _ItemCursor		ItemCursor;
 typedef struct _ItemGrid		ItemGrid;
 typedef struct _ItemBar			ItemBar;
 typedef struct _ItemEdit		ItemEdit;
-typedef struct _GnmCanvas		GnmCanvas;
-typedef struct _GnumericPane		GnmPane;
+typedef struct _GnmPane			GnmPane;
+
 typedef struct _SheetControlGUI		SheetControlGUI;
+typedef struct _WBCGtk			WBCGtk;
+
 typedef struct _WorkbookControlComponent  WorkbookControlComponent;
-typedef struct _WorkbookControlGUI	  WorkbookControlGUI;
-typedef struct _WorkbookControlStandalone WorkbookControlStandalone;
 
 #endif /* GUI_GNUMERIC_H */
