@@ -363,8 +363,8 @@ gnumeric_popup_menu (GtkMenu *menu, GdkEventButton *event)
 	 * instead pass 0.  Otherwise bringing up a menu with
 	 * the right button will disable clicking on the menu with the left.
 	 */
-	gtk_menu_popup (menu, NULL, NULL, NULL, NULL, 0, 
-			(event != NULL) ? event->time 
+	gtk_menu_popup (menu, NULL, NULL, NULL, NULL, 0,
+			(event != NULL) ? event->time
 			: gtk_get_current_event_time());
 }
 
@@ -752,76 +752,6 @@ gnumeric_load_pixbuf (char const *filename)
 }
 
 
-/**
- * gnm_pixbuf_tile: created a pixbuf consistent of the source pixbuf tiled
- * enough times to fill out the space needed.
- *
- * The fractional tiles are spead evenly left-right and top-bottom.
- */
-GdkPixbuf *
-gnm_pixbuf_tile (GdkPixbuf const *src, int w, int h)
-{
-	int src_w = gdk_pixbuf_get_width (src);
-	int src_h = gdk_pixbuf_get_height (src);
-
-	int tile_x = w / src_w;  /* Number of full tiles  */
-	int tile_y = h / src_h;
-
-	int left_x = w - tile_x * src_w;
-	int left_y = h - tile_y * src_h;
-
-	int dst_y = 0;
-	int stripe_y;
-	GdkPixbuf *dst = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (src),
-					 gdk_pixbuf_get_has_alpha (src),
-					 gdk_pixbuf_get_bits_per_sample (src),
-					 MAX (w, 1),
-					 MAX (h, 1));
-
-	for (stripe_y = -1; stripe_y <= tile_y; stripe_y++) {
-		int dst_x = 0;
-		int stripe_x;
-		int this_h, start_y = 0;
-
-		if (stripe_y == -1) {
-			this_h = (left_y + 1) / 2;
-			start_y = src_h - this_h;
-		} else if (stripe_y == tile_y)
-			this_h = left_y / 2;
-		else
-			this_h = src_h;
-
-		if (this_h == 0)
-			continue;
-
-		for (stripe_x = -1; stripe_x <= tile_x; stripe_x++) {
-			int this_w, start_x = 0;
-
-			if (stripe_x == -1) {
-				this_w = (left_x + 1) / 2;
-				start_x = src_w - this_w;
-			} else if (stripe_x == tile_x)
-				this_w = left_x / 2;
-			else
-				this_w = src_w;
-
-			if (this_w == 0)
-				continue;
-
-			gdk_pixbuf_copy_area (src, start_x, start_y,
-					      this_w, this_h,
-					      dst,
-					      dst_x, dst_y);
-
-			dst_x += this_w;
-		}
-
-		dst_y += this_h;
-	}
-
-	return dst;
-}
-
 static void
 cb_focus_to_entry (GtkWidget *button, GtkWidget *entry)
 {
@@ -873,7 +803,7 @@ gnm_widget_set_cursor_type (GtkWidget *w, GdkCursorType ct)
  * A convenience fonction to build HIG compliant message dialogs.
  *
  *   parent : transient parent, or NULL for none.
- *   flags 
+ *   flags
  *   type : type of dialog
  *   primary_message : message displayed in bold
  *   secondary_message : message displayed below
@@ -899,7 +829,7 @@ gnumeric_message_dialog_new (GtkWindow * parent,
 	dialog = gtk_dialog_new_with_buttons ("", parent, flags, NULL);
 
 	if (dialog) {
-		image = gtk_image_new (); 
+		image = gtk_image_new ();
 
 		switch (type) {
 		case GTK_MESSAGE_INFO:
@@ -932,7 +862,7 @@ gnumeric_message_dialog_new (GtkWindow * parent,
 
 			gtk_window_set_title (GTK_WINDOW (dialog), item.label);
 		} else
-			g_warning ("Stock dialog ID doesn't exist?");  
+			g_warning ("Stock dialog ID doesn't exist?");
 
 		if (primary_message) {
 			if (secondary_message) {
@@ -971,7 +901,7 @@ gnumeric_message_dialog_new (GtkWindow * parent,
 	return dialog;
 }
 
-gboolean 
+gboolean
 gnm_tree_model_iter_prev (GtkTreeModel *model, GtkTreeIter* iter)
 {
 	GtkTreePath *path = gtk_tree_model_get_path (model, iter);
@@ -999,7 +929,7 @@ cb_gnm_dialog_setup_destroy_handlers (G_GNUC_UNUSED GtkWidget *widget,
 	for (i = 0; i < (int)os->len; i += 2) {
 		GObject *obj = g_ptr_array_index (os, i);
 		guint s = GPOINTER_TO_UINT (g_ptr_array_index (os, i + 1));
-		g_signal_handler_disconnect (obj, s);	
+		g_signal_handler_disconnect (obj, s);
 	}
 
 	g_ptr_array_free (os, TRUE);
