@@ -270,40 +270,45 @@ ib_draw_cell (ItemBar const * const ib, GdkDrawable *drawable,
 	default:
 	case COL_ROW_NO_SELECTION:
 		shadow = GTK_SHADOW_OUT;
-		gc = canvas->style->bg_gc [GTK_STATE_ACTIVE];
-		font = ib->normal_font;
+		gc     = canvas->style->bg_gc [GTK_STATE_ACTIVE];
+		font   = ib->normal_font;
 		ascent = ib->normal_font_ascent;
 		break;
 
 	case COL_ROW_PARTIAL_SELECTION:
 		shadow = GTK_SHADOW_OUT;
-		gc = canvas->style->dark_gc [GTK_STATE_PRELIGHT];
-		font = ib->bold_font;
+		gc     = canvas->style->dark_gc [GTK_STATE_PRELIGHT];
+		font   = ib->bold_font;
 		ascent = ib->bold_font_ascent;
 		break;
 
 	case COL_ROW_FULL_SELECTION:
 		shadow = GTK_SHADOW_IN;
-		gc = canvas->style->dark_gc [GTK_STATE_NORMAL];
-		font = ib->bold_font;
+		gc     = canvas->style->dark_gc [GTK_STATE_NORMAL];
+		font   = ib->bold_font;
 		ascent = ib->bold_font_ascent;
 		break;
 	}
-	g_return_if_fail (font != NULL);
+	/* When we are really small leave out the shadow and the text */
+	if (rect->width <= 2 || rect->height <= 2) {
+		gdk_draw_rectangle (drawable, gc, TRUE,
+			rect->x, rect->y, rect->width, rect->height);
+		return;
+	}
 
-	/* Draw header background */
 	gdk_draw_rectangle (drawable, gc, TRUE,
-			    rect->x + 1, rect->y + 1, rect->width - 1, rect->height - 1);
-	/* Then draw its shadow. */
+		rect->x + 1, rect->y + 1, rect->width - 1, rect->height - 1);
 	gtk_paint_shadow (canvas->style, drawable, GTK_STATE_NORMAL, shadow,
 			  NULL, NULL, "GnmItemBarCell",
 			  rect->x, rect->y, rect->width + 1, rect->height + 1);
-	gdk_gc_set_clip_rectangle (text_gc, rect);
 
+	g_return_if_fail (font != NULL);
 	g_object_unref (ib->pango.item->analysis.font);
 	ib->pango.item->analysis.font = g_object_ref (font);
 	pango_shape (str, strlen (str), &(ib->pango.item->analysis), ib->pango.glyphs);
 	pango_glyph_string_extents (ib->pango.glyphs, font, NULL, &size);
+
+	gdk_gc_set_clip_rectangle (text_gc, rect);
 	gdk_draw_glyphs (drawable, text_gc, font,
 		rect->x + (rect->width - PANGO_PIXELS (size.width)) / 2,
 		rect->y + (rect->height - PANGO_PIXELS (size.height)) / 2 + ascent,
@@ -349,7 +354,7 @@ item_bar_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expos
 		/* shadow type selection must be keep in sync with code in ib_draw_cell */
 		rect.y = ib->indent;
 		rect.height = ib->cell_height;
-		shadow = (col > 0 && !has_object && sv_selection_col_type (sv, col-1) == COL_ROW_FULL_SELECTION) 
+		shadow = (col > 0 && !has_object && sv_selection_col_type (sv, col-1) == COL_ROW_FULL_SELECTION)
 			? GTK_SHADOW_IN : GTK_SHADOW_OUT;
 
 		if (rtl)
@@ -577,9 +582,9 @@ item_bar_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expos
 							gdk_draw_lines (drawable, ib->lines, points, 3);
 						else if (!draw_below && i > next->outline_level)
 							gdk_draw_lines (drawable, ib->lines, points, 3);
-						else 
+						else
 							gdk_draw_line (drawable, ib->lines,
-								       pos, top - first_line_offset, 
+								       pos, top - first_line_offset,
 								       pos, total);
 					}
 					first_line_offset = 0;
@@ -727,7 +732,7 @@ is_pointer_on_division (ItemBar const *ib, double x, double y,
 			WBCGtk *wbcg = scg_wbcg (ib->pane->simple.scg);
 			total += cri->size_pixels;
 
-			if (wbcg_edit_get_guru (wbcg) == NULL &&
+			if (wbc_gtk_get_guru (wbcg) == NULL &&
 			    !wbcg_is_editing (wbcg) &&
 			    (total - 4 < major) && (major < total + 4)) {
 				if (the_total)
@@ -921,7 +926,7 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 		if (e->button.button > 3)
 			return FALSE;
 
-		if (wbcg_edit_get_guru (wbcg) == NULL)
+		if (wbc_gtk_get_guru (wbcg) == NULL)
 			scg_mode_edit (scg);
 
 		cri = is_pointer_on_division (ib, e->button.x, e->button.y,
@@ -932,7 +937,7 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 			return outline_button_press (ib, element, minor_pos);
 
 		if (e->button.button == 3) {
-			if (wbcg_edit_get_guru (wbcg) != NULL)
+			if (wbc_gtk_get_guru (wbcg) != NULL)
 				return TRUE;
 			/* If the selection does not contain the current row/col
 			 * then clear the selection and add it.
@@ -968,7 +973,7 @@ item_bar_event (FooCanvasItem *item, GdkEvent *e)
 				gtk_widget_show_all (gtk_widget_get_toplevel (ib->tip));
 			}
 		} else {
-			if (wbcg_edit_get_guru (wbcg) != NULL &&
+			if (wbc_gtk_get_guru (wbcg) != NULL &&
 			    !wbcg_entry_has_logical (wbcg))
 				break;
 
