@@ -411,7 +411,7 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expo
 	g_printerr ("%s:", cell_coord_name (start_col, start_row));
 	g_printerr ("%s <= %d vs %d", cell_coord_name(end_col, end_row), y, expose->area.y);
 	g_printerr (" [%s]\n", cell_coord_name (ig->bound.end.col, ig->bound.end.row));
-	
+
 #endif
 
 	/* clip to bounds */
@@ -822,7 +822,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	 * ends the edit.  */
 	if (scg->selected_objects == NULL)
 		wbcg_focus_cur_scg (wbcg);
-	else if (wbcg_edit_get_guru (wbcg) == NULL)
+	else if (wbc_gtk_get_guru (wbcg) == NULL)
 		scg_mode_edit (scg);
 
 	/* If we were already selecting a range of cells for a formula,
@@ -855,7 +855,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	}
 
 	/* While a guru is up ignore clicks */
-	if (wbcg_edit_get_guru (wbcg) != NULL)
+	if (wbc_gtk_get_guru (wbcg) != NULL)
 		return TRUE;
 
 	/* This was a regular click on a cell on the spreadsheet.  Select it.
