@@ -59,9 +59,10 @@ typedef enum {
 
 GnmStyle   *gnm_style_new           (void);
 GnmStyle   *gnm_style_new_default   (void);
-GnmStyle   *gnm_style_new_merged    (GnmStyle const *orig, GnmStyle const *overlay);
+GnmStyle   *gnm_style_new_merged    (GnmStyle const *base, GnmStyle const *overlay);
 GnmStyle   *gnm_style_dup	    (GnmStyle const *src);
-void        gnm_style_merge_element (GnmStyle *dst, GnmStyle const *src,
+void        gnm_style_merge	    (GnmStyle *base, GnmStyle const *overlay);
+void        gnm_style_merge_element (GnmStyle *base, GnmStyle const *overlay,
 				     GnmStyleElement elem);
 void        gnm_style_ref           (GnmStyle const *style);
 void        gnm_style_unref         (GnmStyle const *style);
@@ -110,12 +111,11 @@ GOFontScript gnm_style_get_font_script	   (GnmStyle const *style);
 void         gnm_style_set_font_size	   (GnmStyle *style, float size);
 float        gnm_style_get_font_size	   (GnmStyle const *style);
 
-/* this font must be unrefd after use */
 GnmFont     *gnm_style_get_font		   (GnmStyle const *style,
 					    PangoContext *context,
 					    float zoom);
-void         gnm_style_set_format	   (GnmStyle *style, GOFormat *);
-void         gnm_style_set_format_text	   (GnmStyle *style, char const *format);
+void         gnm_style_set_format	   (GnmStyle *style, GOFormat *fmt);
+void         gnm_style_set_format_text	   (GnmStyle *style, char const *fmt);
 GOFormat    *gnm_style_get_format	   (GnmStyle const *style);
 void         gnm_style_set_align_h	   (GnmStyle *style, GnmHAlign a);
 GnmHAlign    gnm_style_get_align_h	   (GnmStyle const *style);
@@ -142,7 +142,8 @@ void		 gnm_style_set_contents_hidden (GnmStyle *style, gboolean f);
 gboolean	 gnm_style_get_contents_hidden (GnmStyle const *style);
 
 void		 gnm_style_set_validation	(GnmStyle *style, GnmValidation *v);
-GnmValidation	*gnm_style_get_validation	(GnmStyle const *style);
+GnmValidation const *
+		 gnm_style_get_validation	(GnmStyle const *style);
 
 void		 gnm_style_set_hlink		(GnmStyle *style, GnmHLink *link);
 GnmHLink	*gnm_style_get_hlink		(GnmStyle const *style);
@@ -159,8 +160,11 @@ PangoAttrList	*gnm_style_generate_attrs_full (GnmStyle const *style);
 PangoAttrList	*gnm_style_get_pango_attrs     (GnmStyle const *style,
 						PangoContext *context,
 						float zoom);
+int              gnm_style_get_pango_height    (GnmStyle const *style,
+						PangoContext *context,
+						float zoom);
 void   	    gnm_style_set_from_pango_attribute (GnmStyle *style,
-						     PangoAttribute const *attr);
+						PangoAttribute const *attr);
 
 void        gnm_style_init (void);
 void        gnm_style_shutdown (void);
