@@ -433,7 +433,7 @@ fixup_hour_ampm (gnm_float *hour, const GORegmatch *pm)
 		*hour = -1;
 		return;
 	}
-	
+
 	if (*hour == 12)
 		*hour = 0;
 	if (!is_am)
@@ -687,7 +687,7 @@ format_match_datetime (char const *text,
 			goto got_date;
 		}
 	}
-	    
+
 	/* ^(\d+)([-/.])(\d+)\b */
 	/*  1    2      3       */
 	if (dig1 >= 0 &&
@@ -771,38 +771,6 @@ format_match_datetime (char const *text,
 	return v;
 }
 
-static gboolean
-hack_month_before_day (GOFormat const *cur_fmt)
-{
-	char *s = g_strdup (go_format_as_XL (cur_fmt));
-	char *p;
-	char const *pos_m, *pos_d;
-	gboolean res;
-
-	/* Try to block out minutes.  */
-	p = strchr (s, 'h');
-	if (p) *p = 0;
-
-	pos_m = strchr (s, 'm');
-	pos_d = strchr (s, 'd');
-	if (pos_m && pos_d)
-		res = (pos_m < pos_d);
-	else
-		res = go_locale_month_before_day ();
-
-	g_free (s);
-	return res;
-}
-
-static gboolean
-hack_prefer_hour (GOFormat const *cur_fmt)
-{
-	const char *s = go_format_as_XL (cur_fmt);
-	gboolean res = (strchr (s, 'h') != NULL);
-	return res;
-}
-
-
 /*
  * Match "12/23", "-12/23", "1 2/3", "-1 2/3", and even "-123".
  * Does not match "1/0".
@@ -941,7 +909,7 @@ format_match_decimal_number (char const *text, GOFormatFamily *family)
 		    g_ascii_isdigit (text[thousand->len + 1]) &&
 		    g_ascii_isdigit (text[thousand->len + 2])) {
 			text += thousand->len;
-			continue;			
+			continue;
 		}
 
 		if (strncmp (decimal->str, text, decimal->len) == 0) {
@@ -1121,7 +1089,7 @@ format_match (char const *text, GOFormat *cur_fmt,
 
 	case GO_FORMAT_DATE: {
 		gboolean month_before_day =
-			hack_month_before_day (cur_fmt);
+			gnm_format_month_before_day (cur_fmt, NULL);
 
 		v = format_match_datetime (text, date_conv,
 					   month_before_day,
@@ -1136,8 +1104,10 @@ format_match (char const *text, GOFormat *cur_fmt,
 
 	case GO_FORMAT_TIME: {
 		gboolean month_before_day =
-			hack_month_before_day (cur_fmt);
-		gboolean prefer_hour = hack_prefer_hour (cur_fmt);
+			gnm_format_month_before_day (cur_fmt, NULL);
+
+		gboolean prefer_hour =
+			gnm_format_has_hour (cur_fmt, NULL);
 
 		v = format_match_datetime (text, date_conv,
 					   month_before_day,
