@@ -2,7 +2,7 @@
 #define GNUMERIC_NUMBERS_H
 
 #include <gnumeric-config.h>
-#include <goffice/utils/go-math.h>
+#include <goffice/math/go-math.h>
 
 #ifdef HAVE_IEEEFP_H
 #include <ieeefp.h>
@@ -13,7 +13,7 @@
 
 #ifndef HAVE_LGAMMA
 /* Defined in mathfunc.c  */
-extern int signgam;
+GO_VAR_DECL int signgam;
 double lgamma (double x);
 #endif
 #ifndef HAVE_LGAMMA_R
@@ -75,6 +75,7 @@ gnm_float gnm_yn (int n, gnm_float x);
 #define gnm_floor floorl
 #define gnm_fmod fmodl
 #define gnm_format_number go_format_numberl
+#define gnm_format_value_gstring go_format_value_gstringl
 #define gnm_frexp frexpl
 #define gnm_hypot hypotl
 #define gnm_isnan isnanl
@@ -92,11 +93,10 @@ gnm_float gnm_yn (int n, gnm_float x);
 #define gnm_pow10 go_pow10l
 #define gnm_pow2 go_pow2l
 #define gnm_render_general go_render_generall
-#define gnm_render_number go_render_numberl
 #define gnm_sin sinl
 #define gnm_sinh sinhl
 #define gnm_sqrt sqrtl
-#define gnm_strto strtold
+#define gnm_strto go_strtold
 #define gnm_sub_epsilon go_sub_epsilonl
 #define gnm_tan tanl
 #define gnm_tanh tanhl
@@ -143,6 +143,7 @@ typedef double gnm_float;
 #define gnm_floor floor
 #define gnm_fmod fmod
 #define gnm_format_number go_format_number
+#define gnm_format_value_gstring go_format_value_gstring
 #define gnm_frexp frexp
 #define gnm_hypot hypot
 #define gnm_isnan isnan
@@ -160,11 +161,10 @@ typedef double gnm_float;
 #define gnm_pow10 go_pow10
 #define gnm_pow2 go_pow2
 #define gnm_render_general go_render_general
-#define gnm_render_number go_render_number
 #define gnm_sin sin
 #define gnm_sinh sinh
 #define gnm_sqrt sqrt
-#define gnm_strto strtod
+#define gnm_strto go_strtod
 #define gnm_sub_epsilon go_sub_epsilon
 #define gnm_tan tan
 #define gnm_tanh tanh
