@@ -328,7 +328,7 @@ typedef struct {
 	gboolean unknown_names_are_strings;
 	gboolean unknown_names_are_invalid;
 
-	GnmExprConventions const *convs;
+	GnmConventions const *convs;
 
 	/* dynamic state */
 	int in_array; /* toggled in the lexer for '{' and '}' */
@@ -2995,10 +2995,10 @@ yylex (void)
 			l = strtol (start, &end, 10);
 			if (start == end) {
 				g_warning ("%s is not an integer, but was expected to be one", start);
-			} else if (errno != ERANGE) {
+			} else if (errno != ERANGE && l >= INT_MIN && l <= INT_MAX) {
 				v = value_new_int (l);
 				state->ptr = end;
-			} else if (l == LONG_MIN || l == LONG_MAX) {
+			} else {
 				gnm_float d;
 
 				errno = 0;
@@ -3143,11 +3143,11 @@ yyerror (char const *s)
 /**
  * gnm_expr_parse_str:
  *
- * @expr_text   : The string to parse.
- * @pp		: #GnmParsePos
- * @flags       : See parse-utils for descriptions
- * @convs	: optionally NULL #GnmExprConventions
- * @error       : optionally NULL ptr to store details of error.
+ * @str   : The string to parse.
+ * @pp	  : #GnmParsePos
+ * @flags : See parse-utils for descriptions
+ * @convs : optionally NULL #GnmConventions
+ * @error : optionally NULL ptr to store details of error.
  *
  * Parse a string. if @error is non-null it will be assumed that the
  * caller has passed a pointer to a GnmParseError struct AND that it will
@@ -3156,18 +3156,18 @@ yyerror (char const *s)
  * If @convs is NULL use the conventions from @pp.
  **/
 GnmExprTop const *
-gnm_expr_parse_str (char const *expr_text, GnmParsePos const *pp,
+gnm_expr_parse_str (char const *str, GnmParsePos const *pp,
 		    GnmExprParseFlags flags,
-		    GnmExprConventions const *convs,
+		    GnmConventions const *convs,
 		    GnmParseError *error)
 {
 	GnmExpr const *expr;
 	ParserState pstate;
 
-	g_return_val_if_fail (expr_text != NULL, NULL);
+	g_return_val_if_fail (str != NULL, NULL);
 	g_return_val_if_fail (pp != NULL, NULL);
 
-	pstate.start = pstate.ptr = expr_text;
+	pstate.start = pstate.ptr = str;
 	pstate.pos   = pp;
 
 	pstate.force_absolute_col_references		= flags & GNM_EXPR_PARSE_FORCE_ABSOLUTE_COL_REFERENCES;
@@ -3176,7 +3176,7 @@ gnm_expr_parse_str (char const *expr_text, GnmParsePos const *pp,
 	pstate.unknown_names_are_strings		= flags & GNM_EXPR_PARSE_UNKNOWN_NAMES_ARE_STRINGS;
 	pstate.unknown_names_are_invalid		= flags & GNM_EXPR_PARSE_UNKNOWN_NAMES_ARE_INVALID;
 	pstate.convs                                    =
-		(NULL != convs) ? convs : ((NULL != pp->sheet) ? pp->sheet->convs : gnm_expr_conventions_default);
+		(NULL != convs) ? convs : ((NULL != pp->sheet) ? pp->sheet->convs : gnm_conventions_default);
 
 
 	pstate.decimal_point = pstate.convs->decimal_sep_dot
