@@ -13,6 +13,7 @@
 #include "gnumeric.h"
 #include "print-info.h"
 
+#include "print.h"
 #include "gutils.h"
 #include "ranges.h"
 #include "gnm-format.h"
@@ -20,6 +21,7 @@
 #include "sheet.h"
 #include "value.h"
 #include "workbook.h"
+#include "workbook-view.h"
 #include "gnumeric-gconf.h"
 #include "gnumeric-gconf-priv.h"
 
@@ -110,7 +112,8 @@ print_hf_copy (PrintHF const *source)
 void
 print_hf_free (PrintHF *print_hf)
 {
-	g_return_if_fail (print_hf != NULL);
+	if (print_hf == NULL)
+		return;
 
 	g_free (print_hf->left_format);
 	g_free (print_hf->middle_format);
@@ -123,13 +126,17 @@ print_info_free (PrintInformation *pi)
 {
 	g_return_if_fail (pi != NULL);
 
+	if (NULL != pi->page_breaks.v)
+		gnm_page_breaks_free (pi->page_breaks.v);
+	if (NULL != pi->page_breaks.h)
+		gnm_page_breaks_free (pi->page_breaks.h);
+
 	print_hf_free (pi->header);
 	print_hf_free (pi->footer);
 
-	g_free (pi->paper);
-	g_free (pi->paper_width);
-	g_free (pi->paper_height);
-	g_free (pi->gp_config_str);
+	if (pi->page_setup)
+		g_object_unref (pi->page_setup);
+
 	g_free (pi);
 }
 
@@ -176,14 +183,14 @@ load_formats (void)
 			hf_formats = g_list_prepend (hf_formats, format);
 			hf_formats_base_num++;
 		}
-	} 
+	}
 
 	/* Now append the custom formats */
 	{
 		GSList const *left;
 		GSList const *middle;
 		GSList const *right;
-		
+
 		left = gnm_app_prefs->printer_header_formats_left;
 		middle = gnm_app_prefs->printer_header_formats_middle;
 		right = gnm_app_prefs->printer_header_formats_right;
@@ -192,13 +199,13 @@ load_formats (void)
 		{
 			PrintHF *format;
 
-			format = print_hf_new 
-				(left->data ? (char *)(left->data) : "",
-				 middle->data ? (char *)(middle->data) : "",
-				 right->data ? (char *)(right->data) : "");
+			format = print_hf_new
+				(left->data ? left->data : "",
+				 middle->data ? middle->data : "",
+				 right->data ? right->data : "");
 
 			hf_formats = g_list_prepend (hf_formats, format);
-			
+
 			left = left->next;
 			middle = middle->next;
 			right = right->next;
@@ -209,29 +216,38 @@ load_formats (void)
 }
 
 /**
- * print_info_new:
+ * print_info_load_defaults:
  *
- * Returns a newly allocated PrintInformation buffer
  *
  * NOTE: This reads from a globally stored configuration. If a
  *       configuration is stored along with a sheet then that will
  *       override these global defaults.
  */
+
 PrintInformation *
-print_info_new (void)
+print_info_load_defaults (PrintInformation *res)
 {
 	GSList *list;
-	PrintInformation *res = g_new0 (PrintInformation, 1);
+
+	if (res->page_setup != NULL)
+		return res;
+
+	res->page_setup = gtk_page_setup_copy (gnm_gconf_get_page_setup ());
 
 	res->scaling.type = gnm_app_prefs->print_scale_percentage
 		? PRINT_SCALE_PERCENTAGE : PRINT_SCALE_FIT_PAGES;
-	res->scaling.percentage.x = res->scaling.percentage.y 
+	res->scaling.percentage.x = res->scaling.percentage.y
 		= gnm_app_prefs->print_scale_percentage_value;
 	res->scaling.dim.cols = gnm_app_prefs->print_scale_width;
 	res->scaling.dim.rows = gnm_app_prefs->print_scale_height;
-	res->margin.top       = gnm_app_prefs->print_margin_top;
-	res->margin.bottom    = gnm_app_prefs->print_margin_bottom;
-	res->margin.left = res->margin.right = res->margin.header = res->margin.footer = -1.;
+	res->edge_to_below_header = gnm_app_prefs->print_margin_top;
+	res->edge_to_above_footer = gnm_app_prefs->print_margin_bottom;
+	res->desired_display.top = gnm_app_prefs->desired_display;
+	res->desired_display.bottom = gnm_app_prefs->desired_display;
+	res->desired_display.left = gnm_app_prefs->desired_display;
+	res->desired_display.right = gnm_app_prefs->desired_display;
+	res->desired_display.footer = gnm_app_prefs->desired_display;
+	res->desired_display.header = gnm_app_prefs->desired_display;
 
 	res->repeat_top.use   = load_range (gnm_app_prefs->print_repeat_top,
 					    &res->repeat_top.range);
@@ -243,40 +259,55 @@ print_info_new (void)
 	res->print_grid_lines      = gnm_app_prefs->print_grid_lines;
 	res->print_titles          = gnm_app_prefs->print_titles;
 	res->print_black_and_white = gnm_app_prefs->print_black_and_white;
-	res->print_as_draft	   = FALSE;
-	res->portrait_orientation  = TRUE;
-
-	res->invert_orientation    = FALSE;
-	res->print_even_if_only_styles 
+	res->print_even_if_only_styles
 		= gnm_app_prefs->print_even_if_only_styles;
 
 	res->print_across_then_down = gnm_app_prefs->print_order_across_then_down;
-	res->comment_placement = PRINT_COMMENTS_IN_PLACE;
-	res->error_display     = PRINT_ERRORS_AS_DISPLAYED;
 
 	list = (GSList *) gnm_app_prefs->printer_header;
 	res->header = list ?
-		print_hf_new ((char *)g_slist_nth_data (list, 0),
-			      (char *)g_slist_nth_data (list, 1),
-			      (char *)g_slist_nth_data (list, 2)) :
+		print_hf_new (g_slist_nth_data (list, 0),
+			      g_slist_nth_data (list, 1),
+			      g_slist_nth_data (list, 2)) :
 		print_hf_new ("", _("&[TAB]"), "");
 	list = (GSList *) gnm_app_prefs->printer_footer;
 	res->footer = list ?
-		print_hf_new ((char *)g_slist_nth_data (list, 0),
-			      (char *)g_slist_nth_data (list, 1),
-			      (char *)g_slist_nth_data (list, 2)) :
+		print_hf_new (g_slist_nth_data (list, 0),
+			      g_slist_nth_data (list, 1),
+			      g_slist_nth_data (list, 2)) :
 		print_hf_new ("", _("Page &[PAGE]"), "");
 
-	res->n_copies	   = 1;
-	res->start_page	   = -1;
-	res->gp_config_str = NULL;
-	res->paper	   = NULL;
-	res->paper_width   = NULL;
-	res->paper_height  = NULL;
-
 	return res;
 }
 
+/**
+ * print_info_new:
+ *
+ * Returns a newly allocated PrintInformation buffer
+ *
+ */
+PrintInformation *
+print_info_new (gboolean load_defaults)
+{
+	PrintInformation *res = g_new0 (PrintInformation, 1);
+
+	res->print_as_draft	   = FALSE;
+	res->comment_placement = PRINT_COMMENTS_IN_PLACE;
+	res->error_display     = PRINT_ERRORS_AS_DISPLAYED;
+
+	res->start_page	   = -1;
+	res->n_copies	   = 0;
+
+	res->page_setup = NULL;
+	res->page_breaks.v = NULL;
+	res->page_breaks.h = NULL;
+
+	if (load_defaults)
+		return print_info_load_defaults (res);
+	else
+		return res;
+}
+
 /*
  *   This can get out of hand, we should limit the number of stored
  * formats.
@@ -324,7 +355,7 @@ destroy_formats (void)
 }
 
 void
-print_info_save (PrintInformation const *pi)
+print_info_save (PrintInformation *pi)
 {
 	GOConfNode *node = go_conf_get_node (gnm_conf_get_root (), PRINTSETUP_GCONF_DIR);
 
@@ -333,7 +364,9 @@ print_info_save (PrintInformation const *pi)
 	go_conf_set_int (node, PRINTSETUP_GCONF_SCALE_WIDTH,  pi->scaling.dim.cols);
 	go_conf_set_int (node, PRINTSETUP_GCONF_SCALE_HEIGHT, pi->scaling.dim.rows);
 
-	gnm_gconf_set_print_tb_margins (&pi->margin);
+	gnm_gconf_set_print_tb_margins (pi->edge_to_below_header,
+					pi->edge_to_above_footer,
+					pi->desired_display.top);
 
 	gnm_gconf_set_print_center_horizontally (pi->center_horizontally);
 	gnm_gconf_set_print_center_vertically (pi->center_vertically);
@@ -342,7 +375,7 @@ print_info_save (PrintInformation const *pi)
 	gnm_gconf_set_print_even_if_only_styles (pi->print_even_if_only_styles);
 	gnm_gconf_set_print_black_and_white (pi->print_black_and_white);
 	gnm_gconf_set_print_order_across_then_down (pi->print_across_then_down);
-	
+
 	go_conf_set_string (node, PRINTSETUP_GCONF_REPEAT_TOP,
 		pi->repeat_top.use ? range_as_string (&pi->repeat_top.range) : "");
 	go_conf_set_string (node, PRINTSETUP_GCONF_REPEAT_LEFT,
@@ -350,8 +383,6 @@ print_info_save (PrintInformation const *pi)
 
 	save_formats ();
 
-	if (NULL != pi->gp_config_str)
-		gnm_gconf_set_printer_config (pi->gp_config_str);
 	gnm_gconf_set_printer_header (pi->header->left_format,
 				      pi->header->middle_format,
 				      pi->header->right_format);
@@ -359,39 +390,46 @@ print_info_save (PrintInformation const *pi)
 				      pi->footer->middle_format,
 				      pi->footer->right_format);
 
+	gnm_gconf_set_page_setup (pi->page_setup);
+
 	go_conf_free_node (node);
 }
 
-const GnomePrintUnit *
+GtkUnit
 unit_name_to_unit (char const *name)
 {
-	GList *units = gnome_print_unit_get_list (GNOME_PRINT_UNITS_ALL);
-	GList *l;
-	GnomePrintUnit const *res = NULL;
+	if (!g_ascii_strcasecmp (name, "cm"))
+		return GTK_UNIT_MM;
+	if (!g_ascii_strcasecmp (name, "mm"))
+		return GTK_UNIT_MM;
+	if (!g_ascii_strcasecmp (name, "centimeter"))
+		return GTK_UNIT_MM;
+	if (!g_ascii_strcasecmp (name, "millimeter"))
+		return GTK_UNIT_MM;
+	if (!g_ascii_strcasecmp (name, "inch"))
+		return GTK_UNIT_INCH;
+	if (!g_ascii_strcasecmp (name, "in"))
+		return GTK_UNIT_INCH;
+	if (!g_ascii_strcasecmp (name, "inches"))
+		return GTK_UNIT_INCH;
 
-	for (l = units; l; l = l->next) {
-		GnomePrintUnit const *u = l->data;
-		if (g_ascii_strcasecmp (name, u->name) == 0 ||
-		    g_ascii_strcasecmp (name, u->plural) == 0 ||
-		    g_ascii_strcasecmp (name, u->abbr) == 0 ||
-		    g_ascii_strcasecmp (name, u->abbr_plural) == 0) {
-			res = u;
-			break;
-		}
-	}
-
-	g_list_free (units);
-	return res;
+	return GTK_UNIT_POINTS;
 }
 
-double
-unit_convert (double value, GnomePrintUnit const *src, GnomePrintUnit const *dst)
+char const *
+unit_to_unit_name (GtkUnit unit)
 {
-	gboolean ok = gnome_print_convert_distance (&value, src, dst);
-	g_assert (ok);
-	return value;
+	switch (unit) {
+	case GTK_UNIT_MM:
+		return "mm";
+	case GTK_UNIT_INCH:
+		return "inch";
+	default:
+		return "points";
+	}
 }
 
+
 static void
 render_tab (GString *target, HFRenderInfo *info, char const *args)
 {
@@ -419,7 +457,7 @@ render_value_with_format (GString *target, char const *number_format, HFRenderIn
 	GOFormat *format;
 
 	/* TODO : Check this assumption.  Is it a localized format ?? */
-	format = go_format_new_from_XL (number_format, FALSE);
+	format = go_format_new_from_XL (number_format);
 	format_value_gstring (target, format, info->date_time, NULL, -1, NULL);
 	go_format_unref (format);
 }
@@ -457,7 +495,7 @@ render_file (GString *target, HFRenderInfo *info, char const *args)
 			go_doc_get_uri (GO_DOC (info->sheet->workbook)));
 		g_string_append (target, name);
 		g_free (name);
-	} else 
+	} else
 		g_string_append (target, _("File Name"));
 }
 
@@ -469,7 +507,7 @@ render_path (GString *target, HFRenderInfo *info, char const *args)
 			go_doc_get_uri (GO_DOC (info->sheet->workbook)), TRUE);
 		g_string_append (target, path);
 		g_free (path);
-	} else 
+	} else
 		g_string_append (target, _("Path "));
 }
 
@@ -511,7 +549,7 @@ render_opcode (GString *target, char /* non-const */ *opcode,
 		if (render_ops [i].name_trans == NULL) {
 			render_ops [i].name_trans = g_utf8_casefold (_(render_ops [i].name), -1);
 		}
-		
+
 		if ((g_ascii_strcasecmp (render_ops [i].name, opcode) == 0) ||
 		    (g_utf8_collate (render_ops [i].name_trans, opcode_trans) == 0)) {
 			(*render_ops [i].render)(target, info, args);
@@ -573,9 +611,24 @@ hf_render_info_destroy (HFRenderInfo *hfi)
 	g_free (hfi);
 }
 
+static void
+pdf_write_workbook (GOFileSaver const *fs, IOContext *context,
+		    gconstpointer wbv_, GsfOutput *output)
+{
+	WorkbookView const *wbv = wbv_;
+	gnm_print_sheet (NULL, wb_view_cur_sheet (wbv), FALSE,
+			 PRINT_ALL_SHEETS, output);
+}
+
 void
 print_init (void)
 {
+	/* Install a pdf saver.  */
+	go_file_saver_register (go_file_saver_new (
+		"Gnumeric_pdf:pdf_assistant", "pdf",
+		_("PDF export"),
+		FILE_FL_WRITE_ONLY, pdf_write_workbook));
+
 	load_formats ();
 }
 
@@ -587,206 +640,409 @@ print_shutdown (void)
 }
 
 PrintInformation *
-print_info_dup (PrintInformation const *src)
+print_info_dup (PrintInformation *src)
 {
-	PrintInformation *dst = print_info_new ();
+	PrintInformation *dst = print_info_new (TRUE);
+
+	print_info_load_defaults (src);
 
 	/* clear the refs in the new obj */
-	g_free (dst->gp_config_str);
-	g_free (dst->paper);
-	g_free (dst->paper_width);
-	g_free (dst->paper_height);
 	print_hf_free (dst->header);
 	print_hf_free (dst->footer);
+	if (dst->page_setup)
+		g_object_unref (dst->page_setup);
 
 	*dst = *src; /* bit bash */
 
+	dst->page_breaks.v = gnm_page_breaks_dup (src->page_breaks.v);
+	dst->page_breaks.h = gnm_page_breaks_dup (src->page_breaks.h);
+
 	/* setup the refs for new content */
-	dst->gp_config_str = g_strdup (src->gp_config_str);
-	dst->paper	   = g_strdup (src->paper);
-	dst->paper_width   = g_strdup (src->paper_width);
-	dst->paper_height  = g_strdup (src->paper_height);
 	dst->header	   = print_hf_copy (src->header);
 	dst->footer	   = print_hf_copy (src->footer);
+	dst->page_setup    = gtk_page_setup_copy (src->page_setup);
 
 	return dst;
 }
 
 void
-print_info_get_margins (PrintInformation const *pi,
-			double *top, double *bottom, double *left, double *right)
+print_info_get_margins (PrintInformation *pi,
+			double *top, double *bottom,
+			double *left, double *right,
+			double *edge_to_below_header,
+			double *edge_to_above_footer)
 {
 	g_return_if_fail (pi != NULL);
+	print_info_load_defaults (pi);
+	g_return_if_fail (pi->page_setup != NULL);
 
 	if (NULL != top)
-		*top = (pi->margin.header > 0.) ? pi->margin.header : 0.;
+		*top = gtk_page_setup_get_top_margin (pi->page_setup, GTK_UNIT_POINTS);
 	if (NULL != bottom)
-		*bottom = (pi->margin.footer > 0.) ? pi->margin.footer : 0.;
+		*bottom = gtk_page_setup_get_bottom_margin (pi->page_setup, GTK_UNIT_POINTS);
 	if (NULL != left)
-		*left = (pi->margin.left > 0.) ? pi->margin.left : 0.;
+		*left = gtk_page_setup_get_left_margin (pi->page_setup, GTK_UNIT_POINTS);
 	if (NULL != right)
-		*right = (pi->margin.right > 0.) ? pi->margin.right : 0.;
+		*right = gtk_page_setup_get_right_margin (pi->page_setup, GTK_UNIT_POINTS);
+	if (NULL != edge_to_below_header)
+		*edge_to_below_header = pi->edge_to_below_header;
+	if (NULL != edge_to_above_footer)
+		*edge_to_above_footer = pi->edge_to_above_footer;
 }
 
 void
 print_info_set_margin_header (PrintInformation *pi, double header)
 {
 	g_return_if_fail (pi != NULL);
-	pi->margin.header = header;
+	print_info_load_defaults (pi);
+	g_return_if_fail (pi->page_setup != NULL);
+
+	gtk_page_setup_set_top_margin (pi->page_setup, header, GTK_UNIT_POINTS);
 }
+
 void
 print_info_set_margin_footer (PrintInformation *pi, double footer)
 {
 	g_return_if_fail (pi != NULL);
-	pi->margin.footer = footer;
+	print_info_load_defaults (pi);
+        g_return_if_fail (pi->page_setup != NULL);
+
+        gtk_page_setup_set_bottom_margin (pi->page_setup, footer, GTK_UNIT_POINTS);
 }
+
 void
 print_info_set_margin_left (PrintInformation *pi, double left)
 {
 	g_return_if_fail (pi != NULL);
-	pi->margin.left = left;
+	print_info_load_defaults (pi);
+	g_return_if_fail (pi->page_setup != NULL);
+
+	gtk_page_setup_set_left_margin (pi->page_setup, left, GTK_UNIT_POINTS);
 }
+
 void
 print_info_set_margin_right (PrintInformation *pi, double right)
 {
 	g_return_if_fail (pi != NULL);
-	pi->margin.right = right;
+	print_info_load_defaults (pi);
+	g_return_if_fail (pi->page_setup != NULL);
+
+	gtk_page_setup_set_right_margin (pi->page_setup, right, GTK_UNIT_POINTS);
 }
 
 void
-print_info_set_margins (PrintInformation *pi,
-			double top, double bottom, double left, double right)
+print_info_set_edge_to_above_footer (PrintInformation *pi, double e_f)
 {
-	print_info_set_margin_header (pi, top);
-	print_info_set_margin_footer (pi, bottom);
-	print_info_set_margin_left (pi, left);
-	print_info_set_margin_right (pi, right);
+	g_return_if_fail (pi != NULL);
+	print_info_load_defaults (pi);
+	g_return_if_fail (pi->page_setup != NULL);
+
+	pi->edge_to_above_footer = e_f;
+}
+
+void
+print_info_set_edge_to_below_header (PrintInformation *pi, double e_h)
+{
+	g_return_if_fail (pi != NULL);
+	print_info_load_defaults (pi);
+	g_return_if_fail (pi->page_setup != NULL);
+
+	pi->edge_to_below_header = e_h;
+}
+
+
+void
+print_info_set_margins (PrintInformation *pi,
+			double header, double footer, double left, double right)
+{
+	g_return_if_fail (pi != NULL);
+	print_info_load_defaults (pi);
+	g_return_if_fail (pi->page_setup != NULL);
+
+	if (header >= 0)
+		gtk_page_setup_set_top_margin (pi->page_setup,
+					       header, GTK_UNIT_POINTS);
+	if (footer >= 0)
+		gtk_page_setup_set_bottom_margin (pi->page_setup,
+						  footer, GTK_UNIT_POINTS);
+	if (left >= 0)
+		gtk_page_setup_set_left_margin (pi->page_setup,
+						left, GTK_UNIT_POINTS);
+	if (right >= 0)
+		gtk_page_setup_set_right_margin (pi->page_setup,
+						 right, GTK_UNIT_POINTS);
+}
+
+void
+page_setup_set_paper        (GtkPageSetup *page_setup, char const *paper)
+{
+	GtkPaperSize* gtk_paper;
+
+	g_return_if_fail (page_setup != NULL);
+
+/* We are now using the standard paper names given by PWG 5101.1-2002 */
+/* We are trying to map some old gnome-print paper names.                  */
+
+/*
+ "A4" -> GTK_PAPER_NAME_A4
+ "USLetter" -> GTK_PAPER_NAME_LETTER
+ "USLegal" -> GTK_PAPER_NAME_LEGAL
+ "Executive" -> GTK_PAPER_NAME_EXECUTIVE
+ "A3" -> GTK_PAPER_NAME_A3
+ "A5" -> GTK_PAPER_NAME_A5
+ "B5" -> GTK_PAPER_NAME_B5
+ *  */
+
+	if (g_ascii_strncasecmp ("A4", paper, 2) == 0)
+		paper = GTK_PAPER_NAME_A4;
+	if (g_ascii_strncasecmp ("A3", paper, 2) == 0)
+	        paper = GTK_PAPER_NAME_A3;
+	if (g_ascii_strncasecmp ("A5", paper, 2) == 0)
+		paper = GTK_PAPER_NAME_A5;
+	if (g_ascii_strncasecmp ("B5", paper, 2) == 0)
+		paper = GTK_PAPER_NAME_B5;
+	if (g_ascii_strncasecmp ("USLetter", paper, 8) == 0)
+		paper = GTK_PAPER_NAME_LETTER;
+	if (g_ascii_strncasecmp ("USLegal", paper, 7) == 0)
+		paper = GTK_PAPER_NAME_LEGAL;
+	if (g_ascii_strncasecmp ("Executive", paper, 9) == 0)
+		paper = GTK_PAPER_NAME_EXECUTIVE;
+
+	gtk_paper = gtk_paper_size_new (paper);
+	gtk_page_setup_set_paper_size (page_setup, gtk_paper);
+	gtk_paper_size_free (gtk_paper);
 }
 
 void
 print_info_set_paper (PrintInformation *pi, char const *paper)
 {
 	g_return_if_fail (pi != NULL);
-	g_free (pi->paper);
-	pi->paper = g_strdup (paper);
-}
-void
-print_info_set_paper_width (PrintInformation *pi, char const *paper_width)
-{
-	g_return_if_fail (pi != NULL);
-	g_free (pi->paper_width);
-	pi->paper_width = g_strdup (paper_width);
-}
-void
-print_info_set_paper_height (PrintInformation *pi, char const *paper_height)
-{
-	g_return_if_fail (pi != NULL);
-	g_free (pi->paper_height);
-	pi->paper_height = g_strdup (paper_height);
-}
-char const *
-print_info_get_paper (PrintInformation const *pi)
-{
-	g_return_val_if_fail (pi != NULL, "A4");
-	return pi->paper;
-}
-char const *
-print_info_get_paper_width (PrintInformation const *pi)
-{
-	g_return_val_if_fail (pi != NULL, "210mm");
-	return pi->paper_width;
-}
-char const *
-print_info_get_paper_height (PrintInformation const *pi)
-{
-	g_return_val_if_fail (pi != NULL, "297mm");
-	return pi->paper_height;
+	print_info_load_defaults (pi);
+	page_setup_set_paper (pi->page_setup, paper);
 }
 
-GnomePrintConfig *
-print_info_make_config (PrintInformation const *pi)
+char *
+page_setup_get_paper (GtkPageSetup *page_setup)
 {
-	GnomePrintConfig *res = (NULL != pi->gp_config_str)
-		? gnome_print_config_from_string (pi->gp_config_str, 0)
-		: ((NULL != gnm_app_prefs->printer_config)
-			? gnome_print_config_from_string (gnm_app_prefs->printer_config, 0)
-			: gnome_print_config_default ());
+	GtkPaperSize* paper;
+	char const *name;
 
-	if (NULL != pi->paper) {
-		gnome_print_config_set (res, GNOME_PRINT_KEY_PAPER_SIZE, pi->paper);
-	} else {
-		if ((NULL != pi->paper_width) && (NULL != pi->paper_height)) {
-			gnome_print_config_set (res, GNOME_PRINT_KEY_PAPER_SIZE, "Custom");
-			gnome_print_config_set (res, GNOME_PRINT_KEY_PAPER_WIDTH, pi->paper_width);
-			gnome_print_config_set (res, GNOME_PRINT_KEY_PAPER_HEIGHT, pi->paper_height);
-		}
+	g_return_val_if_fail (page_setup != NULL, g_strdup (GTK_PAPER_NAME_A4));
+
+	paper = gtk_page_setup_get_paper_size (page_setup);
+
+	if (gtk_paper_size_is_custom (paper)) {
+		double width = gtk_paper_size_get_width (paper, GTK_UNIT_MM);
+		double height = gtk_paper_size_get_height (paper, GTK_UNIT_MM);
+		return g_strdup_printf ("custom_Gnm-%.0fx%.0fmm_%.0fx%.0fmm",
+					width, height, width, height);
 	}
-	if (pi->margin.header >= 0)
-		gnome_print_config_set_length (res, GNOME_PRINT_KEY_PAGE_MARGIN_TOP,
-			pi->margin.header, GNOME_PRINT_PS_UNIT);
-	if (pi->margin.footer >= 0)
-		gnome_print_config_set_length (res, GNOME_PRINT_KEY_PAGE_MARGIN_BOTTOM,
-			pi->margin.footer, GNOME_PRINT_PS_UNIT);
-	if (pi->margin.left >= 0)
-		gnome_print_config_set_length (res, GNOME_PRINT_KEY_PAGE_MARGIN_LEFT,
-			pi->margin.left, GNOME_PRINT_PS_UNIT);
-	if (pi->margin.right >= 0)
-		gnome_print_config_set_length (res, GNOME_PRINT_KEY_PAGE_MARGIN_RIGHT,
-			pi->margin.right, GNOME_PRINT_PS_UNIT);
 
-	gnome_print_config_set_int (res, GNOME_PRINT_KEY_NUM_COPIES, pi->n_copies);
-	gnome_print_config_set (res, GNOME_PRINT_KEY_ORIENTATION, pi->portrait_orientation
-		? (pi->invert_orientation ? "R180" : "R0")
-		: (pi->invert_orientation ? "R180" : "R90"));
+	name =  gtk_paper_size_get_name (gtk_page_setup_get_paper_size (page_setup));
+
+/* Working around gtk bug 426416 */
+	if (strncmp (name, "custom", 6) == 0) {
+		double width = gtk_paper_size_get_width (paper, GTK_UNIT_MM);
+		double height = gtk_paper_size_get_height (paper, GTK_UNIT_MM);
+		return g_strdup_printf ("custom_Gnm-%.0fx%.0fmm_%.0fx%.0fmm",
+					width, height, width, height);
+	}
+	return g_strdup (name);
+}
+
+char  *
+print_info_get_paper (PrintInformation *pi)
+{
+	g_return_val_if_fail (pi != NULL, g_strdup (GTK_PAPER_NAME_A4));
+	print_info_load_defaults (pi);
+
+	return page_setup_get_paper (pi->page_setup);
+}
+
+char  const*
+print_info_get_paper_display_name (PrintInformation *pi)
+{
+	GtkPaperSize* paper;
+
+	g_return_val_if_fail (pi != NULL, "ERROR: No printinformation specified");
+	print_info_load_defaults (pi);
+	g_return_val_if_fail (pi->page_setup != NULL, "ERROR: No pagesetup loaded");
+
+	paper = gtk_page_setup_get_paper_size (pi->page_setup);
+	return gtk_paper_size_get_display_name (paper);
+}
+
+double
+print_info_get_paper_width (PrintInformation *pi, GtkUnit unit)
+{
+	g_return_val_if_fail (pi != NULL, 0.);
+	print_info_load_defaults (pi);
+
+	return gtk_page_setup_get_paper_width (pi->page_setup, unit);
+}
+
+double
+print_info_get_paper_height (PrintInformation *pi, GtkUnit unit)
+{
+	g_return_val_if_fail (pi != NULL, 0);
+	print_info_load_defaults (pi);
+
+	return gtk_page_setup_get_paper_height (pi->page_setup, unit);
+}
+
+GtkPageSetup*
+print_info_get_page_setup (PrintInformation *pi)
+{
+	g_return_val_if_fail (pi != NULL, NULL);
+	print_info_load_defaults (pi);
+
+	if (pi->page_setup)
+		return g_object_ref (pi->page_setup);
+	else
+		return NULL;
+}
+
+void
+print_info_set_page_setup (PrintInformation *pi, GtkPageSetup *page_setup)
+{
+	double header, footer, left, right;
+
+	g_return_if_fail (pi != NULL);
+	print_info_load_defaults (pi);
+
+	if (pi->page_setup) {
+		g_object_unref (pi->page_setup);
+		print_info_get_margins (pi, &header, &footer, &left, &right,
+					NULL, NULL);
+		pi->page_setup = page_setup;
+		print_info_set_margins (pi, header, footer, left, right);
+	} else pi->page_setup = page_setup;
+}
+
+GtkPageOrientation
+print_info_get_paper_orientation (PrintInformation *pi)
+{
+	GtkPageOrientation orientation;
+
+	g_return_val_if_fail (pi != NULL, GTK_PAGE_ORIENTATION_PORTRAIT);
+	print_info_load_defaults (pi);
+	g_return_val_if_fail (pi->page_setup != NULL, GTK_PAGE_ORIENTATION_PORTRAIT);
+
+	orientation = gtk_page_setup_get_orientation (pi->page_setup);
+	return orientation;
+}
+
+void
+print_info_set_paper_orientation (PrintInformation *pi,
+				  GtkPageOrientation orientation)
+{
+	g_return_if_fail (pi != NULL);
+	print_info_load_defaults (pi);
+
+	gtk_page_setup_set_orientation (pi->page_setup, orientation);
+}
+
+/**
+ * print_info_set_breaks :
+ * @pi : #PrintInformation
+ * @breaks : #GnmPageBreaks
+ * @is_col : Do @breaks split between columns or rows ?
+ *
+ * NOTE : Takes ownership of @breaks.  DO NOT FREE after calling.
+ **/
+void
+print_info_set_breaks (PrintInformation *pi,
+		       GnmPageBreaks    *breaks)
+{
+	GnmPageBreaks **target;
+
+	g_return_if_fail (pi != NULL);
+
+	target = breaks->is_vert ? &pi->page_breaks.v : &pi->page_breaks.h;
+
+	if (*target == breaks) /* just in case something silly happens */
+		return;
+
+	if (NULL != *target)
+		gnm_page_breaks_free (*target);
+	*target = breaks;
+}
+
+/********************************************************************
+ * Simple data structure to store page breaks defined as a wrapper in case we
+ * need something more extensive later. */
+
+/**
+ * gnm_page_breaks_new :
+ * @len : optional estimate of number of breaks that will be in the collection
+ * @is_vert :
+ *
+ * Allocate a collection of page breaks and provide some sanity checking for
+ * @len.
+ **/
+GnmPageBreaks *
+gnm_page_breaks_new (int len, gboolean is_vert)
+{
+	GnmPageBreaks *res = g_new (GnmPageBreaks, 1);
+
+	if (len < 0 || len > colrow_max (is_vert))
+		len = 0;
+	res->is_vert = is_vert;
+	res->details = g_array_sized_new (FALSE, FALSE,
+		sizeof (GnmPageBreak), len);
 
 	return res;
 }
 
-void
-print_info_load_config (PrintInformation *pi, GnomePrintConfig *config)
+GnmPageBreaks *
+gnm_page_breaks_dup (GnmPageBreaks const *src)
 {
-	guchar *str = NULL;
-	double d_tmp;
-	int tmp;
+	if (src != NULL) {
+		GnmPageBreaks *dst = gnm_page_breaks_new (src->details->len, src->is_vert);
+		GArray       *d_details = dst->details;
+		GArray const *s_details = src->details;
+		unsigned i;
 
-	g_return_if_fail (pi != NULL);
-	g_return_if_fail (config != NULL);
+		/* no need to validate through gnm_page_breaks_append_break, just dup */
+		for (i = 0; i < s_details->len ; i++)
+			g_array_append_val (d_details,
+				g_array_index (s_details, GnmPageBreak, i));
 
-	g_free (pi->gp_config_str);
-	pi->gp_config_str = gnome_print_config_to_string (config, 0);
+		return dst;
+	} else
+		return NULL;
+}
 
-	if (gnome_print_config_get_length (config, GNOME_PRINT_KEY_PAGE_MARGIN_TOP, &d_tmp, NULL))
-		pi->margin.header = d_tmp;
-	if (gnome_print_config_get_length (config, GNOME_PRINT_KEY_PAGE_MARGIN_BOTTOM, &d_tmp, NULL))
-		pi->margin.footer = d_tmp;
-	if (gnome_print_config_get_length (config, GNOME_PRINT_KEY_PAGE_MARGIN_LEFT, &d_tmp, NULL))
-		pi->margin.left = d_tmp;
-	if (gnome_print_config_get_length (config, GNOME_PRINT_KEY_PAGE_MARGIN_RIGHT, &d_tmp, NULL))
-		pi->margin.right = d_tmp;
+void
+gnm_page_breaks_free (GnmPageBreaks *breaks)
+{
+	g_array_free (breaks->details, TRUE);
+	g_free (breaks);
+}
 
-	if (gnome_print_config_get_int (config, GNOME_PRINT_KEY_NUM_COPIES, &tmp))
-		pi->n_copies = tmp;
-	else
-		pi->n_copies = 1;
+gboolean
+gnm_page_breaks_append_break (GnmPageBreaks *breaks,
+			      int pos,
+			      GnmPageBreakType type)
+{
+	GnmPageBreak const *prev;
+	GnmPageBreak info;
 
-	g_free (pi->paper);
-	pi->paper = gnome_print_config_get (config, GNOME_PRINT_KEY_PAPER_SIZE);
+	g_return_val_if_fail (breaks != NULL, FALSE);
 
-	str = gnome_print_config_get (config, GNOME_PRINT_KEY_ORIENTATION);
-	if (str != NULL) {
-		if (strcmp (str, "R0") == 0) {
-			pi->portrait_orientation = TRUE;
-			pi->invert_orientation   = FALSE;
-		} else if (strcmp (str, "R180") == 0) {
-			pi->portrait_orientation = TRUE;
-			pi->invert_orientation   = TRUE;
-		} else if (strcmp (str, "R90") == 0) {
-			pi->portrait_orientation = FALSE;
-			pi->invert_orientation   = FALSE;
-		} else if (strcmp (str, "R270") == 0) {
-			pi->portrait_orientation = FALSE;
-			pi->invert_orientation   = TRUE;
-		}
-		g_free (str);
+	/* Do some simple validation */
+	if (pos < 0)
+		return FALSE;
+	if (breaks->details->len > 0) {
+		prev = &g_array_index (breaks->details, GnmPageBreak,
+			breaks->details->len-1);
+		if (prev->pos >= pos)
+			return FALSE;
 	}
+
+	info.pos   = pos;
+	info.type  = type;
+	g_array_append_val (breaks->details, info);
+
+	return TRUE;
 }
