@@ -11,12 +11,9 @@
 #define SHEET_CONTROL_GUI_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), SHEET_CONTROL_GUI_TYPE))
 #define IS_SHEET_CONTROL_GUI(o)       (G_TYPE_CHECK_INSTANCE_TYPE((o), SHEET_CONTROL_GUI_TYPE))
 
-#define	SHEET_CONTROL_KEY	"SheetControl"
-
 GType		 sheet_control_gui_get_type (void);
-SheetControlGUI *sheet_control_gui_new	    (SheetView *sv, WorkbookControlGUI *wbcg);
+SheetControlGUI *sheet_control_gui_new	    (SheetView *sv, WBCGtk *wbcg);
 
-GtkWidget *scg_toplevel		(SheetControlGUI *scg);
 void scg_take_focus             (SheetControlGUI *scg);
 
 void scg_mode_create_object	(SheetControlGUI *scg, SheetObject *so);
@@ -29,16 +26,16 @@ void scg_object_anchor_to_coords (SheetControlGUI const *scg,
 void scg_object_coords_to_anchor (SheetControlGUI const *scg,
 				  double const *coords, SheetObjectAnchor *in_out);
 
-void scg_objects_drag		(SheetControlGUI *scg, GnmCanvas *gcanvas,
+void scg_objects_drag		(SheetControlGUI *scg, GnmPane *gcanvas,
 				 SheetObject *primary,
 				 gdouble *dx, gdouble *dy,
 				 int drag_type, gboolean symmetric, gboolean snap_to_grid,
 				 gboolean is_mouse_move);
 void scg_objects_drag_commit	(SheetControlGUI *scg, int drag_type,
 				 gboolean created_objects);
-void scg_objects_nudge		(SheetControlGUI *scg, GnmCanvas *gcanvas,
+void scg_objects_nudge		(SheetControlGUI *scg, GnmPane *gcanvas,
 				 int drag_type, double dx, double dy,
-				 gboolean symmetric, 
+				 gboolean symmetric,
 				 gboolean snap_to_grid);
 
 void scg_object_select		(SheetControlGUI *scg, SheetObject *so);
@@ -87,28 +84,35 @@ gboolean scg_special_cursor_bound_set (SheetControlGUI *scg, GnmRange const *r);
 void scg_set_left_col		(SheetControlGUI *scg, int new_first_col);
 void scg_set_top_row		(SheetControlGUI *scg, int new_first_row);
 
-void scg_colrow_resize_stop	(SheetControlGUI *scg);
-void scg_colrow_resize_start	(SheetControlGUI *scg,
-				 gboolean is_cols, int resize_first);
-void scg_colrow_resize_move	(SheetControlGUI *scg,
-				 gboolean is_cols, int resize_last);
+void scg_size_guide_start	(SheetControlGUI *scg, gboolean vert,
+				 int colrow, int width);
+void scg_size_guide_motion	(SheetControlGUI *scg, gboolean vert,
+				 int guide_pos);
+void scg_size_guide_stop	(SheetControlGUI *scg);
 
 typedef void (*SCGUIMoveFunc)	(SheetControlGUI *, int n,
 				 gboolean jump, gboolean horiz);
 void scg_queue_movement		(SheetControlGUI *scg,
 				 SCGUIMoveFunc	  handler,
 				 int n, gboolean jump, gboolean horiz);
-void  scg_paste_image (SheetControlGUI *scg, GnmRange *where, 
+void  scg_paste_image (SheetControlGUI *scg, GnmRange *where,
 		       guint8 const *data, unsigned len);
 void scg_drag_data_received (SheetControlGUI *scg, GtkWidget *source_widget,
-			     double x, double y, 
+			     double x, double y,
 			     GtkSelectionData *selection_data);
-void scg_drag_data_get      (SheetControlGUI *scg, 
+void scg_drag_data_get      (SheetControlGUI *scg,
 			     GtkSelectionData *selection_data);
 
+void scg_delete_sheet_if_possible (SheetControlGUI *scg);
+
+/* Convenience wrappers.  */
+SheetView	*scg_view	(SheetControlGUI const *scg);
+Sheet		*scg_sheet	(SheetControlGUI const *scg);
+WorkbookControl *scg_wbc	(SheetControlGUI const *scg);
+
 /* DO NOT USE THIS WITHOUT ALOT OF THOUGHT */
-GnmCanvas	   *scg_pane		(SheetControlGUI *scg, int pane);
+GnmPane	   *scg_pane		(SheetControlGUI *scg, int pane);
 
-WorkbookControlGUI *scg_get_wbcg	(SheetControlGUI const *scg);
+WBCGtk *scg_wbcg	(SheetControlGUI const *scg);
 
 #endif /* GNUMERIC_SHEET_CONTROL_GUI_H */
