@@ -14,8 +14,6 @@ struct _SheetControl {
 typedef struct {
 	GObjectClass   object_class;
 
-	void (*init_state) (SheetControl *sc);
-
 	void (*resize)			(SheetControl *sc, gboolean force_scroll);
 	void (*redraw_all)		(SheetControl *sc, gboolean headers);
 	void (*redraw_range)		(SheetControl *sc, GnmRange const *r);
@@ -27,7 +25,7 @@ typedef struct {
 	void (*scrollbar_config)	(SheetControl const *sc);
 	void (*mode_edit)		(SheetControl *sc);
 	void (*set_top_left)		(SheetControl *sc, int col, int row);
-	void (*compute_visible_region)	(SheetControl *sc,
+	void (*recompute_visible_region)(SheetControl *sc,
 					 gboolean full_recompute);
 	void (*make_cell_visible)	(SheetControl  *sc, int col, int row,
 					 gboolean couple_panes);
