@@ -88,6 +88,7 @@ gnm_filter_condition_new_bucket (gboolean top, gboolean absolute, float n)
 {
 	GnmFilterCondition *res = g_new0 (GnmFilterCondition, 1);
 	res->op[0] = GNM_FILTER_OP_TOP_N | (top ? 0 : 1) | (absolute ? 0 : 2);
+	res->op[1] = GNM_FILTER_UNUSED;
 	res->count = n;
 	return res;
 }
@@ -137,7 +138,7 @@ filter_expr_init (FilterExpr *fexpr, unsigned i,
 {
 	GnmValue *tmp = cond->value[i];
 
-	if (VALUE_IS_STRING (tmp)) {
+	if (tmp && VALUE_IS_STRING (tmp)) {
 		GnmFilterOp op = cond->op[i];
 		char const *str = value_peek_string (tmp);
 		GODateConventions const *date_conv =
@@ -173,7 +174,7 @@ filter_expr_eval (GnmFilterOp op, GnmValue const *src, GORegexp const *regexp,
 	GnmValDiff cmp;
 
 	if (src == NULL) {
-		GOFormat const *format = gnm_cell_get_format (cell);			
+		GOFormat const *format = gnm_cell_get_format (cell);
 		GODateConventions const *date_conv =
 			workbook_date_conv (cell->base.sheet->workbook);
 		char *str = format_value (format, target, NULL, -1, date_conv);
@@ -372,21 +373,29 @@ cb_hide_unwanted_percentage (GnmCellIter const *iter,
 void
 gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 {
-	GnmFilter const *filter = fcombo->filter;
-	GnmFilterCondition const *cond = fcombo->cond;
-	int const col = sheet_object_get_range (SHEET_OBJECT (fcombo))->start.col;
-	int const start_row = filter->r.start.row + 1;
-	int const end_row = filter->r.end.row;
+	GnmFilter const *filter;
+	GnmFilterCondition const *cond;
+	int col, start_row, end_row;
 	CellIterFlags iter_flags = CELL_ITER_IGNORE_HIDDEN;
 
+	g_return_if_fail (IS_GNM_FILTER_COMBO (fcombo));
+
+	filter = fcombo->filter;
+	cond = fcombo->cond;
+	col = sheet_object_get_range (SHEET_OBJECT (fcombo))->start.col;
+	start_row = filter->r.start.row + 1;
+	end_row = filter->r.end.row;
+
 	if (start_row > end_row ||
 	    cond == NULL ||
 	    cond->op[0] == GNM_FILTER_UNUSED)
 		return;
 
-	/* For the combo we filter a temporary sheet using the data from filter->sheet
-	 * and need to include everything from the source, because it has a
-	 * different set of conditions */
+	/*
+	 * For the combo we filter a temporary sheet using the data from
+	 * filter->sheet and need to include everything from the source,
+	 * because it has a different set of conditions
+	 */
 	if (target_sheet != filter->sheet)
 		iter_flags = CELL_ITER_ALL;
 
@@ -399,7 +408,7 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 			filter_expr_init (&data, 1, cond, filter);
 
 		sheet_foreach_cell_in_range (filter->sheet,
-			(target_sheet == filter->sheet) ? CELL_ITER_IGNORE_HIDDEN : CELL_ITER_ALL,
+			iter_flags,
 			col, start_row, col, end_row,
 			(CellIterFunc) cb_filter_expr, &data);
 
@@ -785,23 +794,23 @@ gnm_sheet_filter_guess_region (Sheet *sheet, GnmRange *region)
 	int col;
 	int end_row;
 	int offset;
-	
+
 	/* check in case only one cell selected */
 	if (region->start.col == region->end.col) {
 		int start = region->start.col;
 		/* look for previous empty column */
 		for (col = start - 1; col > 0; col--)
-			if (!sheet_cell_or_one_below_is_not_empty (sheet, col, region->start.row)) 
+			if (!sheet_cell_or_one_below_is_not_empty (sheet, col, region->start.row))
 				break;
 		region->start.col = col - 1;
 
 		/* look for next empty column */
 		for (col = start + 1; col < SHEET_MAX_COLS; col++)
-			if (!sheet_cell_or_one_below_is_not_empty (sheet, col, region->start.row)) 
+			if (!sheet_cell_or_one_below_is_not_empty (sheet, col, region->start.row))
 				break;
 		region->end.col = col - 1;
-	}		
-	
+	}
+
 	/* find first and last non-empty cells in region */
 	for (col = region->start.col; col <= region->end.col; col++)
 		if (sheet_cell_or_one_below_is_not_empty (sheet, col, region->start.row))
@@ -810,12 +819,12 @@ gnm_sheet_filter_guess_region (Sheet *sheet, GnmRange *region)
 	if (col > region->end.col)
 		return; /* all empty -- give up */
 	region->start.col = col;
-	
+
 	for (col = region->end.col; col >= region->start.col; col--)
 		if (sheet_cell_or_one_below_is_not_empty(sheet, col, region->start.row))
 			break;
 	region->end.col = col;
-	
+
 	/* now find length of longest column */
 	for (col = region->start.col; col <= region->end.col; col++) {
 		offset = 0;
@@ -823,7 +832,7 @@ gnm_sheet_filter_guess_region (Sheet *sheet, GnmRange *region)
 			offset = 1;
 		end_row = sheet_find_boundary_vertical (sheet, col,
 			region->start.row + offset, col, 1, TRUE);
-		if (end_row > region->end.row) 
+		if (end_row > region->end.row)
 			region->end.row = end_row;
 	}
 }
