@@ -8,10 +8,6 @@
 #include <glib-object.h>
 #include <gtk/gtkmenu.h>
 
-#ifdef WITH_GNOME_PRINT
-#include <libgnomeprint/gnome-print.h>
-#endif
-
 typedef enum {
 	SHEET_OBJECT_IS_VISIBLE	= 1 << 0,	/* user selectable */
 	SHEET_OBJECT_PRINT	= 1 << 1,
@@ -36,7 +32,7 @@ typedef struct {
 	char const *icon;	/* optionally NULL */
 	char const *label;	/* NULL for separators */
 	char const *msg_domain;	/* for plugins to specify translations */
-	int  submenu;		/* > 1 starts a menu, < 1 end one */ 
+	int  submenu;		/* > 1 starts a menu, < 1 end one */
 	SheetObjectActionFunc	func;
 } SheetObjectAction;
 
@@ -65,16 +61,6 @@ typedef struct {
 	void      (*prep_sax_parser) (SheetObject *so,
 				      GsfXMLIn *xin, xmlChar const **attrs);
 	void        (*write_xml_sax) (SheetObject const *so, GsfXMLOut *output);
-
-	/* Called with 0,0 set to the top, left corner of the object, and the
-	 * graphics context saved */
-#ifdef WITH_GNOME_PRINT
-	void                (*print) (SheetObject const *so,
-				      GnomePrintContext *ctx,
-				      double width, double height);
-#else
-	void                *print;
-#endif
 	void		    (*copy)  (SheetObject *dst,
 				      SheetObject const *src);
 
@@ -149,10 +135,12 @@ typedef struct {
 				  double const *input, SheetObjectAnchor *output);
 } SheetObjectViewContainerIface;
 
+#if 0
 void so_vc_anchor_to_coords (SheetObjectViewContainer *sovc,
 			     SheetObjectAnchor const *input, double *output);
 void so_vc_coords_to_anchor (SheetObjectViewContainer *sovc,
 			     double const *input, SheetObjectAnchor *output);
+#endif
 
 /***************************************************************************/
 
@@ -160,10 +148,10 @@ struct _SheetObjectImageableIface {
 	GTypeInterface base;
 
 	GtkTargetList *(*get_target_list) (SheetObject const *so);
-	void           (*write_image)	  (SheetObject const *so, 
+	void           (*write_image)	  (SheetObject const *so,
 					   char const *format,
 					   double resolution,
-					   GsfOutput *output, 
+					   GsfOutput *output,
 					   GError **err);
 };
 
@@ -173,7 +161,7 @@ struct _SheetObjectExportableIface {
 	GTypeInterface base;
 
 	GtkTargetList *(*get_target_list) (SheetObject const *so);
-	void           (*write_object)	  (SheetObject const *so, 
+	void           (*write_object)	  (SheetObject const *so,
 					   char const *format,
 					   GsfOutput *output, GError **err);
 };
