@@ -25,10 +25,10 @@
 #include "gnumeric.h"
 #include "sheet-object-widget.h"
 
+#include "gnm-pane.h"
+#include "gnumeric-simple-canvas.h"
 #include "gui-util.h"
 #include "dependent.h"
-#include "gnumeric-canvas.h"
-#include "gnumeric-pane.h"
 #include "sheet-control-gui.h"
 #include "sheet-object-impl.h"
 #include "expr.h"
@@ -36,7 +36,7 @@
 #include "value.h"
 #include "ranges.h"
 #include "selection.h"
-#include "workbook-edit.h"
+#include "wbc-gtk.h"
 #include "workbook.h"
 #include "sheet.h"
 #include "cell.h"
@@ -209,11 +209,10 @@ read_dep (GnmDependent *dep, char const *name,
 static SheetObjectView *
 sheet_object_widget_new_view (SheetObject *so, SheetObjectViewContainer *container)
 {
-	GnmCanvas *gcanvas = ((GnmPane *)container)->gcanvas;
 	GtkWidget *view_widget =
 		SOW_CLASS(so)->create_widget (SHEET_OBJECT_WIDGET (so));
 	FooCanvasItem *view_item = foo_canvas_item_new (
-		gcanvas->object_views,
+		gnm_pane_object_group (GNM_PANE (container)),
 		so_widget_foo_view_get_type (),
 		"widget", view_widget,
 		"size_pixels", FALSE,
@@ -351,7 +350,7 @@ typedef struct {
   	char               *old_label;
   	GtkWidget          *old_focus;
 
-  	WorkbookControlGUI *wbcg;
+  	WBCGtk *wbcg;
   	SheetWidgetFrame   *swf;
   	Sheet		   *sheet;
 } FrameConfigState;
@@ -361,8 +360,6 @@ cb_frame_config_destroy (FrameConfigState *state)
 {
  	g_return_if_fail (state != NULL);
 
- 	wbcg_edit_detach_guru (state->wbcg);
-
  	if (state->gui != NULL) {
  		g_object_unref (G_OBJECT (state->gui));
  		state->gui = NULL;
@@ -421,7 +418,7 @@ static void
 sheet_widget_frame_user_config (SheetObject *so, SheetControl *sc)
 {
   	SheetWidgetFrame *swf = SHEET_WIDGET_FRAME (so);
-  	WorkbookControlGUI   *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
+  	WBCGtk   *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
   	FrameConfigState *state;
   	GtkWidget *table;
 
@@ -461,9 +458,6 @@ sheet_widget_frame_user_config (SheetObject *so, SheetControl *sc)
 			  "clicked",
 			  G_CALLBACK (cb_frame_config_cancel_clicked), state);
 
-	g_object_set_data_full (G_OBJECT (state->dialog),
-		"state", state, (GDestroyNotify) cb_frame_config_destroy);
-
   	gnumeric_init_help_button (
   		glade_xml_get_widget (state->gui, "help_button"),
   		GNUMERIC_HELP_LINK_SO_FRAME);
@@ -472,7 +466,9 @@ sheet_widget_frame_user_config (SheetObject *so, SheetControl *sc)
   	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
   			       SHEET_OBJECT_CONFIG_KEY);
 
-  	wbcg_edit_attach_guru (state->wbcg, state->dialog);
+  	wbc_gtk_attach_guru (state->wbcg, state->dialog);
+	g_object_set_data_full (G_OBJECT (state->dialog),
+		"state", state, (GDestroyNotify) cb_frame_config_destroy);
 
   	gtk_widget_show (state->dialog);
 }
@@ -867,7 +863,7 @@ typedef struct {
 
 	GtkWidget          *old_focus;
 
-	WorkbookControlGUI *wbcg;
+	WBCGtk *wbcg;
 	SheetWidgetAdjustment *swa;
 	Sheet		   *sheet;
 } AdjustmentConfigState;
@@ -876,12 +872,11 @@ static void
 cb_adjustment_set_focus (GtkWidget *window, GtkWidget *focus_widget,
 			 AdjustmentConfigState *state)
 {
-	/* Note:  half of the set-focus action is handle by the default */
-	/*        callback installed by wbcg_edit_attach_guru           */
+	/* Note:  half of the set-focus action is handle by the default
+	 *        callback installed by wbc_gtk_attach_guru. */
 
-	/* Force an update of the content in case it
-	 * needs tweaking (eg make it absolute)
-	 */
+	/* Force an update of the content in case it needs tweaking (eg make it
+	 * absolute) */
 	if (state->old_focus != NULL &&
 	    IS_GNM_EXPR_ENTRY (state->old_focus->parent)) {
 		GnmParsePos  pp;
@@ -900,8 +895,6 @@ cb_adjustment_config_destroy (AdjustmentConfigState *state)
 {
 	g_return_if_fail (state != NULL);
 
-	wbcg_edit_detach_guru (state->wbcg);
-
 	if (state->gui != NULL) {
 		g_object_unref (G_OBJECT (state->gui));
 		state->gui = NULL;
@@ -949,7 +942,7 @@ static void
 sheet_widget_adjustment_user_config (SheetObject *so, SheetControl *sc)
 {
 	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (so);
-	WorkbookControlGUI   *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
+	WBCGtk   *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
 	AdjustmentConfigState *state;
 	GtkWidget *table;
 
@@ -1010,8 +1003,6 @@ sheet_widget_adjustment_user_config (SheetObject *so, SheetControl *sc)
 		"clicked",
 		G_CALLBACK (cb_adjustment_config_cancel_clicked), state);
 
-	g_object_set_data_full (G_OBJECT (state->dialog),
-		"state", state, (GDestroyNotify) cb_adjustment_config_destroy);
 	gnumeric_init_help_button (
 		glade_xml_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_SO_ADJUSTMENT);
@@ -1019,11 +1010,13 @@ sheet_widget_adjustment_user_config (SheetObject *so, SheetControl *sc)
 	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
 			       SHEET_OBJECT_CONFIG_KEY);
 
-	wbcg_edit_attach_guru (state->wbcg, state->dialog);
+	wbc_gtk_attach_guru (state->wbcg, state->dialog);
+	g_object_set_data_full (G_OBJECT (state->dialog),
+		"state", state, (GDestroyNotify) cb_adjustment_config_destroy);
+
 	/* Note:  half of the set-focus action is handle by the default */
-	/*        callback installed by wbcg_edit_attach_guru           */
-	g_signal_connect (G_OBJECT (state->dialog),
-		"set-focus",
+	/*        callback installed by wbc_gtk_attach_guru           */
+	g_signal_connect (G_OBJECT (state->dialog), "set-focus",
 		G_CALLBACK (cb_adjustment_set_focus), state);
 
 	gtk_widget_show (state->dialog);
@@ -1230,7 +1223,7 @@ sheet_widget_spinbutton_create_widget (SheetObjectWidget *sow)
 
 static void
 sheet_widget_spinbutton_class_init (SheetObjectWidgetClass *sow_class)
-{                                                                         
+{
         sow_class->create_widget = &sheet_widget_spinbutton_create_widget;
 }
 
@@ -1273,7 +1266,7 @@ sheet_widget_slider_create_widget (SheetObjectWidget *sow)
 
 static void
 sheet_widget_slider_class_init (SheetObjectWidgetClass *sow_class)
-{                                                                         
+{
         sow_class->create_widget = &sheet_widget_slider_create_widget;
 }
 
@@ -1507,7 +1500,7 @@ typedef struct {
 	char *old_label;
 	GtkWidget *old_focus;
 
-	WorkbookControlGUI  *wbcg;
+	WBCGtk  *wbcg;
 	SheetWidgetCheckbox *swc;
 	Sheet		    *sheet;
 } CheckboxConfigState;
@@ -1516,12 +1509,11 @@ static void
 cb_checkbox_set_focus (GtkWidget *window, GtkWidget *focus_widget,
 		       CheckboxConfigState *state)
 {
-	/* Note:  have of the set-focus action is handle by the default */
-	/*        callback installed by wbcg_edit_attach_guru           */
+	/* Note:  half of the set-focus action is handle by the default
+	 *        callback installed by wbc_gtk_attach_guru */
 
-	/* Force an update of the content in case it
-	 * needs tweaking (eg make it absolute)
-	 */
+	/* Force an update of the content in case it needs tweaking (eg make it
+	 * absolute) */
 	if (state->old_focus != NULL &&
 	    IS_GNM_EXPR_ENTRY (state->old_focus->parent)) {
 		GnmParsePos  pp;
@@ -1540,8 +1532,6 @@ cb_checkbox_config_destroy (CheckboxConfigState *state)
 {
 	g_return_if_fail (state != NULL);
 
-	wbcg_edit_detach_guru (state->wbcg);
-
 	if (state->gui != NULL) {
 		g_object_unref (G_OBJECT (state->gui));
 		state->gui = NULL;
@@ -1589,7 +1579,7 @@ static void
 sheet_widget_checkbox_user_config (SheetObject *so, SheetControl *sc)
 {
 	SheetWidgetCheckbox *swc = SHEET_WIDGET_CHECKBOX (so);
-	WorkbookControlGUI  *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
+	WBCGtk  *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
 	CheckboxConfigState *state;
 	GtkWidget *table;
 
@@ -1642,8 +1632,6 @@ sheet_widget_checkbox_user_config (SheetObject *so, SheetControl *sc)
 		"clicked",
 		G_CALLBACK (cb_checkbox_config_cancel_clicked), state);
 
-	g_object_set_data_full (G_OBJECT (state->dialog),
-		"state", state, (GDestroyNotify) cb_checkbox_config_destroy);
 	gnumeric_init_help_button (
 		glade_xml_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_SO_CHECKBOX);
@@ -1651,11 +1639,13 @@ sheet_widget_checkbox_user_config (SheetObject *so, SheetControl *sc)
 	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
 			       SHEET_OBJECT_CONFIG_KEY);
 
-	wbcg_edit_attach_guru (state->wbcg, state->dialog);
+	wbc_gtk_attach_guru (state->wbcg, state->dialog);
+	g_object_set_data_full (G_OBJECT (state->dialog),
+		"state", state, (GDestroyNotify) cb_checkbox_config_destroy);
+
 	/* Note:  half of the set-focus action is handle by the default */
-	/*        callback installed by wbcg_edit_attach_guru           */
-	g_signal_connect (G_OBJECT (state->dialog),
-		"set-focus",
+	/*        callback installed by wbc_gtk_attach_guru */
+	g_signal_connect (G_OBJECT (state->dialog), "set-focus",
 		G_CALLBACK (cb_checkbox_set_focus), state);
 
 	gtk_widget_show (state->dialog);
@@ -2094,7 +2084,7 @@ sheet_widget_list_base_set_selection (SheetWidgetListBase *swl, int selection,
 			selection = n;
 	} else
 		selection = 0;
-	
+
 	if (swl->selection != selection) {
 		swl->selection = selection;
 		if (NULL!= wbc &&
@@ -2427,7 +2417,7 @@ sheet_widget_list_create_widget (SheetObjectWidget *sow)
 
 static void
 sheet_widget_list_class_init (SheetObjectWidgetClass *sow_class)
-{                                                                         
+{
         sow_class->create_widget = &sheet_widget_list_create_widget;
 }
 
@@ -2458,8 +2448,14 @@ static void
 cb_combo_model_changed (SheetWidgetListBase *swl, GtkComboBox *combo)
 {
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), swl->model);
-	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
-	cb_combo_selection_changed (swl, combo); /* for entry to reload */
+
+	/* we can not set this until we have a model,
+	 * but after that we can not reset it */
+	if (gtk_combo_box_entry_get_text_column (GTK_COMBO_BOX_ENTRY (combo)) < 0)
+		gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
+
+	/* force entry to reload */
+	cb_combo_selection_changed (swl, combo);
 }
 
 static void
@@ -2496,7 +2492,7 @@ sheet_widget_combo_create_widget (SheetObjectWidget *sow)
 
 static void
 sheet_widget_combo_class_init (SheetObjectWidgetClass *sow_class)
-{                                                                         
+{
         sow_class->create_widget = &sheet_widget_combo_create_widget;
 }
 
