@@ -26,6 +26,7 @@ struct _SheetView {
 	GSList		*selections;
 	GnmCellPos	 edit_pos;	/* Cell that would be edited */
 	GnmCellPos	 edit_pos_real;	/* Even in the middle of a merged cell */
+	int		 first_tab_col;	/* where to jump to after an Enter */
 
 	struct {
 		/* Static corner to rubber band the selection range around */
@@ -53,7 +54,7 @@ struct _SheetView {
 	struct {
 		unsigned char location;
 		unsigned char content; /* entered content NOT value */
-		unsigned char format;
+		unsigned char style;
 	} edit_pos_changed;
 	guint            auto_expr_timer;
 };
@@ -86,7 +87,7 @@ gboolean      sv_is_region_empty_or_selected (SheetView const *sv,
 /* Manipulation */
 void	 sv_flag_status_update_pos   (SheetView *sv, GnmCellPos const *pos);
 void	 sv_flag_status_update_range (SheetView *sv, GnmRange const *r);
-void	 sv_flag_format_update_range (SheetView *sv, GnmRange const *r);
+void	 sv_flag_style_update_range  (SheetView *sv, GnmRange const *r);
 void	 sv_flag_selection_change    (SheetView *sv);
 
 void	 sv_unant		(SheetView *sv);
