@@ -16,6 +16,7 @@
 #include "parse-util.h"
 #include "workbook.h"
 #include "libgnumeric.h"
+#include "gutils.h"
 #include "gnumeric-paths.h"
 #include "gnm-plugin.h"
 #include "command-context.h"
@@ -43,7 +44,7 @@ static char *ssconvert_import_id = NULL;
 static char *ssconvert_export_id = NULL;
 static char **ssconvert_goal_seek = NULL;
 
-static const GOptionEntry ssconvert_options [] = { 
+static const GOptionEntry ssconvert_options [] = {
 	{
 		"version", 'v',
 		0, G_OPTION_ARG_NONE, &ssconvert_show_version,
@@ -53,22 +54,6 @@ static const GOptionEntry ssconvert_options [] = {
 
 	/* ---------------------------------------- */
 
-	{
-		"lib-dir", 'L',
-		0, G_OPTION_ARG_FILENAME, &gnumeric_lib_dir,
-		N_("Set the root library directory"),
-		N_("DIR")
-	},
-
-	{
-		"data-dir", 'D',
-		0, G_OPTION_ARG_FILENAME, &gnumeric_data_dir,
-		N_("Adjust the root data directory"),
-		N_("DIR")
-	},
-
-	/* ---------------------------------------- */
-
 	{
 		"import-encoding", 'E',
 		0, G_OPTION_ARG_STRING, &ssconvert_import_encoding,
@@ -140,7 +125,7 @@ static const GOptionEntry ssconvert_options [] = {
 
 	/* ---------------------------------------- */
 
-	{ NULL } 
+	{ NULL }
 };
 
 static void
@@ -255,7 +240,7 @@ convert (char const *inarg, char const *outarg,
 				      "Try --list-importers to see a list of possibilities.\n"),
 				    ssconvert_import_id);
 			goto out;
-		} 
+		}
 	}
 
 	if (fs != NULL) {
@@ -319,14 +304,15 @@ main (int argc, char const **argv)
 	int		 res = 0;
 	GOCmdContext	*cc;
 	GOptionContext *ocontext;
-	GError *error = NULL;	
+	GError *error = NULL;
 
 	/* No code before here, we need to init threads */
 	argv = gnm_pre_parse_init (argc, argv);
 
 	ocontext = g_option_context_new (_("INFILE [OUTFILE]"));
 	g_option_context_add_main_entries (ocontext, ssconvert_options, GETTEXT_PACKAGE);
-	g_option_context_parse (ocontext, &argc, (char **)&argv, &error);
+	g_option_context_add_group	  (ocontext, gnm_get_option_group ());
+	g_option_context_parse (ocontext, &argc, (char ***)&argv, &error);
 	g_option_context_free (ocontext);
 
 	if (error) {
