@@ -23,7 +23,7 @@
 */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "reports.h"
 
 #include "parse-util.h"
@@ -41,6 +41,7 @@
 #include "analysis-tools.h"
 #include "api.h"
 #include "gutils.h"
+#include <goffice/utils/go-glib-extras.h>
 
 #include <math.h>
 #include <stdlib.h>
@@ -74,10 +75,8 @@ solver_param_new (void)
 void
 solver_param_destroy (SolverParameters *sp)
 {
-	g_slist_foreach	(sp->constraints,
-			 (GFunc)solver_constraint_destroy,
-			 NULL);
-	g_slist_free (sp->constraints);
+	go_slist_free_custom (sp->constraints,
+			      (GFreeFunc)solver_constraint_destroy);
 	g_slist_free (sp->input_cells);
 	g_free (sp->input_entry_str);
 	g_free (sp->options.scenario_name);
@@ -259,14 +258,14 @@ get_lp_coeff (GnmCell *target, GnmCell *change)
 {
         gnm_float x0, x1;
 
-	cell_set_value (change, value_new_float (0.0));
+	gnm_cell_set_value (change, value_new_float (0.0));
 	cell_queue_recalc (change);
-	cell_eval (target);
+	gnm_cell_eval (target);
 	x0 = value_get_as_float (target->value);
 
-	cell_set_value (change, value_new_float (1.0));
+	gnm_cell_set_value (change, value_new_float (1.0));
 	cell_queue_recalc (change);
-	cell_eval (target);
+	gnm_cell_eval (target);
 	x1 = value_get_as_float (target->value);
 
 	return x1 - x0;
@@ -302,25 +301,15 @@ save_original_values (SolverResults          *res,
 	res->original_value_of_obj_fn = value_get_as_float (cell->value);
 }
 
-/*
- * Restores the original values of the input variables.
- */
 static void
 restore_original_values (SolverResults *res)
 {
-  
-	GSList   *inputs = res->param->input_cells;
-	GnmCell  *cell;
-	int      i = 0;
+	GSList *ptr;
+	int     i = 0;
 
-	while (inputs != NULL) {
-	        cell = (GnmCell *) inputs->data;
-
-		sheet_cell_set_value (cell,
-				      value_new_float(res->original_values[i]));
-		inputs = inputs->next;
-		i++;
-	}
+	for (ptr = res->param->input_cells; ptr != NULL ; ptr = ptr->next)
+		sheet_cell_set_value (ptr->data,
+			value_new_float (res->original_values[i++]));
 }
 
 /************************************************************************
@@ -374,7 +363,7 @@ lp_qp_solver_init (Sheet *sheet, const SolverParameters *param,
 	target = solver_get_target_cell (sheet);
 	clear_input_vars (param->n_variables, res);
 
-	cell_eval (target);
+	gnm_cell_eval (target);
 
 	if (param->options.model_type == SolverLPModel) {
 	        for (i = 0; i < param->n_variables; i++) {
@@ -404,7 +393,7 @@ lp_qp_solver_init (Sheet *sheet, const SolverParameters *param,
 
 		target = sheet_cell_get (sheet, c->lhs.col, c->lhs.row);
 		if (target) {
-			cell_eval (target);
+			gnm_cell_eval (target);
 			val = target->value;
 		} else
 			val = NULL;
@@ -447,7 +436,7 @@ lp_qp_solver_init (Sheet *sheet, const SolverParameters *param,
 
 		target = sheet_cell_get (sheet, c->rhs.col, c->rhs.row);
 		if (target) {
-			cell_eval (target);
+			gnm_cell_eval (target);
 			val = target->value;
 		} else
 			val = NULL;
@@ -760,10 +749,12 @@ solver_lp_copy (const SolverParameters *src_param, Sheet *new_sheet)
 
 	/* Copy the input cell list */
 	for (inputs = src_param->input_cells; inputs ; inputs = inputs->next) {
-		GnmCell *new_cell = cell_dup (inputs->data);
-		new_cell->base.sheet = new_sheet;
-		dst_param->input_cells = g_slist_prepend (
-			dst_param->input_cells, (gpointer) new_cell);
+		GnmCell const *old_cell = inputs->data;
+		GnmCell *new_cell = sheet_cell_fetch (new_sheet,
+						      old_cell->pos.col,
+						      old_cell->pos.row);
+		dst_param->input_cells =
+			g_slist_prepend (dst_param->input_cells, new_cell);
 	}
 	dst_param->input_cells = g_slist_reverse (dst_param->input_cells);
 
@@ -833,17 +824,14 @@ solver_insert_cols (Sheet *sheet, int col, int count)
 
 	/* Adjust the input range. */
 	input_range = value_new_cellrange_str (sheet, param->input_entry_str);
-	if (input_range != NULL) {
-	        if (input_range->v_range.cell.a.col >= col) {
-		        range.start.col = input_range->v_range.cell.a.col +
-			        count;
-		        range.start.row = input_range->v_range.cell.a.row;
-		        range.end.col   = input_range->v_range.cell.b.col +
-			        count;
-		        range.end.row   = input_range->v_range.cell.b.row;
-			param->input_entry_str =
-			        g_strdup (global_range_name (sheet, &range));
-		}
+	if (input_range != NULL &&
+	    input_range->v_range.cell.a.col >= col) {
+		range.start.col = input_range->v_range.cell.a.col + count;
+		range.start.row = input_range->v_range.cell.a.row;
+		range.end.col   = input_range->v_range.cell.b.col + count;
+		range.end.row   = input_range->v_range.cell.b.row;
+		param->input_entry_str = g_strdup (
+			global_range_name (sheet, &range));
 	}
 
 	/* Adjust the constraints. */
@@ -876,21 +864,17 @@ solver_delete_rows (Sheet *sheet, int row, int count)
 
 	/* Adjust the input range. */
 	input_range = value_new_cellrange_str (sheet, param->input_entry_str);
-	if (input_range != NULL) {
-	        if (input_range->v_range.cell.a.row >= row) {
-		        range.start.col = input_range->v_range.cell.a.col;
-		        range.start.row = input_range->v_range.cell.a.row -
-			        count;
-		        range.end.col   = input_range->v_range.cell.b.col;
-		        range.end.row   = input_range->v_range.cell.b.row -
-			        count;
-			if (range.start.row < row || range.end.row < row)
-			        param->input_entry_str = g_strdup ("");
-			else
-			        param->input_entry_str =
-				         g_strdup (global_range_name (sheet,
-								      &range));
-		}
+	if (input_range != NULL &&
+	    input_range->v_range.cell.a.row >= row) {
+		range.start.col = input_range->v_range.cell.a.col;
+		range.start.row = input_range->v_range.cell.a.row - count;
+		range.end.col   = input_range->v_range.cell.b.col;
+		range.end.row   = input_range->v_range.cell.b.row - count;
+		if (range.start.row < row || range.end.row < row)
+			param->input_entry_str = g_strdup ("");
+		else
+			param->input_entry_str = g_strdup (
+				global_range_name (sheet, &range));
 	}
 
 	/* Adjust the constraints. */
