@@ -26,33 +26,33 @@ value_dump (GnmValue const *value)
 {
 	switch (value->type){
 	case VALUE_EMPTY:
-		printf ("EMPTY\n");
+		g_print ("EMPTY\n");
 		break;
 
 	case VALUE_ERROR:
-		printf ("ERROR: %s\n", value->v_err.mesg->str);
+		g_print ("ERROR: %s\n", value->v_err.mesg->str);
 		break;
 
 	case VALUE_BOOLEAN:
-		printf ("BOOLEAN: %s\n", go_locale_boolean_name (value->v_bool.val));
+		g_print ("BOOLEAN: %s\n", go_locale_boolean_name (value->v_bool.val));
 		break;
 
 	case VALUE_STRING:
-		printf ("STRING: %s\n", value->v_str.val->str);
+		g_print ("STRING: %s\n", value->v_str.val->str);
 		break;
 
 	case VALUE_FLOAT:
-		printf ("NUMBER: %" GNM_FORMAT_f "\n", value_get_as_float (value));
+		g_print ("NUMBER: %" GNM_FORMAT_f "\n", value_get_as_float (value));
 		break;
 
 	case VALUE_ARRAY: {
 		int x, y;
 
-		printf ("Array: { ");
+		g_print ("Array: { ");
 		for (y = 0; y < value->v_array.y; y++)
 			for (x = 0; x < value->v_array.x; x++)
 				value_dump (value->v_array.vals [x][y]);
-		printf ("}\n");
+		g_print ("}\n");
 		break;
 	}
 	case VALUE_CELLRANGE: {
@@ -63,26 +63,26 @@ value_dump (GnmValue const *value)
 		GnmCellRef const *c = &value->v_range.cell.a;
 		Sheet const *sheet = c->sheet;
 
-		printf ("CellRange\n");
+		g_print ("CellRange\n");
 		if (sheet && sheet->name_unquoted)
-			printf ("%s:", sheet->name_quoted);
+			g_print ("%s:", sheet->name_quoted);
 		else
-			printf ("%p :", sheet);
-		printf ("%s%s%s%s\n",
+			g_print ("%p :", sheet);
+		g_print ("%s%s%s%s\n",
 			(c->col_relative ? "":"$"), col_name(c->col),
 			(c->row_relative ? "":"$"), row_name(c->row));
 		c = &value->v_range.cell.b;
 		if (sheet && sheet->name_quoted)
-			printf ("%s:", sheet->name_unquoted);
+			g_print ("%s:", sheet->name_unquoted);
 		else
-			printf ("%p :", sheet);
-		printf ("%s%s%s%s\n",
+			g_print ("%p :", sheet);
+		g_print ("%s%s%s%s\n",
 			(c->col_relative ? "":"$"), col_name(c->col),
 			(c->row_relative ? "":"$"), row_name(c->row));
 		break;
 	}
 	default:
-		printf ("Unhandled item type\n");
+		g_print ("Unhandled item type\n");
 	}
 }
 
@@ -137,7 +137,7 @@ value_area_get_height (GnmValue const *v, GnmEvalPos const *ep)
  * @x : column
  * @y : row
  * @ep : const #GnmEvalPos *
- * 
+ *
  * An internal routine to get a cell from an array or range.
  * Ensures that elements of CELLRANGE are evaluated
  *
@@ -159,7 +159,7 @@ value_area_fetch_x_y (GnmValue const *v, int x, int y, GnmEvalPos const *ep)
  * @x : column
  * @y : row
  * @ep : const #GnmEvalPos *
- * 
+ *
  * An internal routine to get a cell from an array or range.
  * Ensures that elements of CELLRANGE are evaluated
  *
