@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <gnumeric-config.h>
@@ -41,7 +41,10 @@ struct _EditableLabel {
 
 	GdkColor  base, text;
 	char	 *unedited_text;
-	unsigned int base_set, text_set, editable : 1;
+	unsigned int base_set;
+	unsigned int text_set;
+	unsigned int editable;
+	unsigned int set_cursor_after_motion;
 };
 
 typedef struct {
@@ -75,14 +78,14 @@ el_set_style_label (EditableLabel *el)
 {
 	GtkWidget *w = GTK_WIDGET (el);
 
-	gtk_widget_modify_base (w, GTK_STATE_NORMAL, 
+	gtk_widget_modify_base (w, GTK_STATE_NORMAL,
 				el->base_set ? &el->base : NULL);
-	gtk_widget_modify_text (w, GTK_STATE_NORMAL, 
+	gtk_widget_modify_text (w, GTK_STATE_NORMAL,
 				el->text_set ? &el->text : NULL);
 
-	gtk_widget_modify_base (w, GTK_STATE_ACTIVE, 
+	gtk_widget_modify_base (w, GTK_STATE_ACTIVE,
 				el->base_set ? &el->base : NULL);
-	gtk_widget_modify_text (w, GTK_STATE_ACTIVE, 
+	gtk_widget_modify_text (w, GTK_STATE_ACTIVE,
 				el->text_set ? &el->text : NULL);
 }
 
@@ -105,10 +108,13 @@ el_stop_editing (EditableLabel *el)
 	el->unedited_text = NULL;
 
 	el_set_style_label (el);
-	el_set_cursor (GTK_ENTRY (el), GDK_HAND2);
 	gtk_editable_set_editable (GTK_EDITABLE (el), FALSE);
 	gtk_editable_select_region (GTK_EDITABLE (el), 0, 0);
 	gtk_grab_remove (GTK_WIDGET (el));
+	el_set_cursor (GTK_ENTRY (el), GDK_HAND2);
+	/* GtkEntry is playing tricks with the cursor, so we sometimes
+	   need to set the cursor again later. */
+	el->set_cursor_after_motion = TRUE;
 }
 
 static void
@@ -218,6 +224,22 @@ el_entry_realize (GtkWidget *widget)
 	el_set_cursor (GTK_ENTRY (widget), GDK_HAND2);
 }
 
+static gint
+el_motion_notify (GtkWidget      *widget,
+		  GdkEventMotion *event)
+{
+	EditableLabel *el = EDITABLE_LABEL (widget);
+	int res = ((GtkWidgetClass *)parent_class)->motion_notify_event (widget, event);
+
+	if (el->set_cursor_after_motion) {
+		el->set_cursor_after_motion = FALSE;
+		el_set_cursor (GTK_ENTRY (widget),
+			       el->unedited_text ? GDK_XTERM : GDK_HAND2);
+	}
+
+	return res;
+}
+
 static void
 el_class_init (GtkObjectClass *object_class)
 {
@@ -228,10 +250,11 @@ el_class_init (GtkObjectClass *object_class)
 	object_class->destroy = el_destroy;
 
 	widget_class = (GtkWidgetClass *) object_class;
-	widget_class->button_press_event = el_button_press_event;
-	widget_class->key_press_event	 = el_key_press_event;
-	widget_class->size_request	 = el_size_request;
-	widget_class->realize		 = el_entry_realize;
+	widget_class->button_press_event  = el_button_press_event;
+	widget_class->key_press_event	  = el_key_press_event;
+	widget_class->size_request	  = el_size_request;
+	widget_class->realize		  = el_entry_realize;
+	widget_class->motion_notify_event = el_motion_notify;
 
 	el_signals [EDIT_FINISHED] = g_signal_new ("edit_finished",
 		EDITABLE_LABEL_TYPE,
@@ -253,6 +276,7 @@ el_init (GObject *obj)
 {
 	EditableLabel *el = EDITABLE_LABEL (obj);
 	el->editable = TRUE;
+	el->set_cursor_after_motion = FALSE;
 	g_signal_connect (obj, "changed", G_CALLBACK (cb_el_changed), NULL);
 }
 
@@ -262,6 +286,8 @@ GSF_CLASS (EditableLabel, editable_label,
 void
 editable_label_set_text (EditableLabel *el, char const *text)
 {
+	g_return_if_fail (IS_EDITABLE_LABEL (el));
+
 	gtk_entry_set_text (GTK_ENTRY (el), text);
 }
 
@@ -269,6 +295,7 @@ char const *
 editable_label_get_text  (EditableLabel const *el)
 {
 	g_return_val_if_fail (IS_EDITABLE_LABEL (el), "");
+
 	return (el->unedited_text != NULL)
 		? el->unedited_text
 		: gtk_entry_get_text (GTK_ENTRY (el));
@@ -288,12 +315,12 @@ editable_label_set_color (EditableLabel *el, GdkColor *base_color, GdkColor *tex
 	g_return_if_fail (IS_EDITABLE_LABEL (el));
 
 	if (base_color != NULL) {
-		el->base_set = TRUE; 
+		el->base_set = TRUE;
 		el->base = *base_color;
 	} else
 		el->base_set = FALSE;
 	if (text_color != NULL) {
-		el->text_set = TRUE; 
+		el->text_set = TRUE;
 		el->text  = *text_color;
 	} else
 		el->text_set = FALSE;
@@ -304,7 +331,7 @@ editable_label_set_color (EditableLabel *el, GdkColor *base_color, GdkColor *tex
 }
 
 GtkWidget *
-editable_label_new (char const *text, GdkColor *base_color, 
+editable_label_new (char const *text, GdkColor *base_color,
 				      GdkColor *text_color)
 {
 	EditableLabel *el = g_object_new (EDITABLE_LABEL_TYPE,
@@ -327,6 +354,8 @@ editable_label_new (char const *text, GdkColor *base_color,
 void
 editable_label_start_editing (EditableLabel *el)
 {
+	g_return_if_fail (IS_EDITABLE_LABEL (el));
+
 	if (el->unedited_text != NULL || !el->editable)
 		return;
 
@@ -342,9 +371,19 @@ editable_label_start_editing (EditableLabel *el)
 	gtk_grab_add (GTK_WIDGET (el));
 }
 
+gboolean
+editable_label_get_editable (EditableLabel *el)
+{
+	g_return_val_if_fail (IS_EDITABLE_LABEL (el), FALSE);
+
+	return el->editable;
+}
+
 void
 editable_label_set_editable (EditableLabel *el, gboolean editable)
 {
+	g_return_if_fail (IS_EDITABLE_LABEL (el));
+
 	if (!editable)
 		el_cancel_editing (el);
 
