@@ -9,11 +9,6 @@ struct _WorkbookControl {
 
 	WorkbookView *wb_view;
 
-	/* When editing a cell: the cell (may be NULL) */
-	GnmCell     *editing_cell;
-	Sheet       *editing_sheet;
-	gboolean     editing;
-
 	gulong clipboard_changed_signal;
 };
 typedef struct {
@@ -29,7 +24,6 @@ typedef struct {
 	void (*edit_line_set)	    (WorkbookControl *wbc, char const *text);
 	void (*edit_finish)	    (WorkbookControl *wbc, gboolean accept);
 	void (*selection_descr_set) (WorkbookControl *wbc, char const *text);
-	void (*auto_expr_value)	    (WorkbookControl *wbc);
 	void (*update_action_sensitivity)  (WorkbookControl *wbc);
 	struct {
 		void (*add)	(WorkbookControl *wbc, SheetView *sv);
