@@ -9,7 +9,7 @@
  *
  * (C) 1998, 1999, 2000 Miguel de Icaza
  * (C) 2000-2001 Ximian, Inc.
- * (C) 2002-2006 Jody Goldberg
+ * (C) 2002-2007 Jody Goldberg
  */
 #include <gnumeric-config.h>
 #include "gnumeric.h"
@@ -56,6 +56,7 @@
 
 enum {
 	PROP_0,
+	RECALC_MODE,
 };
 enum {
 	SHEET_ORDER_CHANGED,
@@ -75,6 +76,19 @@ cb_saver_finalize (Workbook *wb, GOFileSaver *saver)
 	wb->file_saver = NULL;
 }
 
+void
+workbook_update_history (Workbook *wb)
+{
+	g_return_if_fail (IS_WORKBOOK (wb));
+
+	if (wb->doc.uri && wb->file_format_level >= FILE_FL_MANUAL_REMEMBER) {
+		const char *mimetype = wb->file_saver
+			? go_file_saver_get_mime_type (wb->file_saver)
+			: NULL;
+		gnm_app_history_add (wb->doc.uri, mimetype);
+	}
+}
+
 static void
 workbook_dispose (GObject *wb_object)
 {
@@ -119,18 +133,14 @@ workbook_dispose (GObject *wb_object)
 	 */
 	/* Get rid of all the views */
 	if (wb->wb_views != NULL) {
-		WORKBOOK_FOREACH_VIEW (wb, view, {
-			workbook_detach_view (view);
-			g_object_unref (view);
+		WORKBOOK_FOREACH_VIEW (wb, wbv, {
+			wb_view_detach_from_workbook (wbv);
+			g_object_unref (wbv);
 		});
 		if (wb->wb_views != NULL)
 			g_warning ("Unexpected left over views");
 	}
 
-	if (wb->doc.uri &&
-	    wb->file_format_level >= FILE_FL_MANUAL_REMEMBER)
-		gnm_app_history_add (wb->doc.uri);
-
 	workbook_parent_class->dispose (wb_object);
 }
 
@@ -196,7 +206,6 @@ workbook_init (GObject *object)
 	gnm_app_workbook_list_add (wb);
 }
 
-#if 0
 static void
 workbook_get_property (GObject *object, guint property_id,
 		       GValue *value, GParamSpec *pspec)
@@ -204,6 +213,9 @@ workbook_get_property (GObject *object, guint property_id,
 	Workbook *wb = (Workbook *)object;
 
 	switch (property_id) {
+	case RECALC_MODE :
+		g_value_set_boolean (value, wb->recalc_auto);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -217,24 +229,31 @@ workbook_set_property (GObject *object, guint property_id,
 	Workbook *wb = (Workbook *)object;
 
 	switch (property_id) {
+	case RECALC_MODE :
+		workbook_set_recalcmode (wb, g_value_get_boolean (value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
 	}
 }
-#endif
 
 static void
-workbook_class_init (GObjectClass *object_class)
+workbook_class_init (GObjectClass *gobject_class)
 {
-	workbook_parent_class = g_type_class_peek_parent (object_class);
+	workbook_parent_class = g_type_class_peek_parent (gobject_class);
 
-#if 0
-	object_class->set_property = workbook_set_property;
-	object_class->get_property = workbook_get_property;
-#endif
-	object_class->finalize = workbook_finalize;
-	object_class->dispose = workbook_dispose;
+	gobject_class->set_property = workbook_set_property;
+	gobject_class->get_property = workbook_get_property;
+	gobject_class->finalize	    = workbook_finalize;
+	gobject_class->dispose	    = workbook_dispose;
+
+        g_object_class_install_property (gobject_class, RECALC_MODE,
+		 g_param_spec_boolean ("recalc-mode", "recalc-mode",
+				       _("Enable automatic recalculation."),
+				       TRUE,
+				       GSF_PARAM_STATIC |
+				       G_PARAM_READWRITE));
 
 	signals [SHEET_ORDER_CHANGED] = g_signal_new ("sheet_order_changed",
 		WORKBOOK_TYPE,
@@ -269,7 +288,7 @@ workbook_class_init (GObjectClass *object_class)
  *
  * Creates a new empty Workbook
  * and assigns a unique name.
- */
+ **/
 Workbook *
 workbook_new (void)
 {
@@ -499,6 +518,28 @@ workbook_cells (Workbook *wb, gboolean comments)
 	return cells;
 }
 
+GnmExprSharer *
+workbook_share_expressions (Workbook *wb, gboolean freeit)
+{
+	GnmExprSharer *es = gnm_expr_sharer_new ();
+
+	WORKBOOK_FOREACH_DEPENDENT (wb, dep, {
+		if (dependent_is_cell (dep)) {
+			/* Hopefully safe, even when linked.  */
+			dep->texpr = gnm_expr_sharer_share (es, dep->texpr);
+		} else {
+			/* Not sure we want to touch this here.  */
+		}
+	});
+
+	if (freeit) {
+		gnm_expr_sharer_destroy (es);
+		es = NULL;
+	}
+
+	return es;
+}
+
 GSList *
 workbook_local_functions (Workbook const *wb)
 {
@@ -518,14 +559,14 @@ workbook_enable_recursive_dirty (Workbook *wb, gboolean enable)
 }
 
 void
-workbook_autorecalc_enable (Workbook *wb, gboolean enable)
+workbook_set_recalcmode (Workbook *wb, gboolean is_auto)
 {
 	g_return_if_fail (IS_WORKBOOK (wb));
-	wb->recalc_auto = enable;
+	wb->recalc_auto = is_auto;
 }
 
 gboolean
-workbook_autorecalc (Workbook const *wb)
+workbook_get_recalcmode (Workbook const *wb)
 {
 	g_return_val_if_fail (IS_WORKBOOK (wb), FALSE);
 	return wb->recalc_auto;
@@ -556,16 +597,18 @@ workbook_iteration_tolerance (Workbook *wb, double tolerance)
 }
 
 void
-workbook_attach_view (Workbook *wb, WorkbookView *wbv)
+workbook_attach_view (WorkbookView *wbv)
 {
-	g_return_if_fail (IS_WORKBOOK (wb));
+	Workbook *wb;
+
 	g_return_if_fail (IS_WORKBOOK_VIEW (wbv));
-	g_return_if_fail (wb_view_get_workbook (wbv) == NULL);
+
+	wb = wb_view_get_workbook (wbv);
+	g_return_if_fail (IS_WORKBOOK (wb));
 
 	if (wb->wb_views == NULL)
 		wb->wb_views = g_ptr_array_new ();
 	g_ptr_array_add (wb->wb_views, wbv);
-	wbv->wb = wb;
 }
 
 void
@@ -584,7 +627,6 @@ workbook_detach_view (WorkbookView *wbv)
 		g_ptr_array_free (wbv->wb->wb_views, TRUE);
 		wbv->wb->wb_views = NULL;
 	}
-	wbv->wb = NULL;
 }
 
 /*****************************************************************************/
@@ -720,11 +762,10 @@ workbook_focus_other_sheet (Workbook *wb, Sheet *sheet)
 			focus = this_sheet;
 	}
 
-	if (focus)
-		WORKBOOK_FOREACH_VIEW (wb, wbv,
-			if (sheet == wb_view_cur_sheet (wbv))
-				wb_view_sheet_focus (wbv, focus);
-		);
+	WORKBOOK_FOREACH_VIEW (wb, wbv, {
+		if (sheet == wb_view_cur_sheet (wbv))
+			wb_view_sheet_focus (wbv, focus);
+	});
 
 	return focus;
 }
@@ -859,6 +900,8 @@ workbook_sheet_delete (Sheet *sheet)
         g_return_if_fail (IS_SHEET (sheet));
         g_return_if_fail (IS_WORKBOOK (sheet->workbook));
 
+	gnm_app_clipboard_invalidate_sheet (sheet);
+
 	wb = sheet->workbook;
 	sheet_index = sheet->index_in_wb;
 
@@ -1004,7 +1047,7 @@ workbook_sheet_rename (Workbook *wb,
 
 	while (new_name && sheet_index) {
 		if (-1 != GPOINTER_TO_INT (sheet_index->data)) {
-			g_hash_table_remove (wb->sheet_hash_private, 
+			g_hash_table_remove (wb->sheet_hash_private,
 					     new_name->data);
 		}
 		sheet_index = sheet_index->next;
@@ -1015,7 +1058,7 @@ workbook_sheet_rename (Workbook *wb,
 	new_name = new_names;
 	while (new_name && sheet_index) {
 		if (-1 != GPOINTER_TO_INT (sheet_index->data)) {
-			Sheet *sheet = workbook_sheet_by_index 
+			Sheet *sheet = workbook_sheet_by_index
 				(wb, GPOINTER_TO_INT (sheet_index->data));
 			g_object_set (sheet, "name", new_name->data, NULL);
 		}
@@ -1105,7 +1148,7 @@ workbook_date_conv (Workbook const *wb)
  *
  * Sets the 1904 flag to @flag and returns the old value.
  * NOTE : THIS IS NOT A SMART ROUTINE.  If you want to actually change this
- * We'll need to recalc and rerender everything.  That will nee to be done
+ * We'll need to recalc and rerender everything.  That will need to be done
  * externally.
  **/
 gboolean
@@ -1255,7 +1298,7 @@ workbook_sheet_state_diff (const WorkbookSheetState *wss_a, const WorkbookSheetS
 		if (ia != ib) {
 			what |= WSS_SHEET_ORDER;
 			/* We do not count reordered sheet.  */
-		}			
+		}
 
 		pa = wss_a->sheets[ia].properties;
 		pb = wss_b->sheets[ib].properties;
