@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * xml-io.c: save/read gnumeric workbooks using gnumeric-1.0 style xml.
+ * xml-io.c: Old slow DOM based gnumeric-1.0 format importer.
  *
  * Authors:
  *   Daniel Veillard <Daniel.Veillard@w3.org>
@@ -505,8 +505,9 @@ xml_read_print_margins (XmlParseContext *ctxt, xmlNodePtr tree)
 	double footer = -1.;
 	double left = -1.;
 	double right = -1.;
+	double edge_to_above_footer = -1.;
+	double edge_to_below_header = -1.;
 
-	
 	g_return_if_fail (ctxt != NULL);
 	g_return_if_fail (tree != NULL);
 	g_return_if_fail (IS_SHEET (ctxt->sheet));
@@ -516,10 +517,10 @@ xml_read_print_margins (XmlParseContext *ctxt, xmlNodePtr tree)
 	g_return_if_fail (pi != NULL);
 
 	if ((child = e_xml_get_child_by_name (tree, CC2XML ("top"))))
-		xml_node_get_print_margin (child, &pi->margin.top,
+		xml_node_get_print_margin (child, &edge_to_below_header,
 					   &pi->desired_display.header);
 	if ((child = e_xml_get_child_by_name (tree, CC2XML ("bottom"))))
-		xml_node_get_print_margin (child, &pi->margin.bottom,
+		xml_node_get_print_margin (child, &edge_to_above_footer,
 					   &pi->desired_display.footer);
 	if ((child = e_xml_get_child_by_name (tree, CC2XML ("left"))))
 		xml_node_get_print_margin (child, &left,
@@ -535,6 +536,11 @@ xml_read_print_margins (XmlParseContext *ctxt, xmlNodePtr tree)
 					   &pi->desired_display.bottom);
 
 	print_info_set_margins (pi, header, footer, left, right);
+	if (!(edge_to_below_header < 0))
+		print_info_set_edge_to_below_header (pi, edge_to_below_header);
+	if (!(edge_to_above_footer < 0))
+		print_info_set_edge_to_above_footer (pi, edge_to_above_footer);
+
 }
 
 static void
@@ -1905,6 +1911,14 @@ xml_sheet_read (XmlParseContext *ctxt, xmlNodePtr tree)
 		g_object_set (sheet, "text-is-rtl", tmp, NULL);
 	if (xml_node_get_bool (tree, "Protected", &tmp))
 		g_object_set (sheet, "protected", tmp, NULL);
+
+	if (NULL != (val = xml_node_get_cstr (tree, CC2XML ("ExprConvention")))) {
+		GnmConventions const *convs = gnm_conventions_default;
+		if (0 == strcmp (val, "gnumeric:R1C1"))
+			convs = gnm_conventions_xls_r1c1;
+		g_object_set (sheet, "conventions", convs, NULL);
+		xmlFree (val);
+	}
 	if (xml_node_get_enum (tree, "Visibility", GNM_SHEET_VISIBILITY_TYPE, &tmpi))
 		g_object_set (sheet, "visibility", tmpi, NULL);
 	sheet->tab_color = xml_node_get_color (tree, "TabColor");
@@ -2278,6 +2292,7 @@ xml_workbook_read (IOContext *context,
 {
 	Sheet     *sheet;
 	GnmLocale *locale;
+	xmlChar   *str;
 	xmlNodePtr child, c;
 
 	if (strcmp (tree->name, "Workbook")){
@@ -2292,6 +2307,8 @@ xml_workbook_read (IOContext *context,
 	if (child)
 		dom_read_meta_data (ctxt, child, go_doc_get_meta_data (GO_DOC (ctxt->wb)));
 
+        /* DEPRECATED, moved to Calculation and expanded in 1.7.11
+	 * Valid value == 1904, anything else == Lotus:1900  */
 	child = e_xml_get_child_by_name (tree, CC2XML ("DateConvention"));
 	if (child != NULL) {
 		int convention;
@@ -2355,7 +2372,7 @@ xml_workbook_read (IOContext *context,
 	if (child) {
 		int sheet_index = 0;
 		if (xml_node_get_int (child, "SelectedTab", &sheet_index)) {
-			Sheet *sheet = workbook_sheet_by_index (ctxt->wb, 
+			Sheet *sheet = workbook_sheet_by_index (ctxt->wb,
 								sheet_index);
 			if (sheet)
 				wb_view_sheet_focus (ctxt->wb_view, sheet);
@@ -2369,13 +2386,18 @@ xml_workbook_read (IOContext *context,
 		double	 d;
 
 		if (xml_node_get_bool (child, "ManualRecalc", &b))
-			workbook_autorecalc_enable (ctxt->wb, !b);
+			workbook_set_recalcmode (ctxt->wb, !b);
 		if (xml_node_get_bool   (child, "EnableIteration", &b))
 			workbook_iteration_enabled (ctxt->wb, b);
 		if (xml_node_get_int    (child, "MaxIterations", &i))
 			workbook_iteration_max_number (ctxt->wb, i);
 		if (xml_node_get_double (child, "IterationTolerance", &d))
 			workbook_iteration_tolerance (ctxt->wb, d);
+		if (NULL != (str = xml_node_get_cstr (child, "DateConvention"))) {
+			workbook_set_1904 (ctxt->wb,
+				strcmp (str, "Apple:1904") == 0);
+			xmlFree (str);
+		}
 	}
 
 	gnm_pop_C_locale (locale);
@@ -2672,6 +2694,7 @@ gnumeric_xml_read_workbook (GOFileOpener const *fo,
 void
 xml_init (void)
 {
+	GOFileSaver *saver;
 	GSList *suffixes = go_slist_create (g_strdup ("gnumeric"), g_strdup ("xml"), NULL);
 	GSList *mimes = go_slist_create (g_strdup ("application/x-gnumeric"), NULL);
 	xml_sax_prober.comment    = NULL;
@@ -2688,11 +2711,26 @@ xml_init (void)
 
 	go_file_opener_register (go_file_opener_new (
 		"Gnumeric_XmlIO:sax",
-		_("EXPERIMENTAL SAX based Gnumeric (*.gnumeric)"),
+		_("Gnumeric XML (*.gnumeric)"),
 		suffixes, mimes,
 		xml_probe, gnm_xml_file_open), 50);
-	go_file_saver_register_as_default (go_file_saver_new (
-		"Gnumeric_XmlIO:sax", "gnumeric",
-		_("Gnumeric XML (*.gnumeric)"),
-		FILE_FL_AUTO, gnm_xml_file_save), 50);
+
+	saver = go_file_saver_new ("Gnumeric_XmlIO:sax",
+				   "gnumeric",
+				   _("Gnumeric XML (*.gnumeric)"),
+				   FILE_FL_AUTO, gnm_xml_file_save);
+	/*
+	 * The following avoids a hard dep on goffice trunk.  When we
+	 * otherwise require that, just do the g_object_set.
+	 */
+	{
+		GParamSpec *pspec = g_object_class_find_property
+			(G_OBJECT_GET_CLASS (saver), "mime-type");
+		if (pspec)
+			g_object_set (G_OBJECT (saver),
+				      "mime-type", "application/x-gnumeric",
+				      NULL);
+	}
+
+	go_file_saver_register_as_default (saver, 50);
 }
