@@ -37,15 +37,12 @@ XmlParseContext *xml_parse_ctx_new     (xmlDoc		*doc,
 void		 xml_parse_ctx_destroy (XmlParseContext *ctxt);
 
 
-xmlNodePtr   xml_write_style    (XmlParseContext *ctxt, GnmStyle *style);
-
 GnmCellRegion *xml_cellregion_read  (WorkbookControl *context, Sheet *sheet,
 				     const char *buffer, int length);
 
 GnmColor  *xml_node_get_color	(xmlNodePtr node, char const *name);
 void       xml_node_set_color	(xmlNodePtr node, char const *name, GnmColor const *color);
 
-xmlNodePtr   xml_write_style    (XmlParseContext *ctxt, GnmStyle *style);
 GnmStyle      *xml_read_style     (XmlParseContext *ctxt, xmlNodePtr tree,
 				   gboolean leave_empty);
 
@@ -64,4 +61,6 @@ gboolean gnm_xml_attr_double  (xmlChar const * const *attrs,
 SheetObject *gnm_xml_in_cur_obj   (GsfXMLIn const *xin);
 Sheet	    *gnm_xml_in_cur_sheet (GsfXMLIn const *xin);
 
+GnmConventions *gnm_xml_io_conventions (void);
+
 #endif /* GNUMERIC_XML_IO_H */
