@@ -3,7 +3,7 @@
 /*
  * xml-sax-read.c : a sax based parser.
  *
- * Copyright (C) 2000-2006 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2000-2007 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -73,6 +73,7 @@
 #include <libxml/parserInternals.h>
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 
 GNM_PLUGIN_MODULE_HEADER;
 
@@ -136,7 +137,7 @@ gboolean
 gnm_xml_attr_int (xmlChar const * const *attrs, char const *name, int *res)
 {
 	char *end;
-	int tmp;
+	long tmp;
 
 	g_return_val_if_fail (attrs != NULL, FALSE);
 	g_return_val_if_fail (attrs[0] != NULL, FALSE);
@@ -145,8 +146,9 @@ gnm_xml_attr_int (xmlChar const * const *attrs, char const *name, int *res)
 	if (strcmp (CXML2C (attrs[0]), name))
 		return FALSE;
 
+	errno = 0;
 	tmp = strtol (CXML2C (attrs[1]), &end, 10);
-	if (*end) {
+	if (*end || errno) {
 		g_warning ("Invalid attribute '%s', expected integer, received '%s'",
 			   name, attrs[1]);
 		return FALSE;
@@ -254,6 +256,7 @@ typedef struct {
 	Workbook	*wb;		/* The new workbook */
 	GnumericXMLVersion version;
 	gsf_off_t last_progress_update;
+	GnmConventions *convs;
 
 	Sheet *sheet;
 	double sheet_zoom;
@@ -306,13 +309,17 @@ typedef struct {
 	int outline_symbols_right;
 	int text_is_rtl;
 	int is_protected;
+	char *expr_conv_name;
 	GnmSheetVisibility visibility;
 	GnmColor *tab_color;
+	GnmColor *tab_text_color;
 
 	/* expressions with ref > 1 a map from index -> expr pointer */
 	GHashTable *expr_map;
 	GList *delayed_names;
 	SheetObject *so;
+
+	GnmPageBreaks *page_breaks;
 } XMLSaxParseState;
 
 static void
@@ -477,17 +484,27 @@ xml_sax_calculation (GsfXMLIn *xin, xmlChar const **attrs)
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
 		if (xml_sax_attr_bool (attrs, "ManualRecalc", &b))
-			workbook_autorecalc_enable (state->wb, !b);
+			workbook_set_recalcmode (state->wb, !b);
 		else if (xml_sax_attr_bool (attrs, "EnableIteration", &b))
 			workbook_iteration_enabled (state->wb, b);
 		else if (gnm_xml_attr_int  (attrs, "MaxIterations", &i))
 			workbook_iteration_max_number (state->wb, i);
 		else if (gnm_xml_attr_double (attrs, "IterationTolerance", &d))
 			workbook_iteration_tolerance (state->wb, d);
-		else
+		else if (strcmp (CXML2C (attrs[0]), "DateConvention") == 0) {
+			workbook_set_1904 (state->wb,
+				strcmp (attrs[1], "Apple:1904") == 0);
+		} else
 			unknown_attr (xin, attrs);
 }
 
+static void
+xml_sax_old_dateconvention (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	workbook_set_1904 (state->wb, strcmp (xin->content->str, "1904") == 0);
+}
+
 static void
 xml_sax_finish_parse_wb_attr (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 {
@@ -541,8 +558,10 @@ xml_sax_sheet_start (GsfXMLIn *xin, xmlChar const **attrs)
 		state->hide_grid = state->display_outlines =
 		state->outline_symbols_below = state->outline_symbols_right =
 		state->text_is_rtl = state->is_protected = -1;
+	state->expr_conv_name = NULL;
 	state->visibility = GNM_SHEET_VISIBILITY_VISIBLE;
 	state->tab_color = NULL;
+	state->tab_text_color = NULL;
 	state->sheet_zoom = 1.; /* default */
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
@@ -568,8 +587,12 @@ xml_sax_sheet_start (GsfXMLIn *xin, xmlChar const **attrs)
 			state->text_is_rtl = tmp;
 		else if (xml_sax_attr_bool (attrs, "Protected", &tmp))
 			state->is_protected = tmp;
+		else if (strcmp (CXML2C (attrs[0]), "ExprConvention") == 0)
+			state->expr_conv_name = g_strdup (attrs[1]);
 		else if (xml_sax_attr_color (attrs, "TabColor", &color))
 			state->tab_color = color;
+		else if (xml_sax_attr_color (attrs, "TabTextColor", &color))
+			state->tab_text_color = color;
 		else
 			unknown_attr (xin, attrs);
 }
@@ -591,6 +614,7 @@ static void
 xml_sax_sheet_name (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 {
 	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	Sheet *sheet;
 
 	char const * content = xin->content->str;
 	g_return_if_fail (state->sheet == NULL);
@@ -599,39 +623,52 @@ xml_sax_sheet_name (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 	 * have to support < GNM_XML_V7 anymore
 	 */
 	if (state->version >= GNM_XML_V7) {
-		state->sheet = workbook_sheet_by_name (state->wb, content);
+		sheet = workbook_sheet_by_name (state->wb, content);
 
-		if (!state->sheet) {
+		if (!sheet) {
 			gnumeric_io_error_string (state->context,
 				_("File has inconsistent SheetNameIndex element."));
-			state->sheet = sheet_new (state->wb, content);
-			workbook_sheet_attach (state->wb, state->sheet);
+			sheet = sheet_new (state->wb, content);
+			workbook_sheet_attach (state->wb, sheet);
 		}
 	} else {
-		state->sheet = sheet_new (state->wb, content);
-		workbook_sheet_attach (state->wb, state->sheet);
+		sheet = sheet_new (state->wb, content);
+		workbook_sheet_attach (state->wb, sheet);
 	}
+	state->sheet = sheet;
 
 	if (state->display_formulas >= 0)
-		g_object_set (state->sheet, "display-formulas", state->display_formulas, NULL);
+		g_object_set (sheet, "display-formulas", state->display_formulas, NULL);
 	if (state->hide_zero >= 0)
-		g_object_set (state->sheet, "display-zeros", !state->hide_zero, NULL);
+		g_object_set (sheet, "display-zeros", !state->hide_zero, NULL);
 	if (state->hide_grid >= 0)
-		g_object_set (state->sheet, "display-grid", !state->hide_grid, NULL);
+		g_object_set (sheet, "display-grid", !state->hide_grid, NULL);
 	if (state->hide_col_header >= 0)
-		g_object_set (state->sheet, "display-column-header", !state->hide_col_header, NULL);
+		g_object_set (sheet, "display-column-header", !state->hide_col_header, NULL);
 	if (state->hide_row_header >= 0)
-		g_object_set (state->sheet, "display-row-header", !state->hide_row_header, NULL);
+		g_object_set (sheet, "display-row-header", !state->hide_row_header, NULL);
 	if (state->display_outlines >= 0)
-		g_object_set (state->sheet, "display-outlines", state->display_outlines, NULL);
+		g_object_set (sheet, "display-outlines", state->display_outlines, NULL);
 	if (state->outline_symbols_below >= 0)
-		g_object_set (state->sheet, "display-outlines-below", state->outline_symbols_below, NULL);
+		g_object_set (sheet, "display-outlines-below", state->outline_symbols_below, NULL);
 	if (state->outline_symbols_right >= 0)
-		g_object_set (state->sheet, "display-outlines-right", state->outline_symbols_right, NULL);
+		g_object_set (sheet, "display-outlines-right", state->outline_symbols_right, NULL);
 	if (state->text_is_rtl >= 0)
-		g_object_set (state->sheet, "text-is-rtl", state->text_is_rtl, NULL);
-	g_object_set (state->sheet, "visibility", state->visibility, NULL);
-	state->sheet->tab_color = state->tab_color;
+		g_object_set (sheet, "text-is-rtl", state->text_is_rtl, NULL);
+	if (state->is_protected >= 0)
+		g_object_set (sheet, "protected", state->is_protected, NULL);
+	if (state->expr_conv_name != NULL) {
+		GnmConventions const *convs = gnm_conventions_default;
+		if (0 == strcmp (state->expr_conv_name, "gnumeric:R1C1"))
+			convs = gnm_conventions_xls_r1c1;
+		g_object_set (sheet, "conventions", convs, NULL);
+
+		g_free (state->expr_conv_name);
+		state->expr_conv_name = NULL;
+	}
+	g_object_set (sheet, "visibility", state->visibility, NULL);
+	sheet->tab_color = state->tab_color;
+	sheet->tab_text_color = state->tab_text_color;
 }
 
 static void
@@ -676,11 +713,19 @@ xml_sax_print_margins (GsfXMLIn *xin, xmlChar const **attrs)
 
 	pi = state->sheet->print_info;
 	switch (xin->node->user_data.v_int) {
-	case 0: xml_sax_print_margins_unit (xin, attrs,
-			&pi->margin.top, &pi->desired_display.header);
+	case 0:
+		xml_sax_print_margins_unit (xin, attrs,
+					    &points,
+					    &pi->desired_display.header);
+		if (points >= 0.)
+			print_info_set_edge_to_below_header (pi, points);
 		break;
-	case 1: xml_sax_print_margins_unit (xin, attrs,
-			&pi->margin.bottom, &pi->desired_display.footer);
+	case 1:
+		xml_sax_print_margins_unit (xin, attrs,
+					    &points,
+					    &pi->desired_display.footer);
+		if (points >= 0.)
+			print_info_set_edge_to_above_footer (pi, points);
 		break;
 	case 2:
 		xml_sax_print_margins_unit (xin, attrs,
@@ -712,7 +757,55 @@ xml_sax_print_margins (GsfXMLIn *xin, xmlChar const **attrs)
 }
 
 
+static void
+xml_sax_page_break (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	GnmPageBreakType  type = GNM_PAGE_BREAK_AUTO;
+	gboolean tmp;
+	int	 pos;
 
+	if (NULL == state->page_breaks)
+		return;
+
+	pos = 0;
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (gnm_xml_attr_int  (attrs, "pos", &pos)) ;
+		else if (xml_sax_attr_bool (attrs, "manual", &tmp)) { if (tmp) type = GNM_PAGE_BREAK_MANUAL; }
+#if 0 /* Ignored */
+		else if (gnm_xml_attr_int  (attrs, "first", &first)) ;
+		else if (gnm_xml_attr_int  (attrs, "last", &last)) ;
+#endif
+
+	gnm_page_breaks_append_break (state->page_breaks, pos, type);
+}
+
+static void
+xml_sax_page_breaks_begin (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	int count = 0;
+
+	g_return_if_fail (state->page_breaks == NULL);
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (gnm_xml_attr_int  (attrs, "count", &count)) ;
+
+	state->page_breaks = gnm_page_breaks_new (count,
+		xin->node->user_data.v_int);
+}
+
+static void
+xml_sax_page_breaks_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+
+	if (NULL != state->page_breaks) {
+		print_info_set_breaks (state->sheet->print_info,
+			state->page_breaks);
+		state->page_breaks = NULL;
+	}
+}
 
 static void
 xml_sax_print_scale (GsfXMLIn *xin, xmlChar const **attrs)
@@ -740,6 +833,149 @@ xml_sax_print_scale (GsfXMLIn *xin, xmlChar const **attrs)
 	}
 }
 
+static void
+xml_sax_print_vcenter (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	PrintInformation *pi;
+	int val;
+
+	g_return_if_fail (state->sheet != NULL);
+	g_return_if_fail (state->sheet->print_info != NULL);
+
+	pi = state->sheet->print_info;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (gnm_xml_attr_int (attrs, "value", &val))
+			pi->center_vertically = val;
+}
+
+static void
+xml_sax_print_hcenter (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	PrintInformation *pi;
+	int val;
+
+	g_return_if_fail (state->sheet != NULL);
+	g_return_if_fail (state->sheet->print_info != NULL);
+
+	pi = state->sheet->print_info;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (gnm_xml_attr_int (attrs, "value", &val))
+			pi->center_horizontally = val;
+}
+
+static void
+xml_sax_print_grid (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	PrintInformation *pi;
+	int val;
+
+	g_return_if_fail (state->sheet != NULL);
+	g_return_if_fail (state->sheet->print_info != NULL);
+
+	pi = state->sheet->print_info;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (gnm_xml_attr_int (attrs, "value", &val))
+			pi->print_grid_lines = val;
+}
+
+
+static void
+xml_sax_monochrome (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	PrintInformation *pi;
+	int val;
+
+	g_return_if_fail (state->sheet != NULL);
+	g_return_if_fail (state->sheet->print_info != NULL);
+
+	pi = state->sheet->print_info;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (gnm_xml_attr_int (attrs, "value", &val))
+			pi->print_black_and_white = val;
+}
+
+static void
+xml_sax_print_titles (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	PrintInformation *pi;
+	int val;
+
+	g_return_if_fail (state->sheet != NULL);
+	g_return_if_fail (state->sheet->print_info != NULL);
+
+	pi = state->sheet->print_info;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (gnm_xml_attr_int (attrs, "value", &val))
+			pi->print_titles = val;
+}
+static void
+xml_sax_repeat_top (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	PrintInformation *pi;
+	int val;
+
+	g_return_if_fail (state->sheet != NULL);
+	g_return_if_fail (state->sheet->print_info != NULL);
+
+	pi = state->sheet->print_info;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (!strcmp (CXML2C (attrs[0]), "value"))
+			pi->repeat_top.use = range_parse
+				(&pi->repeat_top.range, CXML2C (attrs[1]));
+
+}
+
+static void
+xml_sax_repeat_left (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	PrintInformation *pi;
+	int val;
+
+	g_return_if_fail (state->sheet != NULL);
+	g_return_if_fail (state->sheet->print_info != NULL);
+
+	pi = state->sheet->print_info;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (!strcmp (CXML2C (attrs[0]), "value"))
+			pi->repeat_left.use = range_parse
+				(&pi->repeat_left.range, CXML2C (attrs[1]));
+}
+
+
+static void
+xml_sax_even_if_only_styles (GsfXMLIn *xin, xmlChar const **attrs)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+	PrintInformation *pi;
+	int val;
+
+	g_return_if_fail (state->sheet != NULL);
+	g_return_if_fail (state->sheet->print_info != NULL);
+
+	pi = state->sheet->print_info;
+
+	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
+		if (gnm_xml_attr_int (attrs, "value", &val))
+			pi->print_even_if_only_styles = val;
+}
+
+
+
+
 static void
 xml_sax_selection_range (GsfXMLIn *xin, xmlChar const **attrs)
 {
@@ -1158,8 +1394,11 @@ xml_sax_validation_expr_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 
 	g_return_if_fail (state->validation.texpr[i] == NULL);
 
-	texpr = gnm_expr_parse_str_simple (xin->content->str,
-		parse_pos_init_sheet (&pos, state->sheet));
+	texpr = gnm_expr_parse_str (xin->content->str,
+				    parse_pos_init_sheet (&pos, state->sheet),
+				    GNM_EXPR_PARSE_DEFAULT,
+				    state->convs,
+				    NULL);
 
 	g_return_if_fail (texpr != NULL);
 
@@ -1221,8 +1460,11 @@ xml_sax_condition_expr_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 
 	g_return_if_fail (state->cond.texpr[i] == NULL);
 
-	texpr = gnm_expr_parse_str_simple (xin->content->str,
-		parse_pos_init_sheet (&pos, state->sheet));
+	texpr = gnm_expr_parse_str (xin->content->str,
+				    parse_pos_init_sheet (&pos, state->sheet),
+				    GNM_EXPR_PARSE_DEFAULT,
+				    state->convs,
+				    NULL);
 
 	g_return_if_fail (texpr != NULL);
 
@@ -1245,7 +1487,7 @@ xml_sax_hlink (GsfXMLIn *xin, xmlChar const **attrs)
 		else if (attr_eq (attrs[0], "target"))
 			target = g_strdup (CXML2C (attrs[1]));
 		else if (attr_eq (attrs[0], "tip"))
-			target = g_strdup (CXML2C (attrs[1]));
+			tip = g_strdup (CXML2C (attrs[1]));
 		else
 			unknown_attr (xin, attrs);
 	}
@@ -1377,18 +1619,23 @@ xml_sax_cell (GsfXMLIn *xin, xmlChar const **attrs)
  * @cols : The number of columns.
  */
 static void
-xml_cell_set_array_expr (GnmCell *cell, char const *text,
+xml_cell_set_array_expr (XMLSaxParseState *state,
+			 GnmCell *cell, char const *text,
 			 int const cols, int const rows)
 {
 	GnmParsePos pp;
-	GnmExprTop const *texpr = gnm_expr_parse_str_simple (text,
-		parse_pos_init_cell (&pp, cell));
+	GnmExprTop const *texpr =
+		gnm_expr_parse_str (text,
+				    parse_pos_init_cell (&pp, cell),
+				    GNM_EXPR_PARSE_DEFAULT,
+				    state->convs,
+				    NULL);
 
 	g_return_if_fail (texpr != NULL);
 	gnm_cell_set_array_formula (cell->base.sheet,
-				cell->pos.col, cell->pos.row,
-				cell->pos.col + cols-1, cell->pos.row + rows-1,
-				texpr);
+				    cell->pos.col, cell->pos.row,
+				    cell->pos.col + cols-1, cell->pos.row + rows-1,
+				    texpr);
 }
 
 /**
@@ -1399,9 +1646,10 @@ xml_cell_set_array_expr (GnmCell *cell, char const *text,
  *     If it is not a member of an array return TRUE.
  */
 static gboolean
-xml_not_used_old_array_spec (GnmCell *cell, char const *content)
+xml_not_used_old_array_spec (XMLSaxParseState *state, GnmCell *cell,
+			     char const *content)
 {
-	int rows, cols, row, col;
+	long rows, cols, row, col;
 
 #if 0
 	/* This is the syntax we are trying to parse */
@@ -1432,7 +1680,7 @@ xml_not_used_old_array_spec (GnmCell *cell, char const *content)
 
 	if (row == 0 && col == 0) {
 		*expr_end = '\0';
-		xml_cell_set_array_expr (cell, content+2, rows, cols);
+		xml_cell_set_array_expr (state, cell, content+2, rows, cols);
 	}
 
 	return FALSE;
@@ -1486,10 +1734,10 @@ xml_sax_cell_content (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 		if (is_post_52_array) {
 			g_return_if_fail (content[0] == '=');
 
-			xml_cell_set_array_expr (cell, content+1,
+			xml_cell_set_array_expr (state, cell, content+1,
 						 array_cols, array_rows);
 		} else if (state->version >= GNM_XML_V3 ||
-			   xml_not_used_old_array_spec (cell, content)) {
+			   xml_not_used_old_array_spec (state, cell, content)) {
 			if (value_type > 0) {
 				GnmValue *v = value_new_from_string (value_type, content, value_fmt, FALSE);
 				if (v == NULL) {
@@ -1498,8 +1746,21 @@ xml_sax_cell_content (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 					gnm_cell_set_text (cell, content);
 				} else
 					gnm_cell_set_value (cell, v);
-			} else
-				gnm_cell_set_text (cell, content);
+			} else {
+				const char *expr_start = gnm_expr_char_start_p (content);
+				if (expr_start && *expr_start) {
+					GnmParsePos pos;
+					GnmExprTop const *texpr =
+						gnm_expr_parse_str (expr_start,
+								    parse_pos_init_cell (&pos, cell),
+								    GNM_EXPR_PARSE_DEFAULT,
+								    state->convs,
+								    NULL);
+					gnm_cell_set_expr (cell, texpr);
+					gnm_expr_top_unref (texpr);
+				} else
+					gnm_cell_set_text (cell, content);
+			}
 		}
 
 		if (expr_id > 0) {
@@ -1608,9 +1869,11 @@ xml_sax_filter_condition (GsfXMLIn *xin, xmlChar const **attrs)
 			v0 = value_new_from_string (vtype0, val0, NULL, FALSE);
 		if (val1 != NULL && vtype1 != VALUE_EMPTY)
 			v1 = value_new_from_string (vtype1, val1, NULL, FALSE);
-		if (v0 != NULL)
+		if (v0 && v1)
 			cond = gnm_filter_condition_new_double (
 				op0, v0, is_and, op1, v1);
+		else if (v0)
+			cond = gnm_filter_condition_new_single (op0, v0);
 	} else if (0 == g_ascii_strcasecmp (type, "blanks")) {
 		cond = gnm_filter_condition_new_single (
 			GNM_FILTER_OP_BLANKS, NULL);
@@ -1838,11 +2101,26 @@ xml_sax_named_expr_prop (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 	}
 }
 
+static void
+xml_sax_print_order (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
+{
+	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
+
+	g_return_if_fail (state != NULL);
+	g_return_if_fail (state->sheet != NULL);
+	g_return_if_fail (state->sheet->print_info != NULL);
+
+	state->sheet->print_info->print_across_then_down =
+		(strcmp (xin->content->str, "r_then_d") == 0);
+}
+
+
 static void
 xml_sax_orientation (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 {
 	XMLSaxParseState *state = (XMLSaxParseState *)xin->user_state;
 	PrintInformation *pi;
+	GtkPageOrientation orient = GTK_PAGE_ORIENTATION_PORTRAIT;
 
 	g_return_if_fail (state->sheet != NULL);
 	g_return_if_fail (state->sheet->print_info != NULL);
@@ -1850,10 +2128,12 @@ xml_sax_orientation (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 	pi = state->sheet->print_info;
 
 #warning TODO: we should also handle inversion
-	print_info_set_paper_orientation (pi,
-					  strcmp (xin->content->str, "portrait")
-					  ? GTK_PAGE_ORIENTATION_LANDSCAPE
-					  : GTK_PAGE_ORIENTATION_PORTRAIT);
+	if (strcmp (xin->content->str, "portrait") == 0)
+			orient = GTK_PAGE_ORIENTATION_PORTRAIT;
+	else if (strcmp (xin->content->str, "landscape") == 0)
+			orient = GTK_PAGE_ORIENTATION_LANDSCAPE;
+
+	print_info_set_paper_orientation (pi, orient);
 }
 
 static void
@@ -1882,7 +2162,7 @@ handle_delayed_names (XMLSaxParseState *state)
 		parse_error_init (&perr);
 		texpr = gnm_expr_parse_str (expr_str, pos,
 					    GNM_EXPR_PARSE_DEFAULT,
-					    gnm_conventions_default,
+					    state->convs,
 					    &perr);
 		if (texpr)
 			expr_name_set_expr (nexpr, texpr);
@@ -1968,23 +2248,32 @@ GSF_XML_IN_NODE_FULL (START, WB, GNM, "Workbook", GSF_XML_NO_CONTENT, TRUE, FALS
 	  GSF_XML_IN_NODE_FULL (PRINT_MARGINS, PRINT_MARGIN_RIGHT,  GNM, "right", GSF_XML_CONTENT, FALSE, FALSE, &xml_sax_print_margins, NULL, 3),
 	  GSF_XML_IN_NODE_FULL (PRINT_MARGINS, PRINT_MARGIN_HEADER, GNM, "header",GSF_XML_CONTENT, FALSE, FALSE, &xml_sax_print_margins, NULL, 4),
 	  GSF_XML_IN_NODE_FULL (PRINT_MARGINS, PRINT_MARGIN_FOOTER, GNM, "footer",GSF_XML_CONTENT, FALSE, FALSE, &xml_sax_print_margins, NULL, 5),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, V_BREAKS, GNM, "vBreaks", GSF_XML_NO_CONTENT, NULL, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, H_BREAKS, GNM, "hBreaks", GSF_XML_NO_CONTENT, NULL, NULL),
+
+	GSF_XML_IN_NODE_FULL (SHEET_PRINTINFO, V_PAGE_BREAKS, GNM, "vPageBreaks", GSF_XML_NO_CONTENT,
+			      FALSE, FALSE, &xml_sax_page_breaks_begin, &xml_sax_page_breaks_end, 0),
+	  GSF_XML_IN_NODE (V_PAGE_BREAKS, PAGE_BREAK, GNM, "brk", GSF_XML_NO_CONTENT, &xml_sax_page_break, NULL),
+	GSF_XML_IN_NODE_FULL (SHEET_PRINTINFO, H_PAGE_BREAKS, GNM, "hPageBreaks", GSF_XML_NO_CONTENT,
+			      FALSE, FALSE, &xml_sax_page_breaks_begin, &xml_sax_page_breaks_end, 0),
+	  GSF_XML_IN_NODE (H_PAGE_BREAKS, PAGE_BREAK, GNM, "brk", GSF_XML_NO_CONTENT, NULL, NULL), /* 2nd Def */
 
 	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_SCALE,	    GNM, "Scale",	GSF_XML_CONTENT, &xml_sax_print_scale, NULL),
-	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_VCENTER,    GNM, "vcenter",	GSF_XML_NO_CONTENT, NULL, NULL),
-	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_HCENTER,    GNM, "hcenter",	GSF_XML_NO_CONTENT, NULL, NULL),
-	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_GRID,	    GNM, "grid",	GSF_XML_NO_CONTENT, NULL, NULL),
-	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_MONO,	    GNM, "monochrome",	GSF_XML_NO_CONTENT, NULL, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_VCENTER,    GNM, "vcenter",	GSF_XML_CONTENT, &xml_sax_print_vcenter, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_HCENTER,    GNM, "hcenter",	GSF_XML_CONTENT, &xml_sax_print_hcenter, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_GRID,	    GNM, "grid",	GSF_XML_NO_CONTENT, &xml_sax_print_grid, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_MONO,	    GNM, "monochrome",	GSF_XML_NO_CONTENT, &xml_sax_monochrome, NULL),
 	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_AS_DRAFT,   GNM, "draft",	GSF_XML_NO_CONTENT, NULL, NULL),
 	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_COMMENTS,   GNM, "comments",	GSF_XML_NO_CONTENT, NULL, NULL),
-	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_TITLES,	    GNM, "titles",	GSF_XML_NO_CONTENT, NULL, NULL),
-	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_REPEAT_TOP, GNM, "repeat_top", 	GSF_XML_NO_CONTENT, NULL, NULL),
-	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_REPEAT_LEFT,GNM, "repeat_left",	GSF_XML_NO_CONTENT, NULL, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_TITLES,	    GNM, "titles",	GSF_XML_NO_CONTENT, &xml_sax_print_titles, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_REPEAT_TOP, GNM, "repeat_top", 	GSF_XML_NO_CONTENT, &xml_sax_repeat_top, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_REPEAT_LEFT,GNM, "repeat_left",	GSF_XML_NO_CONTENT, &xml_sax_repeat_left, NULL),
 	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_HEADER,	    GNM, "Footer",	GSF_XML_NO_CONTENT, NULL, NULL),
 	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_FOOTER,	    GNM, "Header",	GSF_XML_NO_CONTENT, NULL, NULL),
-	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_ORDER,	    GNM, "order",	GSF_XML_CONTENT,  NULL, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_ORDER,	    GNM, "order",	GSF_XML_CONTENT,  NULL, &xml_sax_print_order),
 	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_PAPER,	    GNM, "paper",	GSF_XML_CONTENT,  NULL, &xml_sax_paper),
 	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_ORIENT,	    GNM, "orientation",	GSF_XML_CONTENT,  NULL, &xml_sax_orientation),
-	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_ONLY_STYLE, GNM, "even_if_only_styles", GSF_XML_CONTENT, NULL, NULL),
+	GSF_XML_IN_NODE (SHEET_PRINTINFO, PRINT_ONLY_STYLE, GNM, "even_if_only_styles", GSF_XML_CONTENT, &xml_sax_even_if_only_styles, NULL),
 
       GSF_XML_IN_NODE (SHEET, SHEET_STYLES, GNM, "Styles", GSF_XML_NO_CONTENT, NULL, NULL),
 	GSF_XML_IN_NODE (SHEET_STYLES, STYLE_REGION, GNM, "StyleRegion", GSF_XML_NO_CONTENT, &xml_sax_style_region_start, &xml_sax_style_region_end),
@@ -2069,6 +2358,7 @@ GSF_XML_IN_NODE_FULL (START, WB, GNM, "Workbook", GSF_XML_NO_CONTENT, TRUE, FALS
   GSF_XML_IN_NODE (WB, WB_GEOMETRY, GNM, "Geometry", GSF_XML_NO_CONTENT, &xml_sax_wb_view, NULL),
   GSF_XML_IN_NODE (WB, WB_VIEW, GNM, "UIData", GSF_XML_NO_CONTENT, &xml_sax_wb_view, NULL),
   GSF_XML_IN_NODE (WB, WB_CALC, GNM, "Calculation", GSF_XML_NO_CONTENT, &xml_sax_calculation, NULL),
+  GSF_XML_IN_NODE (WB, WB_DATE, GNM, "DateConvention", GSF_XML_CONTENT, NULL, &xml_sax_old_dateconvention),
   { NULL }
 };
 
@@ -2196,6 +2486,8 @@ gnm_xml_file_open (GOFileOpener const *fo, IOContext *io_context,
 	state.wb = wb_view_get_workbook (wb_view);
 	state.sheet = NULL;
 	state.version = GNM_XML_UNKNOWN;
+	state.last_progress_update = 0;
+	state.convs = gnm_xml_io_conventions ();
 	state.attribute.name = state.attribute.value = NULL;
 	state.name.name = state.name.value = state.name.position = NULL;
 	state.style_range_init = FALSE;
@@ -2244,6 +2536,7 @@ gnm_xml_file_open (GOFileOpener const *fo, IOContext *io_context,
 
 	/* cleanup */
 	g_hash_table_destroy (state.expr_map);
+	gnm_conventions_free (state.convs);
 
 	gsf_xml_in_doc_free (doc);
 }
