@@ -4,7 +4,7 @@
  * xml-sax-write.c : export .gnumeric and the clipboard subset using a the sax
  * 			like wrappers in libgsf
  *
- * Copyright (C) 2003-2006 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2007 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -70,6 +70,7 @@ typedef struct {
 	Sheet const 	   *sheet;
 	GnmConventions	   *convs;
 	GHashTable	   *expr_map;
+	GString		   *cell_str;   /* Scratch pad.  */
 
 	GsfXMLOut *output;
 } GnmOutputXML;
@@ -138,10 +139,11 @@ xml_write_attributes (GnmOutputXML *state)
 static void
 xml_write_meta_data (GnmOutputXML *state)
 {
-	gsf_opendoc_metadata_write (state->output, 
+	gsf_opendoc_metadata_write (state->output,
 		go_doc_get_meta_data (GO_DOC (state->wb)));
 }
 
+/* DEPRECATED in 1.7.11 */
 static void
 xml_write_conventions (GnmOutputXML *state)
 {
@@ -254,6 +256,8 @@ xml_write_print_info (GnmOutputXML *state, PrintInformation *pi)
 	double footer;
 	double left;
 	double right;
+	double edge_to_above_footer;
+	double edge_to_below_header;
 	GtkPageOrientation orient;
 
 	g_return_if_fail (pi != NULL);
@@ -261,11 +265,13 @@ xml_write_print_info (GnmOutputXML *state, PrintInformation *pi)
 	gsf_xml_out_start_element (state->output, GNM "PrintInformation");
 
 	gsf_xml_out_start_element (state->output, GNM "Margins");
-	xml_write_print_unit (state, GNM "top",    pi->margin.top,
+
+	print_info_get_margins (pi, &header, &footer, &left, &right,
+				&edge_to_below_header, &edge_to_above_footer);
+	xml_write_print_unit (state, GNM "top", edge_to_below_header,
 			      pi->desired_display.header);
-	xml_write_print_unit (state, GNM "bottom", pi->margin.bottom,
+	xml_write_print_unit (state, GNM "bottom", edge_to_above_footer,
 			      pi->desired_display.footer);
-	print_info_get_margins (pi, &header, &footer, &left, &right);
 	xml_write_print_unit (state, GNM "left", left,
 			      pi->desired_display.left);
 	xml_write_print_unit (state, GNM "right", right,
@@ -523,7 +529,7 @@ xml_write_gnmstyle (GnmOutputXML *state, GnmStyle const *style)
 			    NULL != (border = gnm_style_get_border (style, i))) {
 				GnmStyleBorderType t = border->line_type;
 				GnmColor *col   = border->color;
-				gsf_xml_out_start_element (state->output, 
+				gsf_xml_out_start_element (state->output,
 					border_names [i - MSTYLE_BORDER_TOP]);
 				gsf_xml_out_add_int (state->output, "Style", t);
 				if (t != GNM_STYLE_BORDER_NONE)
@@ -721,7 +727,9 @@ xml_write_cell_and_position (GnmOutputXML *state,
 	}
 
 	if (write_contents) {
-		GString *str = g_string_sized_new (1000);
+		GString *str = state->cell_str;
+
+		g_string_truncate (str, 0);
 
 		if (!texpr) {
 			if (val != NULL) {
@@ -745,7 +753,6 @@ xml_write_cell_and_position (GnmOutputXML *state,
 		}
 
 		gsf_xml_out_add_cstr (state->output, NULL, str->str);
-		g_string_free (str, TRUE);
 	}
 	gsf_xml_out_end_element (state->output); /* </gnm:Cell> */
 }
@@ -1006,7 +1013,7 @@ xml_write_scenarios (GnmOutputXML *state)
 }
 
 static void
-xml_write_objects (GnmOutputXML *state, GSList *ptr)
+xml_write_objects (GnmOutputXML *state, GSList *objects)
 {
 	gboolean needs_container = TRUE;
 	SheetObject	 *so;
@@ -1014,8 +1021,12 @@ xml_write_objects (GnmOutputXML *state, GSList *ptr)
 	char buffer[4*(DBL_DIG+10)];
 	char const *type_name;
 	char *tmp;
+	GSList *ptr;
 
-	for (;ptr != NULL ; ptr = ptr->next) {
+	/* reverse the list to maintain order when we prepend the objects in
+	 * sheet_object_set_sheet on import */
+	objects = g_slist_reverse ( g_slist_copy (objects));
+	for (ptr = objects ;ptr != NULL ; ptr = ptr->next) {
 		so = ptr->data;
 		klass = SHEET_OBJECT_CLASS (G_OBJECT_GET_CLASS (so));
 		if (klass == NULL || klass->write_xml_sax == NULL)
@@ -1047,6 +1058,7 @@ xml_write_objects (GnmOutputXML *state, GSList *ptr)
 		gsf_xml_out_end_element (state->output); /* </gnm:{typename}> */
 		g_free (tmp);
 	}
+	g_slist_free (objects);
 
 	if (!needs_container)
 		gsf_xml_out_end_element (state->output); /* </gnm:Objects> */
@@ -1080,6 +1092,12 @@ xml_write_sheet (GnmOutputXML *state, Sheet const *sheet)
 	if (sheet->is_protected)
 		gsf_xml_out_add_bool (state->output,
 			"Protected", sheet->is_protected);
+
+	/* TODO : Make this an enum internally eventually */
+	if (sheet->convs->r1c1_addresses)
+		gsf_xml_out_add_cstr_unchecked (state->output,
+			"ExprConvention", "gnumeric:R1C1");
+
 	gsf_xml_out_add_enum (state->output,
 		"Visibility", GNM_SHEET_VISIBILITY_TYPE, sheet->visibility);
 
@@ -1137,31 +1155,37 @@ xml_write_uidata (GnmOutputXML *state)
 static void
 xml_write_calculation (GnmOutputXML *state)
 {
+	GODateConventions const *conv = workbook_date_conv (state->wb);
+
 	gsf_xml_out_start_element (state->output, GNM "Calculation");
-	gsf_xml_out_add_bool (state->output, 
+	gsf_xml_out_add_bool (state->output,
 		"ManualRecalc",		!state->wb->recalc_auto);
-	gsf_xml_out_add_bool (state->output, 
+	gsf_xml_out_add_bool (state->output,
 		"EnableIteration",	state->wb->iteration.enabled);
-	gsf_xml_out_add_int (state->output, 
+	gsf_xml_out_add_int (state->output,
 		"MaxIterations",	state->wb->iteration.max_number);
-	gsf_xml_out_add_float (state->output, 
+	gsf_xml_out_add_float (state->output,
 		"IterationTolerance",	state->wb->iteration.tolerance, -1);
+	if (conv->use_1904)
+		gsf_xml_out_add_cstr_unchecked (state->output,
+			GNM "DateConvention", "Apple:1904");
+
 	gsf_xml_out_end_element (state->output); /* </gnm:Calculation> */
 }
 
-static GnmConventions *
-xml_io_conventions (void)
+GnmConventions *
+gnm_xml_io_conventions (void)
 {
 	GnmConventions *res = gnm_conventions_new ();
 
-	res->decimal_sep_dot		= TRUE;
-	res->input.range_ref		= rangeref_parse;
-	res->output.range_ref		= gnm_1_0_rangeref_as_string;
-	res->range_sep_colon		= TRUE;
-	res->arg_sep			= ',';
-	res->array_col_sep		= ',';
-	res->array_row_sep		= ';';
-	res->output.translated		= FALSE;
+	res->decimal_sep_dot	= TRUE;
+	res->input.range_ref	= rangeref_parse;
+	res->output.range_ref	= gnm_1_0_rangeref_as_string;
+	res->range_sep_colon	= TRUE;
+	res->arg_sep		= ',';
+	res->array_col_sep	= ',';
+	res->array_row_sep	= ';';
+	res->output.translated	= FALSE;
 
 	return res;
 }
@@ -1181,7 +1205,7 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 		extension = gsf_extension_pointer (gsf_output_name (output));
 	if (NULL != extension && g_ascii_strcasecmp (extension, "xml") == 0)
 		compress = FALSE;
-	else 
+	else
 		compress = (gnm_app_prefs->xml_compression_level > 0);
 
 	if (compress) {
@@ -1193,8 +1217,9 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 	state.wb	= wb_view_get_workbook (wb_view);
 	state.sheet	= NULL;
 	state.output	= gsf_xml_out_new (output);
-	state.convs	= xml_io_conventions ();
+	state.convs	= gnm_xml_io_conventions ();
 	state.expr_map  = g_hash_table_new (g_direct_hash, g_direct_equal);
+	state.cell_str  = g_string_new (NULL);
 
 	locale = gnm_push_C_locale ();
 
@@ -1209,7 +1234,7 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 	xml_write_version	    (&state);
 	xml_write_attributes	    (&state);
 	xml_write_meta_data	    (&state);
-	xml_write_conventions	    (&state);
+	xml_write_conventions	    (&state);	/* DEPRECATED, moved to Calculation */
 	xml_write_sheet_names	    (&state);
 	xml_write_named_expressions (&state, state.wb->names);
 	xml_write_geometry 	    (&state);
@@ -1222,6 +1247,7 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 	gnm_pop_C_locale (locale);
 
 	g_hash_table_destroy (state.expr_map);
+	g_string_free (state.cell_str, TRUE);
 	gnm_conventions_free (state.convs);
 	g_object_unref (G_OBJECT (state.output));
 
@@ -1269,12 +1295,13 @@ gnm_cellregion_to_xml (GnmCellRegion const *cr)
 	g_return_val_if_fail (cr != NULL, NULL);
 	g_return_val_if_fail (IS_SHEET (cr->origin_sheet), NULL);
 
-	state.state.wb_view	= NULL;
-	state.state.wb	= NULL;
-	state.state.sheet	= NULL;
-	state.state.output	= gsf_xml_out_new (buf);
-	state.state.convs	= xml_io_conventions ();
-	state.state.expr_map  = g_hash_table_new (g_direct_hash, g_direct_equal);
+	state.state.wb_view = NULL;
+	state.state.wb = NULL;
+	state.state.sheet = NULL;
+	state.state.output = gsf_xml_out_new (buf);
+	state.state.convs = gnm_xml_io_conventions ();
+	state.state.expr_map = g_hash_table_new (g_direct_hash, g_direct_equal);
+	state.state.cell_str = g_string_new (NULL);
 
 	locale = gnm_push_C_locale ();
 
@@ -1324,6 +1351,7 @@ gnm_cellregion_to_xml (GnmCellRegion const *cr)
 	gnm_pop_C_locale (locale);
 
 	g_hash_table_destroy (state.state.expr_map);
+	g_string_free (state.state.cell_str, TRUE);
 	gnm_conventions_free (state.state.convs);
 	g_object_unref (G_OBJECT (state.state.output));
 
